"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InvalidOriginReadTimeout$ = exports.InvalidOriginKeepaliveTimeout$ = exports.InvalidOriginAccessIdentity$ = exports.InvalidOriginAccessControl$ = exports.InvalidOrigin$ = exports.InvalidMinimumProtocolVersion$ = exports.InvalidLocationCode$ = exports.InvalidLambdaFunctionAssociation$ = exports.InvalidIfMatchVersion$ = exports.InvalidHeadersForS3Origin$ = exports.InvalidGeoRestrictionParameter$ = exports.InvalidFunctionAssociation$ = exports.InvalidForwardCookies$ = exports.InvalidErrorCode$ = exports.InvalidDomainNameForOriginAccessControl$ = exports.InvalidDefaultRootObject$ = exports.InvalidAssociation$ = exports.InvalidArgument$ = exports.InconsistentQuantities$ = exports.IllegalUpdate$ = exports.IllegalOriginAccessConfiguration$ = exports.IllegalFieldLevelEncryptionConfigAssociationWithCacheBehavior$ = exports.IllegalDelete$ = exports.FunctionSizeLimitExceeded$ = exports.FunctionInUse$ = exports.FunctionAlreadyExists$ = exports.FieldLevelEncryptionProfileSizeExceeded$ = exports.FieldLevelEncryptionProfileInUse$ = exports.FieldLevelEncryptionProfileAlreadyExists$ = exports.FieldLevelEncryptionConfigInUse$ = exports.FieldLevelEncryptionConfigAlreadyExists$ = exports.EntitySizeLimitExceeded$ = exports.EntityNotFound$ = exports.EntityLimitExceeded$ = exports.EntityAlreadyExists$ = exports.DistributionNotDisabled$ = exports.DistributionAlreadyExists$ = exports.ContinuousDeploymentPolicyInUse$ = exports.ContinuousDeploymentPolicyAlreadyExists$ = exports.CNAMEAlreadyExists$ = exports.CloudFrontOriginAccessIdentityInUse$ = exports.CloudFrontOriginAccessIdentityAlreadyExists$ = exports.CannotUpdateEntityWhileInUse$ = exports.CannotDeleteEntityWhileInUse$ = exports.CannotChangeImmutablePublicKeyFields$ = exports.CachePolicyInUse$ = exports.CachePolicyAlreadyExists$ = exports.BatchTooLarge$ = exports.AccessDenied$ = exports.CloudFrontServiceException$ = void 0;
exports.TooManyCacheBehaviors$ = exports.TooLongCSPInResponseHeadersPolicy$ = exports.TestFunctionFailed$ = exports.StreamingDistributionNotDisabled$ = exports.StreamingDistributionAlreadyExists$ = exports.StagingDistributionInUse$ = exports.ResponseHeadersPolicyInUse$ = exports.ResponseHeadersPolicyAlreadyExists$ = exports.ResourceNotDisabled$ = exports.ResourceInUse$ = exports.RealtimeLogConfigOwnerMismatch$ = exports.RealtimeLogConfigInUse$ = exports.RealtimeLogConfigAlreadyExists$ = exports.QueryArgProfileEmpty$ = exports.PublicKeyInUse$ = exports.PublicKeyAlreadyExists$ = exports.PreconditionFailed$ = exports.OriginRequestPolicyInUse$ = exports.OriginRequestPolicyAlreadyExists$ = exports.OriginAccessControlInUse$ = exports.OriginAccessControlAlreadyExists$ = exports.NoSuchStreamingDistribution$ = exports.NoSuchResponseHeadersPolicy$ = exports.NoSuchResource$ = exports.NoSuchRealtimeLogConfig$ = exports.NoSuchPublicKey$ = exports.NoSuchOriginRequestPolicy$ = exports.NoSuchOriginAccessControl$ = exports.NoSuchOrigin$ = exports.NoSuchMonitoringSubscription$ = exports.NoSuchInvalidation$ = exports.NoSuchFunctionExists$ = exports.NoSuchFieldLevelEncryptionProfile$ = exports.NoSuchFieldLevelEncryptionConfig$ = exports.NoSuchDistribution$ = exports.NoSuchContinuousDeploymentPolicy$ = exports.NoSuchCloudFrontOriginAccessIdentity$ = exports.NoSuchCachePolicy$ = exports.MonitoringSubscriptionAlreadyExists$ = exports.MissingBody$ = exports.KeyGroupAlreadyExists$ = exports.InvalidWebACLId$ = exports.InvalidViewerCertificate$ = exports.InvalidTTLOrder$ = exports.InvalidTagging$ = exports.InvalidResponseCode$ = exports.InvalidRequiredProtocol$ = exports.InvalidRelativePath$ = exports.InvalidQueryStringParameters$ = exports.InvalidProtocolSettings$ = void 0;
exports.TooManyTrustedSigners$ = exports.TooManyStreamingDistributions$ = exports.TooManyStreamingDistributionCNAMEs$ = exports.TooManyResponseHeadersPolicies$ = exports.TooManyRemoveHeadersInResponseHeadersPolicy$ = exports.TooManyRealtimeLogConfigs$ = exports.TooManyQueryStringsInOriginRequestPolicy$ = exports.TooManyQueryStringsInCachePolicy$ = exports.TooManyQueryStringParameters$ = exports.TooManyPublicKeysInKeyGroup$ = exports.TooManyPublicKeys$ = exports.TooManyOrigins$ = exports.TooManyOriginRequestPolicies$ = exports.TooManyOriginGroupsPerDistribution$ = exports.TooManyOriginCustomHeaders$ = exports.TooManyOriginAccessControls$ = exports.TooManyLambdaFunctionAssociations$ = exports.TooManyKeyGroupsAssociatedToDistribution$ = exports.TooManyKeyGroups$ = exports.TooManyInvalidationsInProgress$ = exports.TooManyHeadersInOriginRequestPolicy$ = exports.TooManyHeadersInForwardedValues$ = exports.TooManyHeadersInCachePolicy$ = exports.TooManyFunctions$ = exports.TooManyFunctionAssociations$ = exports.TooManyFieldLevelEncryptionQueryArgProfiles$ = exports.TooManyFieldLevelEncryptionProfiles$ = exports.TooManyFieldLevelEncryptionFieldPatterns$ = exports.TooManyFieldLevelEncryptionEncryptionEntities$ = exports.TooManyFieldLevelEncryptionContentTypeProfiles$ = exports.TooManyFieldLevelEncryptionConfigs$ = exports.TooManyDistributionsWithSingleFunctionARN$ = exports.TooManyDistributionsWithLambdaAssociations$ = exports.TooManyDistributionsWithFunctionAssociations$ = exports.TooManyDistributionsAssociatedToResponseHeadersPolicy$ = exports.TooManyDistributionsAssociatedToOriginRequestPolicy$ = exports.TooManyDistributionsAssociatedToOriginAccessControl$ = exports.TooManyDistributionsAssociatedToKeyGroup$ = exports.TooManyDistributionsAssociatedToFieldLevelEncryptionConfig$ = exports.TooManyDistributionsAssociatedToCachePolicy$ = exports.TooManyDistributions$ = exports.TooManyDistributionCNAMEs$ = exports.TooManyCustomHeadersInResponseHeadersPolicy$ = exports.TooManyCookiesInOriginRequestPolicy$ = exports.TooManyCookiesInCachePolicy$ = exports.TooManyCookieNamesInWhiteList$ = exports.TooManyContinuousDeploymentPolicies$ = exports.TooManyCloudFrontOriginAccessIdentities$ = exports.TooManyCertificates$ = exports.TooManyCachePolicies$ = void 0;
exports.ContinuousDeploymentSingleWeightConfig$ = exports.ContinuousDeploymentSingleHeaderConfig$ = exports.ContinuousDeploymentPolicySummary$ = exports.ContinuousDeploymentPolicyList$ = exports.ContinuousDeploymentPolicyConfig$ = exports.ContinuousDeploymentPolicy$ = exports.ContentTypeProfiles$ = exports.ContentTypeProfileConfig$ = exports.ContentTypeProfile$ = exports.ConnectionGroupSummary$ = exports.ConnectionGroupAssociationFilter$ = exports.ConnectionGroup$ = exports.ConnectionFunctionTestResult$ = exports.ConnectionFunctionSummary$ = exports.ConnectionFunctionAssociation$ = exports.ConflictingAliasesList$ = exports.ConflictingAlias$ = exports.CloudFrontOriginAccessIdentitySummary$ = exports.CloudFrontOriginAccessIdentityList$ = exports.CloudFrontOriginAccessIdentityConfig$ = exports.CloudFrontOriginAccessIdentity$ = exports.Certificate$ = exports.CachePolicySummary$ = exports.CachePolicyQueryStringsConfig$ = exports.CachePolicyList$ = exports.CachePolicyHeadersConfig$ = exports.CachePolicyCookiesConfig$ = exports.CachePolicyConfig$ = exports.CachePolicy$ = exports.CachedMethods$ = exports.CacheBehaviors$ = exports.CacheBehavior$ = exports.CaCertificatesBundleS3Location$ = exports.AssociateDistributionWebACLResult$ = exports.AssociateDistributionWebACLRequest$ = exports.AssociateDistributionTenantWebACLResult$ = exports.AssociateDistributionTenantWebACLRequest$ = exports.AssociateAliasRequest$ = exports.AnycastIpListSummary$ = exports.AnycastIpListCollection$ = exports.AnycastIpList$ = exports.AllowedMethods$ = exports.AliasICPRecordal$ = exports.Aliases$ = exports.ActiveTrustedSigners$ = exports.ActiveTrustedKeyGroups$ = exports.errorTypeRegistries = exports.UnsupportedOperation$ = exports.TrustedSignerDoesNotExist$ = exports.TrustedKeyGroupDoesNotExist$ = void 0;
exports.CreateStreamingDistributionResult$ = exports.CreateStreamingDistributionRequest$ = exports.CreateResponseHeadersPolicyResult$ = exports.CreateResponseHeadersPolicyRequest$ = exports.CreateRealtimeLogConfigResult$ = exports.CreateRealtimeLogConfigRequest$ = exports.CreatePublicKeyResult$ = exports.CreatePublicKeyRequest$ = exports.CreateOriginRequestPolicyResult$ = exports.CreateOriginRequestPolicyRequest$ = exports.CreateOriginAccessControlResult$ = exports.CreateOriginAccessControlRequest$ = exports.CreateMonitoringSubscriptionResult$ = exports.CreateMonitoringSubscriptionRequest$ = exports.CreateKeyValueStoreResult$ = exports.CreateKeyValueStoreRequest$ = exports.CreateKeyGroupResult$ = exports.CreateKeyGroupRequest$ = exports.CreateInvalidationResult$ = exports.CreateInvalidationRequest$ = exports.CreateInvalidationForDistributionTenantResult$ = exports.CreateInvalidationForDistributionTenantRequest$ = exports.CreateFunctionResult$ = exports.CreateFunctionRequest$ = exports.CreateFieldLevelEncryptionProfileResult$ = exports.CreateFieldLevelEncryptionProfileRequest$ = exports.CreateFieldLevelEncryptionConfigResult$ = exports.CreateFieldLevelEncryptionConfigRequest$ = exports.CreateDistributionWithTagsResult$ = exports.CreateDistributionWithTagsRequest$ = exports.CreateDistributionTenantResult$ = exports.CreateDistributionTenantRequest$ = exports.CreateDistributionResult$ = exports.CreateDistributionRequest$ = exports.CreateContinuousDeploymentPolicyResult$ = exports.CreateContinuousDeploymentPolicyRequest$ = exports.CreateConnectionGroupResult$ = exports.CreateConnectionGroupRequest$ = exports.CreateConnectionFunctionResult$ = exports.CreateConnectionFunctionRequest$ = exports.CreateCloudFrontOriginAccessIdentityResult$ = exports.CreateCloudFrontOriginAccessIdentityRequest$ = exports.CreateCachePolicyResult$ = exports.CreateCachePolicyRequest$ = exports.CreateAnycastIpListResult$ = exports.CreateAnycastIpListRequest$ = exports.CopyDistributionResult$ = exports.CopyDistributionRequest$ = exports.CookiePreference$ = exports.CookieNames$ = void 0;
exports.DistributionConfigWithTags$ = exports.DistributionConfig$ = exports.Distribution$ = exports.DisassociateDistributionWebACLResult$ = exports.DisassociateDistributionWebACLRequest$ = exports.DisassociateDistributionTenantWebACLResult$ = exports.DisassociateDistributionTenantWebACLRequest$ = exports.DescribeKeyValueStoreResult$ = exports.DescribeKeyValueStoreRequest$ = exports.DescribeFunctionResult$ = exports.DescribeFunctionRequest$ = exports.DescribeConnectionFunctionResult$ = exports.DescribeConnectionFunctionRequest$ = exports.DeleteVpcOriginResult$ = exports.DeleteVpcOriginRequest$ = exports.DeleteTrustStoreRequest$ = exports.DeleteStreamingDistributionRequest$ = exports.DeleteResponseHeadersPolicyRequest$ = exports.DeleteResourcePolicyRequest$ = exports.DeleteRealtimeLogConfigRequest$ = exports.DeletePublicKeyRequest$ = exports.DeleteOriginRequestPolicyRequest$ = exports.DeleteOriginAccessControlRequest$ = exports.DeleteMonitoringSubscriptionResult$ = exports.DeleteMonitoringSubscriptionRequest$ = exports.DeleteKeyValueStoreRequest$ = exports.DeleteKeyGroupRequest$ = exports.DeleteFunctionRequest$ = exports.DeleteFieldLevelEncryptionProfileRequest$ = exports.DeleteFieldLevelEncryptionConfigRequest$ = exports.DeleteDistributionTenantRequest$ = exports.DeleteDistributionRequest$ = exports.DeleteContinuousDeploymentPolicyRequest$ = exports.DeleteConnectionGroupRequest$ = exports.DeleteConnectionFunctionRequest$ = exports.DeleteCloudFrontOriginAccessIdentityRequest$ = exports.DeleteCachePolicyRequest$ = exports.DeleteAnycastIpListRequest$ = exports.DefaultCacheBehavior$ = exports.CustomOriginConfig$ = exports.Customizations$ = exports.CustomHeaders$ = exports.CustomErrorResponses$ = exports.CustomErrorResponse$ = exports.CreateVpcOriginResult$ = exports.CreateVpcOriginRequest$ = exports.CreateTrustStoreResult$ = exports.CreateTrustStoreRequest$ = exports.CreateStreamingDistributionWithTagsResult$ = exports.CreateStreamingDistributionWithTagsRequest$ = void 0;
exports.GetConnectionGroupResult$ = exports.GetConnectionGroupRequest$ = exports.GetConnectionGroupByRoutingEndpointResult$ = exports.GetConnectionGroupByRoutingEndpointRequest$ = exports.GetConnectionFunctionResult$ = exports.GetConnectionFunctionRequest$ = exports.GetCloudFrontOriginAccessIdentityResult$ = exports.GetCloudFrontOriginAccessIdentityRequest$ = exports.GetCloudFrontOriginAccessIdentityConfigResult$ = exports.GetCloudFrontOriginAccessIdentityConfigRequest$ = exports.GetCachePolicyResult$ = exports.GetCachePolicyRequest$ = exports.GetCachePolicyConfigResult$ = exports.GetCachePolicyConfigRequest$ = exports.GetAnycastIpListResult$ = exports.GetAnycastIpListRequest$ = exports.GeoRestrictionCustomization$ = exports.GeoRestriction$ = exports.FunctionSummary$ = exports.FunctionMetadata$ = exports.FunctionList$ = exports.FunctionConfig$ = exports.FunctionAssociations$ = exports.FunctionAssociation$ = exports.ForwardedValues$ = exports.FieldPatterns$ = exports.FieldLevelEncryptionSummary$ = exports.FieldLevelEncryptionProfileSummary$ = exports.FieldLevelEncryptionProfileList$ = exports.FieldLevelEncryptionProfileConfig$ = exports.FieldLevelEncryptionProfile$ = exports.FieldLevelEncryptionList$ = exports.FieldLevelEncryptionConfig$ = exports.FieldLevelEncryption$ = exports.EndPoint$ = exports.EncryptionEntity$ = exports.EncryptionEntities$ = exports.DomainResult$ = exports.DomainItem$ = exports.DomainConflict$ = exports.DnsConfiguration$ = exports.DistributionTenantSummary$ = exports.DistributionTenantAssociationFilter$ = exports.DistributionTenant$ = exports.DistributionSummary$ = exports.DistributionResourceId$ = exports.DistributionList$ = exports.DistributionIdOwnerList$ = exports.DistributionIdOwner$ = exports.DistributionIdList$ = void 0;
exports.GetResourcePolicyResult$ = exports.GetResourcePolicyRequest$ = exports.GetRealtimeLogConfigResult$ = exports.GetRealtimeLogConfigRequest$ = exports.GetPublicKeyResult$ = exports.GetPublicKeyRequest$ = exports.GetPublicKeyConfigResult$ = exports.GetPublicKeyConfigRequest$ = exports.GetOriginRequestPolicyResult$ = exports.GetOriginRequestPolicyRequest$ = exports.GetOriginRequestPolicyConfigResult$ = exports.GetOriginRequestPolicyConfigRequest$ = exports.GetOriginAccessControlResult$ = exports.GetOriginAccessControlRequest$ = exports.GetOriginAccessControlConfigResult$ = exports.GetOriginAccessControlConfigRequest$ = exports.GetMonitoringSubscriptionResult$ = exports.GetMonitoringSubscriptionRequest$ = exports.GetManagedCertificateDetailsResult$ = exports.GetManagedCertificateDetailsRequest$ = exports.GetKeyGroupResult$ = exports.GetKeyGroupRequest$ = exports.GetKeyGroupConfigResult$ = exports.GetKeyGroupConfigRequest$ = exports.GetInvalidationResult$ = exports.GetInvalidationRequest$ = exports.GetInvalidationForDistributionTenantResult$ = exports.GetInvalidationForDistributionTenantRequest$ = exports.GetFunctionResult$ = exports.GetFunctionRequest$ = exports.GetFieldLevelEncryptionResult$ = exports.GetFieldLevelEncryptionRequest$ = exports.GetFieldLevelEncryptionProfileResult$ = exports.GetFieldLevelEncryptionProfileRequest$ = exports.GetFieldLevelEncryptionProfileConfigResult$ = exports.GetFieldLevelEncryptionProfileConfigRequest$ = exports.GetFieldLevelEncryptionConfigResult$ = exports.GetFieldLevelEncryptionConfigRequest$ = exports.GetDistributionTenantResult$ = exports.GetDistributionTenantRequest$ = exports.GetDistributionTenantByDomainResult$ = exports.GetDistributionTenantByDomainRequest$ = exports.GetDistributionResult$ = exports.GetDistributionRequest$ = exports.GetDistributionConfigResult$ = exports.GetDistributionConfigRequest$ = exports.GetContinuousDeploymentPolicyResult$ = exports.GetContinuousDeploymentPolicyRequest$ = exports.GetContinuousDeploymentPolicyConfigResult$ = exports.GetContinuousDeploymentPolicyConfigRequest$ = void 0;
exports.ListDistributionsByAnycastIpListIdResult$ = exports.ListDistributionsByAnycastIpListIdRequest$ = exports.ListContinuousDeploymentPoliciesResult$ = exports.ListContinuousDeploymentPoliciesRequest$ = exports.ListConnectionGroupsResult$ = exports.ListConnectionGroupsRequest$ = exports.ListConnectionFunctionsResult$ = exports.ListConnectionFunctionsRequest$ = exports.ListConflictingAliasesResult$ = exports.ListConflictingAliasesRequest$ = exports.ListCloudFrontOriginAccessIdentitiesResult$ = exports.ListCloudFrontOriginAccessIdentitiesRequest$ = exports.ListCachePoliciesResult$ = exports.ListCachePoliciesRequest$ = exports.ListAnycastIpListsResult$ = exports.ListAnycastIpListsRequest$ = exports.LambdaFunctionAssociations$ = exports.LambdaFunctionAssociation$ = exports.KinesisStreamConfig$ = exports.KGKeyPairIds$ = exports.KeyValueStoreList$ = exports.KeyValueStoreAssociations$ = exports.KeyValueStoreAssociation$ = exports.KeyValueStore$ = exports.KeyPairIds$ = exports.KeyGroupSummary$ = exports.KeyGroupList$ = exports.KeyGroupConfig$ = exports.KeyGroup$ = exports.IpamConfig$ = exports.IpamCidrConfig$ = exports.InvalidationSummary$ = exports.InvalidationList$ = exports.InvalidationBatch$ = exports.Invalidation$ = exports.ImportSource$ = exports.Headers$ = exports.GrpcConfig$ = exports.GetVpcOriginResult$ = exports.GetVpcOriginRequest$ = exports.GetTrustStoreResult$ = exports.GetTrustStoreRequest$ = exports.GetStreamingDistributionResult$ = exports.GetStreamingDistributionRequest$ = exports.GetStreamingDistributionConfigResult$ = exports.GetStreamingDistributionConfigRequest$ = exports.GetResponseHeadersPolicyResult$ = exports.GetResponseHeadersPolicyRequest$ = exports.GetResponseHeadersPolicyConfigResult$ = exports.GetResponseHeadersPolicyConfigRequest$ = void 0;
exports.ListPublicKeysResult$ = exports.ListPublicKeysRequest$ = exports.ListOriginRequestPoliciesResult$ = exports.ListOriginRequestPoliciesRequest$ = exports.ListOriginAccessControlsResult$ = exports.ListOriginAccessControlsRequest$ = exports.ListKeyValueStoresResult$ = exports.ListKeyValueStoresRequest$ = exports.ListKeyGroupsResult$ = exports.ListKeyGroupsRequest$ = exports.ListInvalidationsResult$ = exports.ListInvalidationsRequest$ = exports.ListInvalidationsForDistributionTenantResult$ = exports.ListInvalidationsForDistributionTenantRequest$ = exports.ListFunctionsResult$ = exports.ListFunctionsRequest$ = exports.ListFieldLevelEncryptionProfilesResult$ = exports.ListFieldLevelEncryptionProfilesRequest$ = exports.ListFieldLevelEncryptionConfigsResult$ = exports.ListFieldLevelEncryptionConfigsRequest$ = exports.ListDomainConflictsResult$ = exports.ListDomainConflictsRequest$ = exports.ListDistributionTenantsResult$ = exports.ListDistributionTenantsRequest$ = exports.ListDistributionTenantsByCustomizationResult$ = exports.ListDistributionTenantsByCustomizationRequest$ = exports.ListDistributionsResult$ = exports.ListDistributionsRequest$ = exports.ListDistributionsByWebACLIdResult$ = exports.ListDistributionsByWebACLIdRequest$ = exports.ListDistributionsByVpcOriginIdResult$ = exports.ListDistributionsByVpcOriginIdRequest$ = exports.ListDistributionsByTrustStoreResult$ = exports.ListDistributionsByTrustStoreRequest$ = exports.ListDistributionsByResponseHeadersPolicyIdResult$ = exports.ListDistributionsByResponseHeadersPolicyIdRequest$ = exports.ListDistributionsByRealtimeLogConfigResult$ = exports.ListDistributionsByRealtimeLogConfigRequest$ = exports.ListDistributionsByOwnedResourceResult$ = exports.ListDistributionsByOwnedResourceRequest$ = exports.ListDistributionsByOriginRequestPolicyIdResult$ = exports.ListDistributionsByOriginRequestPolicyIdRequest$ = exports.ListDistributionsByKeyGroupResult$ = exports.ListDistributionsByKeyGroupRequest$ = exports.ListDistributionsByConnectionModeResult$ = exports.ListDistributionsByConnectionModeRequest$ = exports.ListDistributionsByConnectionFunctionResult$ = exports.ListDistributionsByConnectionFunctionRequest$ = exports.ListDistributionsByCachePolicyIdResult$ = exports.ListDistributionsByCachePolicyIdRequest$ = void 0;
exports.PublishFunctionRequest$ = exports.PublishConnectionFunctionResult$ = exports.PublishConnectionFunctionRequest$ = exports.PublicKeySummary$ = exports.PublicKeyList$ = exports.PublicKeyConfig$ = exports.PublicKey$ = exports.Paths$ = exports.ParametersInCacheKeyAndForwardedToOrigin$ = exports.ParameterDefinitionSchema$ = exports.ParameterDefinition$ = exports.Parameter$ = exports.OriginSslProtocols$ = exports.OriginShield$ = exports.Origins$ = exports.OriginRequestPolicySummary$ = exports.OriginRequestPolicyQueryStringsConfig$ = exports.OriginRequestPolicyList$ = exports.OriginRequestPolicyHeadersConfig$ = exports.OriginRequestPolicyCookiesConfig$ = exports.OriginRequestPolicyConfig$ = exports.OriginRequestPolicy$ = exports.OriginMtlsConfig$ = exports.OriginGroups$ = exports.OriginGroupMembers$ = exports.OriginGroupMember$ = exports.OriginGroupFailoverCriteria$ = exports.OriginGroup$ = exports.OriginCustomHeader$ = exports.OriginAccessControlSummary$ = exports.OriginAccessControlList$ = exports.OriginAccessControlConfig$ = exports.OriginAccessControl$ = exports.Origin$ = exports.MonitoringSubscription$ = exports.ManagedCertificateRequest$ = exports.ManagedCertificateDetails$ = exports.LoggingConfig$ = exports.ListVpcOriginsResult$ = exports.ListVpcOriginsRequest$ = exports.ListTrustStoresResult$ = exports.ListTrustStoresRequest$ = exports.ListTagsForResourceResult$ = exports.ListTagsForResourceRequest$ = exports.ListStreamingDistributionsResult$ = exports.ListStreamingDistributionsRequest$ = exports.ListResponseHeadersPoliciesResult$ = exports.ListResponseHeadersPoliciesRequest$ = exports.ListRealtimeLogConfigsResult$ = exports.ListRealtimeLogConfigsRequest$ = void 0;
exports.Tags$ = exports.TagResourceRequest$ = exports.TagKeys$ = exports.Tag$ = exports.StringSchemaConfig$ = exports.StreamingLoggingConfig$ = exports.StreamingDistributionSummary$ = exports.StreamingDistributionList$ = exports.StreamingDistributionConfigWithTags$ = exports.StreamingDistributionConfig$ = exports.StreamingDistribution$ = exports.StatusCodes$ = exports.StagingDistributionDnsNames$ = exports.Signer$ = exports.SessionStickinessConfig$ = exports.S3OriginConfig$ = exports.S3Origin$ = exports.Restrictions$ = exports.ResponseHeadersPolicyXSSProtection$ = exports.ResponseHeadersPolicySummary$ = exports.ResponseHeadersPolicyStrictTransportSecurity$ = exports.ResponseHeadersPolicyServerTimingHeadersConfig$ = exports.ResponseHeadersPolicySecurityHeadersConfig$ = exports.ResponseHeadersPolicyRemoveHeadersConfig$ = exports.ResponseHeadersPolicyRemoveHeader$ = exports.ResponseHeadersPolicyReferrerPolicy$ = exports.ResponseHeadersPolicyList$ = exports.ResponseHeadersPolicyFrameOptions$ = exports.ResponseHeadersPolicyCustomHeadersConfig$ = exports.ResponseHeadersPolicyCustomHeader$ = exports.ResponseHeadersPolicyCorsConfig$ = exports.ResponseHeadersPolicyContentTypeOptions$ = exports.ResponseHeadersPolicyContentSecurityPolicy$ = exports.ResponseHeadersPolicyConfig$ = exports.ResponseHeadersPolicyAccessControlExposeHeaders$ = exports.ResponseHeadersPolicyAccessControlAllowOrigins$ = exports.ResponseHeadersPolicyAccessControlAllowMethods$ = exports.ResponseHeadersPolicyAccessControlAllowHeaders$ = exports.ResponseHeadersPolicy$ = exports.RealtimeMetricsSubscriptionConfig$ = exports.RealtimeLogConfigs$ = exports.RealtimeLogConfig$ = exports.QueryStringNames$ = exports.QueryStringCacheKeys$ = exports.QueryArgProfiles$ = exports.QueryArgProfileConfig$ = exports.QueryArgProfile$ = exports.PutResourcePolicyResult$ = exports.PutResourcePolicyRequest$ = exports.PublishFunctionResult$ = void 0;
exports.UpdateRealtimeLogConfigRequest$ = exports.UpdatePublicKeyResult$ = exports.UpdatePublicKeyRequest$ = exports.UpdateOriginRequestPolicyResult$ = exports.UpdateOriginRequestPolicyRequest$ = exports.UpdateOriginAccessControlResult$ = exports.UpdateOriginAccessControlRequest$ = exports.UpdateKeyValueStoreResult$ = exports.UpdateKeyValueStoreRequest$ = exports.UpdateKeyGroupResult$ = exports.UpdateKeyGroupRequest$ = exports.UpdateFunctionResult$ = exports.UpdateFunctionRequest$ = exports.UpdateFieldLevelEncryptionProfileResult$ = exports.UpdateFieldLevelEncryptionProfileRequest$ = exports.UpdateFieldLevelEncryptionConfigResult$ = exports.UpdateFieldLevelEncryptionConfigRequest$ = exports.UpdateDomainAssociationResult$ = exports.UpdateDomainAssociationRequest$ = exports.UpdateDistributionWithStagingConfigResult$ = exports.UpdateDistributionWithStagingConfigRequest$ = exports.UpdateDistributionTenantResult$ = exports.UpdateDistributionTenantRequest$ = exports.UpdateDistributionResult$ = exports.UpdateDistributionRequest$ = exports.UpdateContinuousDeploymentPolicyResult$ = exports.UpdateContinuousDeploymentPolicyRequest$ = exports.UpdateConnectionGroupResult$ = exports.UpdateConnectionGroupRequest$ = exports.UpdateConnectionFunctionResult$ = exports.UpdateConnectionFunctionRequest$ = exports.UpdateCloudFrontOriginAccessIdentityResult$ = exports.UpdateCloudFrontOriginAccessIdentityRequest$ = exports.UpdateCachePolicyResult$ = exports.UpdateCachePolicyRequest$ = exports.UpdateAnycastIpListResult$ = exports.UpdateAnycastIpListRequest$ = exports.UntagResourceRequest$ = exports.TrustStoreSummary$ = exports.TrustStoreConfig$ = exports.TrustStore$ = exports.TrustedSigners$ = exports.TrustedKeyGroups$ = exports.TrafficConfig$ = exports.TestResult$ = exports.TestFunctionResult$ = exports.TestFunctionRequest$ = exports.TestConnectionFunctionResult$ = exports.TestConnectionFunctionRequest$ = exports.TenantConfig$ = void 0;
exports.CreateTrustStore$ = exports.CreateStreamingDistributionWithTags$ = exports.CreateStreamingDistribution$ = exports.CreateResponseHeadersPolicy$ = exports.CreateRealtimeLogConfig$ = exports.CreatePublicKey$ = exports.CreateOriginRequestPolicy$ = exports.CreateOriginAccessControl$ = exports.CreateMonitoringSubscription$ = exports.CreateKeyValueStore$ = exports.CreateKeyGroup$ = exports.CreateInvalidationForDistributionTenant$ = exports.CreateInvalidation$ = exports.CreateFunction$ = exports.CreateFieldLevelEncryptionProfile$ = exports.CreateFieldLevelEncryptionConfig$ = exports.CreateDistributionWithTags$ = exports.CreateDistributionTenant$ = exports.CreateDistribution$ = exports.CreateContinuousDeploymentPolicy$ = exports.CreateConnectionGroup$ = exports.CreateConnectionFunction$ = exports.CreateCloudFrontOriginAccessIdentity$ = exports.CreateCachePolicy$ = exports.CreateAnycastIpList$ = exports.CopyDistribution$ = exports.AssociateDistributionWebACL$ = exports.AssociateDistributionTenantWebACL$ = exports.AssociateAlias$ = exports.CaCertificatesBundleSource$ = exports.WebAclCustomization$ = exports.VpcOriginSummary$ = exports.VpcOriginList$ = exports.VpcOriginEndpointConfig$ = exports.VpcOriginConfig$ = exports.VpcOrigin$ = exports.ViewerMtlsConfig$ = exports.ViewerCertificate$ = exports.VerifyDnsConfigurationResult$ = exports.VerifyDnsConfigurationRequest$ = exports.ValidationTokenDetail$ = exports.UpdateVpcOriginResult$ = exports.UpdateVpcOriginRequest$ = exports.UpdateTrustStoreResult$ = exports.UpdateTrustStoreRequest$ = exports.UpdateStreamingDistributionResult$ = exports.UpdateStreamingDistributionRequest$ = exports.UpdateResponseHeadersPolicyResult$ = exports.UpdateResponseHeadersPolicyRequest$ = exports.UpdateRealtimeLogConfigResult$ = void 0;
exports.GetInvalidationForDistributionTenant$ = exports.GetInvalidation$ = exports.GetFunction$ = exports.GetFieldLevelEncryptionProfileConfig$ = exports.GetFieldLevelEncryptionProfile$ = exports.GetFieldLevelEncryptionConfig$ = exports.GetFieldLevelEncryption$ = exports.GetDistributionTenantByDomain$ = exports.GetDistributionTenant$ = exports.GetDistributionConfig$ = exports.GetDistribution$ = exports.GetContinuousDeploymentPolicyConfig$ = exports.GetContinuousDeploymentPolicy$ = exports.GetConnectionGroupByRoutingEndpoint$ = exports.GetConnectionGroup$ = exports.GetConnectionFunction$ = exports.GetCloudFrontOriginAccessIdentityConfig$ = exports.GetCloudFrontOriginAccessIdentity$ = exports.GetCachePolicyConfig$ = exports.GetCachePolicy$ = exports.GetAnycastIpList$ = exports.DisassociateDistributionWebACL$ = exports.DisassociateDistributionTenantWebACL$ = exports.DescribeKeyValueStore$ = exports.DescribeFunction$ = exports.DescribeConnectionFunction$ = exports.DeleteVpcOrigin$ = exports.DeleteTrustStore$ = exports.DeleteStreamingDistribution$ = exports.DeleteResponseHeadersPolicy$ = exports.DeleteResourcePolicy$ = exports.DeleteRealtimeLogConfig$ = exports.DeletePublicKey$ = exports.DeleteOriginRequestPolicy$ = exports.DeleteOriginAccessControl$ = exports.DeleteMonitoringSubscription$ = exports.DeleteKeyValueStore$ = exports.DeleteKeyGroup$ = exports.DeleteFunction$ = exports.DeleteFieldLevelEncryptionProfile$ = exports.DeleteFieldLevelEncryptionConfig$ = exports.DeleteDistributionTenant$ = exports.DeleteDistribution$ = exports.DeleteContinuousDeploymentPolicy$ = exports.DeleteConnectionGroup$ = exports.DeleteConnectionFunction$ = exports.DeleteCloudFrontOriginAccessIdentity$ = exports.DeleteCachePolicy$ = exports.DeleteAnycastIpList$ = exports.CreateVpcOrigin$ = void 0;
exports.ListOriginRequestPolicies$ = exports.ListOriginAccessControls$ = exports.ListKeyValueStores$ = exports.ListKeyGroups$ = exports.ListInvalidationsForDistributionTenant$ = exports.ListInvalidations$ = exports.ListFunctions$ = exports.ListFieldLevelEncryptionProfiles$ = exports.ListFieldLevelEncryptionConfigs$ = exports.ListDomainConflicts$ = exports.ListDistributionTenantsByCustomization$ = exports.ListDistributionTenants$ = exports.ListDistributionsByWebACLId$ = exports.ListDistributionsByVpcOriginId$ = exports.ListDistributionsByTrustStore$ = exports.ListDistributionsByResponseHeadersPolicyId$ = exports.ListDistributionsByRealtimeLogConfig$ = exports.ListDistributionsByOwnedResource$ = exports.ListDistributionsByOriginRequestPolicyId$ = exports.ListDistributionsByKeyGroup$ = exports.ListDistributionsByConnectionMode$ = exports.ListDistributionsByConnectionFunction$ = exports.ListDistributionsByCachePolicyId$ = exports.ListDistributionsByAnycastIpListId$ = exports.ListDistributions$ = exports.ListContinuousDeploymentPolicies$ = exports.ListConnectionGroups$ = exports.ListConnectionFunctions$ = exports.ListConflictingAliases$ = exports.ListCloudFrontOriginAccessIdentities$ = exports.ListCachePolicies$ = exports.ListAnycastIpLists$ = exports.GetVpcOrigin$ = exports.GetTrustStore$ = exports.GetStreamingDistributionConfig$ = exports.GetStreamingDistribution$ = exports.GetResponseHeadersPolicyConfig$ = exports.GetResponseHeadersPolicy$ = exports.GetResourcePolicy$ = exports.GetRealtimeLogConfig$ = exports.GetPublicKeyConfig$ = exports.GetPublicKey$ = exports.GetOriginRequestPolicyConfig$ = exports.GetOriginRequestPolicy$ = exports.GetOriginAccessControlConfig$ = exports.GetOriginAccessControl$ = exports.GetMonitoringSubscription$ = exports.GetManagedCertificateDetails$ = exports.GetKeyGroupConfig$ = exports.GetKeyGroup$ = void 0;
exports.VerifyDnsConfiguration$ = exports.UpdateVpcOrigin$ = exports.UpdateTrustStore$ = exports.UpdateStreamingDistribution$ = exports.UpdateResponseHeadersPolicy$ = exports.UpdateRealtimeLogConfig$ = exports.UpdatePublicKey$ = exports.UpdateOriginRequestPolicy$ = exports.UpdateOriginAccessControl$ = exports.UpdateKeyValueStore$ = exports.UpdateKeyGroup$ = exports.UpdateFunction$ = exports.UpdateFieldLevelEncryptionProfile$ = exports.UpdateFieldLevelEncryptionConfig$ = exports.UpdateDomainAssociation$ = exports.UpdateDistributionWithStagingConfig$ = exports.UpdateDistributionTenant$ = exports.UpdateDistribution$ = exports.UpdateContinuousDeploymentPolicy$ = exports.UpdateConnectionGroup$ = exports.UpdateConnectionFunction$ = exports.UpdateCloudFrontOriginAccessIdentity$ = exports.UpdateCachePolicy$ = exports.UpdateAnycastIpList$ = exports.UntagResource$ = exports.TestFunction$ = exports.TestConnectionFunction$ = exports.TagResource$ = exports.PutResourcePolicy$ = exports.PublishFunction$ = exports.PublishConnectionFunction$ = exports.ListVpcOrigins$ = exports.ListTrustStores$ = exports.ListTagsForResource$ = exports.ListStreamingDistributions$ = exports.ListResponseHeadersPolicies$ = exports.ListRealtimeLogConfigs$ = exports.ListPublicKeys$ = void 0;
const _A = "Aliases";
const _AA = "AssociateAlias";
const _AAN = "AwsAccountNumber";
const _AANL = "AwsAccountNumberList";
const _AAR = "AssociateAliasRequest";
const _ACAC = "AccessControlAllowCredentials";
const _ACAH = "AccessControlAllowHeaders";
const _ACAHL = "AccessControlAllowHeadersList";
const _ACAM = "AccessControlAllowMethods";
const _ACAML = "AccessControlAllowMethodsList";
const _ACAO = "AccessControlAllowOrigins";
const _ACAOL = "AccessControlAllowOriginsList";
const _ACEH = "AccessControlExposeHeaders";
const _ACEHL = "AccessControlExposeHeadersList";
const _ACMAS = "AccessControlMaxAgeSec";
const _ACMCA = "ACMCertificateArn";
const _AD = "AccessDenied";
const _ADTWACL = "AssociateDistributionTenantWebACL";
const _ADTWACLR = "AssociateDistributionTenantWebACLRequest";
const _ADTWACLRs = "AssociateDistributionTenantWebACLResult";
const _ADWACL = "AssociateDistributionWebACL";
const _ADWACLR = "AssociateDistributionWebACLRequest";
const _ADWACLRs = "AssociateDistributionWebACLResult";
const _AF = "AssociationFilter";
const _AI = "AnycastIps";
const _AICPR = "AliasICPRecordal";
const _AICPRl = "AliasICPRecordals";
const _AIL = "AnycastIpList";
const _AILC = "AnycastIpListCollection";
const _AILI = "AnycastIpListId";
const _AILS = "AnycastIpListSummary";
const _AILSn = "AnycastIpListSummaries";
const _AILn = "AnycastIpLists";
const _AIc = "AccountId";
const _AIn = "AnycastIp";
const _AL = "AliasList";
const _AM = "AllowedMethods";
const _ARN = "ARN";
const _ATKG = "ActiveTrustedKeyGroups";
const _ATS = "ActiveTrustedSigners";
const _ATSCN = "AdvertiseTrustStoreCaNames";
const _Ac = "Action";
const _Al = "Alias";
const _Ar = "Arn";
const _B = "Bucket";
const _BTL = "BatchTooLarge";
const _C = "Compress";
const _CA = "ConflictingAlias";
const _CAIL = "CreateAnycastIpList";
const _CAILR = "CreateAnycastIpListRequest";
const _CAILRr = "CreateAnycastIpListResult";
const _CAL = "ConflictingAliasesList";
const _CAe = "CertificateArn";
const _CAo = "ConnectionAttempts";
const _CAon = "ConflictingAliases";
const _CB = "CacheBehavior";
const _CBL = "CacheBehaviorList";
const _CBa = "CacheBehaviors";
const _CBo = "CookieBehavior";
const _CC = "CookiesConfig";
const _CCA = "ClientCertificateArn";
const _CCBS = "CaCertificatesBundleSource";
const _CCBSL = "CaCertificatesBundleS3Location";
const _CCDP = "CreateContinuousDeploymentPolicy";
const _CCDPR = "CreateContinuousDeploymentPolicyRequest";
const _CCDPRr = "CreateContinuousDeploymentPolicyResult";
const _CCF = "CreateConnectionFunction";
const _CCFOAI = "CreateCloudFrontOriginAccessIdentity";
const _CCFOAIR = "CreateCloudFrontOriginAccessIdentityRequest";
const _CCFOAIRr = "CreateCloudFrontOriginAccessIdentityResult";
const _CCFR = "CreateConnectionFunctionRequest";
const _CCFRr = "CreateConnectionFunctionResult";
const _CCG = "CreateConnectionGroup";
const _CCGR = "CreateConnectionGroupRequest";
const _CCGRr = "CreateConnectionGroupResult";
const _CCIPKF = "CannotChangeImmutablePublicKeyFields";
const _CCP = "CreateCachePolicy";
const _CCPR = "CreateCachePolicyRequest";
const _CCPRr = "CreateCachePolicyResult";
const _CCo = "CorsConfig";
const _CD = "CopyDistribution";
const _CDEWIU = "CannotDeleteEntityWhileInUse";
const _CDP = "ContinuousDeploymentPolicy";
const _CDPAE = "ContinuousDeploymentPolicyAlreadyExists";
const _CDPC = "ContinuousDeploymentPolicyConfig";
const _CDPI = "ContinuousDeploymentPolicyId";
const _CDPIU = "ContinuousDeploymentPolicyInUse";
const _CDPL = "ContinuousDeploymentPolicyList";
const _CDPS = "ContinuousDeploymentPolicySummary";
const _CDPSL = "ContinuousDeploymentPolicySummaryList";
const _CDR = "CopyDistributionRequest";
const _CDRo = "CopyDistributionResult";
const _CDRr = "CreateDistributionRequest";
const _CDRre = "CreateDistributionResult";
const _CDSHC = "ContinuousDeploymentSingleHeaderConfig";
const _CDSWC = "ContinuousDeploymentSingleWeightConfig";
const _CDT = "CreateDistributionTenant";
const _CDTR = "CreateDistributionTenantRequest";
const _CDTRr = "CreateDistributionTenantResult";
const _CDWT = "CreateDistributionWithTags";
const _CDWTR = "CreateDistributionWithTagsRequest";
const _CDWTRr = "CreateDistributionWithTagsResult";
const _CDr = "CreateDistribution";
const _CER = "CustomErrorResponse";
const _CERL = "CustomErrorResponseList";
const _CERu = "CustomErrorResponses";
const _CF = "ConnectionFunctions";
const _CFA = "ConnectionFunctionAssociation";
const _CFAo = "ConnectionFunctionArn";
const _CFC = "ConnectionFunctionConfig";
const _CFCo = "ConnectionFunctionCode";
const _CFDC = "CloudFrontDefaultCertificate";
const _CFEL = "ConnectionFunctionExecutionLogs";
const _CFEM = "ConnectionFunctionErrorMessage";
const _CFI = "ConnectionFunctionIdentifier";
const _CFLEC = "CreateFieldLevelEncryptionConfig";
const _CFLECR = "CreateFieldLevelEncryptionConfigRequest";
const _CFLECRr = "CreateFieldLevelEncryptionConfigResult";
const _CFLEP = "CreateFieldLevelEncryptionProfile";
const _CFLEPR = "CreateFieldLevelEncryptionProfileRequest";
const _CFLEPRr = "CreateFieldLevelEncryptionProfileResult";
const _CFO = "ConnectionFunctionOutput";
const _CFOAI = "CloudFrontOriginAccessIdentity";
const _CFOAIAE = "CloudFrontOriginAccessIdentityAlreadyExists";
const _CFOAIC = "CloudFrontOriginAccessIdentityConfig";
const _CFOAIIU = "CloudFrontOriginAccessIdentityInUse";
const _CFOAIL = "CloudFrontOriginAccessIdentityList";
const _CFOAIS = "CloudFrontOriginAccessIdentitySummary";
const _CFOAISL = "CloudFrontOriginAccessIdentitySummaryList";
const _CFR = "CreateFunctionRequest";
const _CFRr = "CreateFunctionResult";
const _CFS = "ConnectionFunctionSummary";
const _CFSL = "ConnectionFunctionSummaryList";
const _CFTR = "ConnectionFunctionTestResult";
const _CFr = "CreateFunction";
const _CG = "ConnectionGroup";
const _CGAF = "ConnectionGroupAssociationFilter";
const _CGI = "ConnectionGroupId";
const _CGS = "ConnectionGroupSummary";
const _CGSL = "ConnectionGroupSummaryList";
const _CGo = "ConnectionGroups";
const _CH = "CustomHeaders";
const _CHC = "CustomHeadersConfig";
const _CI = "CreateInvalidation";
const _CIFDT = "CreateInvalidationForDistributionTenant";
const _CIFDTR = "CreateInvalidationForDistributionTenantRequest";
const _CIFDTRr = "CreateInvalidationForDistributionTenantResult";
const _CIR = "CreateInvalidationRequest";
const _CIRr = "CreateInvalidationResult";
const _CKG = "CreateKeyGroup";
const _CKGR = "CreateKeyGroupRequest";
const _CKGRr = "CreateKeyGroupResult";
const _CKVS = "CreateKeyValueStore";
const _CKVSR = "CreateKeyValueStoreRequest";
const _CKVSRr = "CreateKeyValueStoreResult";
const _CM = "CachedMethods";
const _CMS = "CreateMonitoringSubscription";
const _CMSR = "CreateMonitoringSubscriptionRequest";
const _CMSRr = "CreateMonitoringSubscriptionResult";
const _CMo = "ConnectionMode";
const _CN = "CookieNames";
const _CNAME = "CNAME";
const _CNAMEAE = "CNAMEAlreadyExists";
const _CNL = "CookieNameList";
const _CO = "ConnectionObject";
const _COAC = "CreateOriginAccessControl";
const _COACR = "CreateOriginAccessControlRequest";
const _COACRr = "CreateOriginAccessControlResult";
const _COC = "CustomOriginConfig";
const _CORP = "CreateOriginRequestPolicy";
const _CORPR = "CreateOriginRequestPolicyRequest";
const _CORPRr = "CreateOriginRequestPolicyResult";
const _CP = "CachePolicy";
const _CPAE = "CachePolicyAlreadyExists";
const _CPC = "CachePolicyConfig";
const _CPCC = "CachePolicyCookiesConfig";
const _CPHC = "CachePolicyHeadersConfig";
const _CPI = "CachePolicyId";
const _CPIU = "CachePolicyInUse";
const _CPK = "CreatePublicKey";
const _CPKR = "CreatePublicKeyRequest";
const _CPKRr = "CreatePublicKeyResult";
const _CPL = "CachePolicyList";
const _CPQSC = "CachePolicyQueryStringsConfig";
const _CPS = "CachePolicySummary";
const _CPSL = "CachePolicySummaryList";
const _CPo = "CookiePreference";
const _CR = "CallerReference";
const _CRHP = "CreateResponseHeadersPolicy";
const _CRHPR = "CreateResponseHeadersPolicyRequest";
const _CRHPRr = "CreateResponseHeadersPolicyResult";
const _CRLC = "CreateRealtimeLogConfig";
const _CRLCR = "CreateRealtimeLogConfigRequest";
const _CRLCRr = "CreateRealtimeLogConfigResult";
const _CS = "CertificateStatus";
const _CSD = "CreateStreamingDistribution";
const _CSDR = "CreateStreamingDistributionRequest";
const _CSDRr = "CreateStreamingDistributionResult";
const _CSDWT = "CreateStreamingDistributionWithTags";
const _CSDWTR = "CreateStreamingDistributionWithTagsRequest";
const _CSDWTRr = "CreateStreamingDistributionWithTagsResult";
const _CSP = "ContentSecurityPolicy";
const _CSe = "CertificateSource";
const _CT = "CommentType";
const _CTLP = "CertificateTransparencyLoggingPreference";
const _CTO = "ContentTypeOptions";
const _CTP = "ContentTypeProfile";
const _CTPC = "ContentTypeProfileConfig";
const _CTPL = "ContentTypeProfileList";
const _CTPo = "ContentTypeProfiles";
const _CTS = "CreateTrustStore";
const _CTSR = "CreateTrustStoreRequest";
const _CTSRr = "CreateTrustStoreResult";
const _CT_ = "Content-Type";
const _CTo = "ContentType";
const _CTon = "ConnectionTimeout";
const _CTr = "CreatedTime";
const _CTre = "CreateTime";
const _CU = "ComputeUtilization";
const _CUEWIU = "CannotUpdateEntityWhileInUse";
const _CVO = "CreateVpcOrigin";
const _CVOR = "CreateVpcOriginRequest";
const _CVORr = "CreateVpcOriginResult";
const _Ce = "Certificate";
const _Ci = "Cidr";
const _Co = "Comment";
const _Coo = "Cookies";
const _Cu = "Customizations";
const _D = "Distribution";
const _DAE = "DistributionAlreadyExists";
const _DAIL = "DeleteAnycastIpList";
const _DAILR = "DeleteAnycastIpListRequest";
const _DC = "DistributionConfig";
const _DCB = "DefaultCacheBehavior";
const _DCDP = "DeleteContinuousDeploymentPolicy";
const _DCDPR = "DeleteContinuousDeploymentPolicyRequest";
const _DCF = "DeleteConnectionFunction";
const _DCFOAI = "DeleteCloudFrontOriginAccessIdentity";
const _DCFOAIR = "DeleteCloudFrontOriginAccessIdentityRequest";
const _DCFR = "DeleteConnectionFunctionRequest";
const _DCFRe = "DescribeConnectionFunctionRequest";
const _DCFRes = "DescribeConnectionFunctionResult";
const _DCFe = "DescribeConnectionFunction";
const _DCG = "DeleteConnectionGroup";
const _DCGR = "DeleteConnectionGroupRequest";
const _DCL = "DnsConfigurationList";
const _DCLo = "DomainConflictsList";
const _DCP = "DeleteCachePolicy";
const _DCPR = "DeleteCachePolicyRequest";
const _DCVR = "DomainControlValidationResource";
const _DCWT = "DistributionConfigWithTags";
const _DCn = "DnsConfiguration";
const _DCo = "DomainConflict";
const _DCom = "DomainConflicts";
const _DD = "DeleteDistribution";
const _DDR = "DeleteDistributionRequest";
const _DDT = "DeleteDistributionTenant";
const _DDTR = "DeleteDistributionTenantRequest";
const _DDTWACL = "DisassociateDistributionTenantWebACL";
const _DDTWACLR = "DisassociateDistributionTenantWebACLRequest";
const _DDTWACLRi = "DisassociateDistributionTenantWebACLResult";
const _DDWACL = "DisassociateDistributionWebACL";
const _DDWACLR = "DisassociateDistributionWebACLRequest";
const _DDWACLRi = "DisassociateDistributionWebACLResult";
const _DF = "DeleteFunction";
const _DFLEC = "DeleteFieldLevelEncryptionConfig";
const _DFLECR = "DeleteFieldLevelEncryptionConfigRequest";
const _DFLEP = "DeleteFieldLevelEncryptionProfile";
const _DFLEPR = "DeleteFieldLevelEncryptionProfileRequest";
const _DFR = "DeleteFunctionRequest";
const _DFRe = "DescribeFunctionRequest";
const _DFRes = "DescribeFunctionResult";
const _DFe = "DescribeFunction";
const _DI = "DistributionId";
const _DIL = "DistributionIdList";
const _DILS = "DistributionIdListSummary";
const _DIO = "DistributionIdOwner";
const _DIOIL = "DistributionIdOwnerItemList";
const _DIOL = "DistributionIdOwnerList";
const _DIo = "DomainItem";
const _DKG = "DeleteKeyGroup";
const _DKGR = "DeleteKeyGroupRequest";
const _DKVS = "DeleteKeyValueStore";
const _DKVSR = "DeleteKeyValueStoreRequest";
const _DKVSRe = "DescribeKeyValueStoreRequest";
const _DKVSRes = "DescribeKeyValueStoreResult";
const _DKVSe = "DescribeKeyValueStore";
const _DL = "DistributionList";
const _DLo = "DomainList";
const _DMS = "DeleteMonitoringSubscription";
const _DMSR = "DeleteMonitoringSubscriptionRequest";
const _DMSRe = "DeleteMonitoringSubscriptionResult";
const _DN = "DomainName";
const _DND = "DistributionNotDisabled";
const _DNn = "DnsName";
const _DOAC = "DeleteOriginAccessControl";
const _DOACR = "DeleteOriginAccessControlRequest";
const _DORP = "DeleteOriginRequestPolicy";
const _DORPR = "DeleteOriginRequestPolicyRequest";
const _DPK = "DeletePublicKey";
const _DPKR = "DeletePublicKeyRequest";
const _DR = "DomainResult";
const _DRHP = "DeleteResponseHeadersPolicy";
const _DRHPR = "DeleteResponseHeadersPolicyRequest";
const _DRI = "DistributionResourceId";
const _DRL = "DomainResultList";
const _DRLC = "DeleteRealtimeLogConfig";
const _DRLCR = "DeleteRealtimeLogConfigRequest";
const _DRO = "DefaultRootObject";
const _DRP = "DeleteResourcePolicy";
const _DRPR = "DeleteResourcePolicyRequest";
const _DS = "DistributionSummary";
const _DSD = "DeleteStreamingDistribution";
const _DSDR = "DeleteStreamingDistributionRequest";
const _DSL = "DistributionSummaryList";
const _DT = "DistributionTenant";
const _DTAF = "DistributionTenantAssociationFilter";
const _DTI = "DistributionTenantId";
const _DTL = "DistributionTenantList";
const _DTS = "DistributionTenantSummary";
const _DTSR = "DeleteTrustStoreRequest";
const _DTSe = "DeleteTrustStore";
const _DTTL = "DefaultTTL";
const _DV = "DefaultValue";
const _DVO = "DeleteVpcOrigin";
const _DVOR = "DeleteVpcOriginRequest";
const _DVORe = "DeleteVpcOriginResult";
const _De = "Description";
const _Def = "Definition";
const _Do = "Domains";
const _Dom = "Domain";
const _E = "Enabled";
const _EAE = "EntityAlreadyExists";
const _EAEB = "EnableAcceptEncodingBrotli";
const _EAEG = "EnableAcceptEncodingGzip";
const _EC = "ErrorCode";
const _ECMTTL = "ErrorCachingMinTTL";
const _EE = "EncryptionEntities";
const _EEL = "EncryptionEntityList";
const _EEn = "EncryptionEntity";
const _EK = "EncodedKey";
const _ELE = "EntityLimitExceeded";
const _ENF = "EntityNotFound";
const _EO = "EventObject";
const _EP = "EndPoints";
const _EPL = "EndPointList";
const _EPn = "EndPoint";
const _ESLE = "EntitySizeLimitExceeded";
const _ET = "ETag";
const _ETt = "ETtag";
const _ETv = "EventType";
const _F = "Format";
const _FA = "FunctionAssociations";
const _FAE = "FunctionAlreadyExists";
const _FAL = "FunctionAssociationList";
const _FARN = "FunctionARN";
const _FAu = "FunctionAssociation";
const _FB = "FunctionBlob";
const _FC = "FunctionConfig";
const _FCa = "FailoverCriteria";
const _FCu = "FunctionCode";
const _FEL = "FunctionExecutionLogs";
const _FELL = "FunctionExecutionLogList";
const _FEM = "FunctionErrorMessage";
const _FEO = "FunctionEventObject";
const _FIU = "FunctionInUse";
const _FL = "FunctionList";
const _FLE = "FieldLevelEncryption";
const _FLEC = "FieldLevelEncryptionConfig";
const _FLECAE = "FieldLevelEncryptionConfigAlreadyExists";
const _FLECIU = "FieldLevelEncryptionConfigInUse";
const _FLEI = "FieldLevelEncryptionId";
const _FLEL = "FieldLevelEncryptionList";
const _FLEP = "FieldLevelEncryptionProfile";
const _FLEPAE = "FieldLevelEncryptionProfileAlreadyExists";
const _FLEPC = "FieldLevelEncryptionProfileConfig";
const _FLEPIU = "FieldLevelEncryptionProfileInUse";
const _FLEPL = "FieldLevelEncryptionProfileList";
const _FLEPS = "FieldLevelEncryptionProfileSummary";
const _FLEPSE = "FieldLevelEncryptionProfileSizeExceeded";
const _FLEPSL = "FieldLevelEncryptionProfileSummaryList";
const _FLES = "FieldLevelEncryptionSummary";
const _FLESL = "FieldLevelEncryptionSummaryList";
const _FLi = "FieldList";
const _FM = "FunctionMetadata";
const _FO = "FrameOption";
const _FOr = "FrameOptions";
const _FOu = "FunctionOutput";
const _FP = "FieldPatterns";
const _FPL = "FieldPatternList";
const _FPi = "FieldPattern";
const _FS = "FunctionSummary";
const _FSL = "FunctionSummaryList";
const _FSLE = "FunctionSizeLimitExceeded";
const _FV = "ForwardedValues";
const _FWCTIU = "ForwardWhenContentTypeIsUnknown";
const _FWQAPIU = "ForwardWhenQueryArgProfileIsUnknown";
const _Fi = "Fields";
const _Fie = "Field";
const _Fo = "Forward";
const _GAIL = "GetAnycastIpList";
const _GAILR = "GetAnycastIpListRequest";
const _GAILRe = "GetAnycastIpListResult";
const _GC = "GrpcConfig";
const _GCDP = "GetContinuousDeploymentPolicy";
const _GCDPC = "GetContinuousDeploymentPolicyConfig";
const _GCDPCR = "GetContinuousDeploymentPolicyConfigRequest";
const _GCDPCRe = "GetContinuousDeploymentPolicyConfigResult";
const _GCDPR = "GetContinuousDeploymentPolicyRequest";
const _GCDPRe = "GetContinuousDeploymentPolicyResult";
const _GCF = "GetConnectionFunction";
const _GCFOAI = "GetCloudFrontOriginAccessIdentity";
const _GCFOAIC = "GetCloudFrontOriginAccessIdentityConfig";
const _GCFOAICR = "GetCloudFrontOriginAccessIdentityConfigRequest";
const _GCFOAICRe = "GetCloudFrontOriginAccessIdentityConfigResult";
const _GCFOAIR = "GetCloudFrontOriginAccessIdentityRequest";
const _GCFOAIRe = "GetCloudFrontOriginAccessIdentityResult";
const _GCFR = "GetConnectionFunctionRequest";
const _GCFRe = "GetConnectionFunctionResult";
const _GCG = "GetConnectionGroup";
const _GCGBRE = "GetConnectionGroupByRoutingEndpoint";
const _GCGBRER = "GetConnectionGroupByRoutingEndpointRequest";
const _GCGBRERe = "GetConnectionGroupByRoutingEndpointResult";
const _GCGR = "GetConnectionGroupRequest";
const _GCGRe = "GetConnectionGroupResult";
const _GCP = "GetCachePolicy";
const _GCPC = "GetCachePolicyConfig";
const _GCPCR = "GetCachePolicyConfigRequest";
const _GCPCRe = "GetCachePolicyConfigResult";
const _GCPR = "GetCachePolicyRequest";
const _GCPRe = "GetCachePolicyResult";
const _GD = "GetDistribution";
const _GDC = "GetDistributionConfig";
const _GDCR = "GetDistributionConfigRequest";
const _GDCRe = "GetDistributionConfigResult";
const _GDR = "GetDistributionRequest";
const _GDRe = "GetDistributionResult";
const _GDT = "GetDistributionTenant";
const _GDTBD = "GetDistributionTenantByDomain";
const _GDTBDR = "GetDistributionTenantByDomainRequest";
const _GDTBDRe = "GetDistributionTenantByDomainResult";
const _GDTR = "GetDistributionTenantRequest";
const _GDTRe = "GetDistributionTenantResult";
const _GF = "GetFunction";
const _GFLE = "GetFieldLevelEncryption";
const _GFLEC = "GetFieldLevelEncryptionConfig";
const _GFLECR = "GetFieldLevelEncryptionConfigRequest";
const _GFLECRe = "GetFieldLevelEncryptionConfigResult";
const _GFLEP = "GetFieldLevelEncryptionProfile";
const _GFLEPC = "GetFieldLevelEncryptionProfileConfig";
const _GFLEPCR = "GetFieldLevelEncryptionProfileConfigRequest";
const _GFLEPCRe = "GetFieldLevelEncryptionProfileConfigResult";
const _GFLEPR = "GetFieldLevelEncryptionProfileRequest";
const _GFLEPRe = "GetFieldLevelEncryptionProfileResult";
const _GFLER = "GetFieldLevelEncryptionRequest";
const _GFLERe = "GetFieldLevelEncryptionResult";
const _GFR = "GetFunctionRequest";
const _GFRe = "GetFunctionResult";
const _GI = "GetInvalidation";
const _GIFDT = "GetInvalidationForDistributionTenant";
const _GIFDTR = "GetInvalidationForDistributionTenantRequest";
const _GIFDTRe = "GetInvalidationForDistributionTenantResult";
const _GIR = "GetInvalidationRequest";
const _GIRe = "GetInvalidationResult";
const _GKG = "GetKeyGroup";
const _GKGC = "GetKeyGroupConfig";
const _GKGCR = "GetKeyGroupConfigRequest";
const _GKGCRe = "GetKeyGroupConfigResult";
const _GKGR = "GetKeyGroupRequest";
const _GKGRe = "GetKeyGroupResult";
const _GMCD = "GetManagedCertificateDetails";
const _GMCDR = "GetManagedCertificateDetailsRequest";
const _GMCDRe = "GetManagedCertificateDetailsResult";
const _GMS = "GetMonitoringSubscription";
const _GMSR = "GetMonitoringSubscriptionRequest";
const _GMSRe = "GetMonitoringSubscriptionResult";
const _GOAC = "GetOriginAccessControl";
const _GOACC = "GetOriginAccessControlConfig";
const _GOACCR = "GetOriginAccessControlConfigRequest";
const _GOACCRe = "GetOriginAccessControlConfigResult";
const _GOACR = "GetOriginAccessControlRequest";
const _GOACRe = "GetOriginAccessControlResult";
const _GORP = "GetOriginRequestPolicy";
const _GORPC = "GetOriginRequestPolicyConfig";
const _GORPCR = "GetOriginRequestPolicyConfigRequest";
const _GORPCRe = "GetOriginRequestPolicyConfigResult";
const _GORPR = "GetOriginRequestPolicyRequest";
const _GORPRe = "GetOriginRequestPolicyResult";
const _GPK = "GetPublicKey";
const _GPKC = "GetPublicKeyConfig";
const _GPKCR = "GetPublicKeyConfigRequest";
const _GPKCRe = "GetPublicKeyConfigResult";
const _GPKR = "GetPublicKeyRequest";
const _GPKRe = "GetPublicKeyResult";
const _GR = "GeoRestrictions";
const _GRC = "GeoRestrictionCustomization";
const _GRHP = "GetResponseHeadersPolicy";
const _GRHPC = "GetResponseHeadersPolicyConfig";
const _GRHPCR = "GetResponseHeadersPolicyConfigRequest";
const _GRHPCRe = "GetResponseHeadersPolicyConfigResult";
const _GRHPR = "GetResponseHeadersPolicyRequest";
const _GRHPRe = "GetResponseHeadersPolicyResult";
const _GRLC = "GetRealtimeLogConfig";
const _GRLCR = "GetRealtimeLogConfigRequest";
const _GRLCRe = "GetRealtimeLogConfigResult";
const _GRP = "GetResourcePolicy";
const _GRPR = "GetResourcePolicyRequest";
const _GRPRe = "GetResourcePolicyResult";
const _GRe = "GeoRestriction";
const _GSD = "GetStreamingDistribution";
const _GSDC = "GetStreamingDistributionConfig";
const _GSDCR = "GetStreamingDistributionConfigRequest";
const _GSDCRe = "GetStreamingDistributionConfigResult";
const _GSDR = "GetStreamingDistributionRequest";
const _GSDRe = "GetStreamingDistributionResult";
const _GTS = "GetTrustStore";
const _GTSR = "GetTrustStoreRequest";
const _GTSRe = "GetTrustStoreResult";
const _GVO = "GetVpcOrigin";
const _GVOR = "GetVpcOriginRequest";
const _GVORe = "GetVpcOriginResult";
const _H = "Headers";
const _HB = "HeaderBehavior";
const _HC = "HeadersConfig";
const _HL = "HeaderList";
const _HN = "HeaderName";
const _HTTPP = "HTTPPort";
const _HTTPSP = "HTTPSPort";
const _HV = "HttpVersion";
const _HVe = "HeaderValue";
const _He = "Header";
const _I = "Items";
const _IA = "InvalidArgument";
const _IAMCI = "IAMCertificateId";
const _IAT = "IpAddressType";
const _IAn = "InvalidAssociation";
const _IB = "InvalidationBatch";
const _IBn = "IncludeBody";
const _IC = "IpCount";
const _ICC = "IpamCidrConfigs";
const _ICCL = "IpamCidrConfigList";
const _ICCp = "IpamCidrConfig";
const _ICE = "IgnoreCertificateExpiry";
const _ICPRS = "ICPRecordalStatus";
const _ICn = "IncludeCookies";
const _ICp = "IpamConfig";
const _ID = "IllegalDelete";
const _IDNFOAC = "InvalidDomainNameForOriginAccessControl";
const _IDRO = "InvalidDefaultRootObject";
const _IDs = "IsDefault";
const _IE = "Ipv6Enabled";
const _IEC = "InvalidErrorCode";
const _IFA = "InvalidFunctionAssociation";
const _IFC = "InvalidForwardCookies";
const _IFLECAWCB = "IllegalFieldLevelEncryptionConfigAssociationWithCacheBehavior";
const _IGRP = "InvalidGeoRestrictionParameter";
const _IHFSO = "InvalidHeadersForS3Origin";
const _IIMV = "InvalidIfMatchVersion";
const _IIPVE = "IsIPV6Enabled";
const _IL = "InvalidationList";
const _ILC = "InvalidLocationCode";
const _ILFA = "InvalidLambdaFunctionAssociation";
const _IM = "IfMatch";
const _IMPV = "InvalidMinimumProtocolVersion";
const _IM_ = "If-Match";
const _IO = "InvalidOrigin";
const _IOAC = "IllegalOriginAccessConfiguration";
const _IOACn = "InvalidOriginAccessControl";
const _IOAI = "InvalidOriginAccessIdentity";
const _IOKT = "InvalidOriginKeepaliveTimeout";
const _IORT = "InvalidOriginReadTimeout";
const _IPA = "IpamPoolArn";
const _IPIB = "InProgressInvalidationBatches";
const _IPS = "InvalidProtocolSettings";
const _IQ = "InconsistentQuantities";
const _IQSP = "InvalidQueryStringParameters";
const _IRC = "InvalidResponseCode";
const _IRP = "InvalidRelativePath";
const _IRPn = "InvalidRequiredProtocol";
const _IS = "ImportSource";
const _ISL = "InvalidationSummaryList";
const _ISn = "InvalidationSummary";
const _ISnc = "IncludeSubdomains";
const _IT = "InvalidTagging";
const _ITTL = "IdleTTL";
const _ITTLO = "InvalidTTLOrder";
const _ITs = "IsTruncated";
const _IU = "IllegalUpdate";
const _IVC = "InvalidViewerCertificate";
const _IWACLI = "InvalidWebACLId";
const _Id = "Id";
const _Ide = "Identifier";
const _In = "Invalidation";
const _K = "Key";
const _KG = "KeyGroup";
const _KGAE = "KeyGroupAlreadyExists";
const _KGC = "KeyGroupConfig";
const _KGI = "KeyGroupId";
const _KGKPI = "KGKeyPairIds";
const _KGKPIL = "KGKeyPairIdsList";
const _KGL = "KeyGroupList";
const _KGS = "KeyGroupSummary";
const _KGSL = "KeyGroupSummaryList";
const _KPI = "KeyPairIds";
const _KPIL = "KeyPairIdList";
const _KPIe = "KeyPairId";
const _KSC = "KinesisStreamConfig";
const _KVS = "KeyValueStore";
const _KVSA = "KeyValueStoreAssociations";
const _KVSAL = "KeyValueStoreAssociationList";
const _KVSARN = "KeyValueStoreARN";
const _KVSAe = "KeyValueStoreAssociation";
const _KVSL = "KeyValueStoreList";
const _KVSSL = "KeyValueStoreSummaryList";
const _L = "Location";
const _LAIL = "ListAnycastIpLists";
const _LAILR = "ListAnycastIpListsRequest";
const _LAILRi = "ListAnycastIpListsResult";
const _LC = "LoggingConfig";
const _LCA = "ListConflictingAliases";
const _LCAR = "ListConflictingAliasesRequest";
const _LCARi = "ListConflictingAliasesResult";
const _LCDP = "ListContinuousDeploymentPolicies";
const _LCDPR = "ListContinuousDeploymentPoliciesRequest";
const _LCDPRi = "ListContinuousDeploymentPoliciesResult";
const _LCF = "ListConnectionFunctions";
const _LCFOAI = "ListCloudFrontOriginAccessIdentities";
const _LCFOAIR = "ListCloudFrontOriginAccessIdentitiesRequest";
const _LCFOAIRi = "ListCloudFrontOriginAccessIdentitiesResult";
const _LCFR = "ListConnectionFunctionsRequest";
const _LCFRi = "ListConnectionFunctionsResult";
const _LCG = "ListConnectionGroups";
const _LCGR = "ListConnectionGroupsRequest";
const _LCGRi = "ListConnectionGroupsResult";
const _LCP = "ListCachePolicies";
const _LCPR = "ListCachePoliciesRequest";
const _LCPRi = "ListCachePoliciesResult";
const _LD = "ListDistributions";
const _LDBAILI = "ListDistributionsByAnycastIpListId";
const _LDBAILIR = "ListDistributionsByAnycastIpListIdRequest";
const _LDBAILIRi = "ListDistributionsByAnycastIpListIdResult";
const _LDBCF = "ListDistributionsByConnectionFunction";
const _LDBCFR = "ListDistributionsByConnectionFunctionRequest";
const _LDBCFRi = "ListDistributionsByConnectionFunctionResult";
const _LDBCM = "ListDistributionsByConnectionMode";
const _LDBCMR = "ListDistributionsByConnectionModeRequest";
const _LDBCMRi = "ListDistributionsByConnectionModeResult";
const _LDBCPI = "ListDistributionsByCachePolicyId";
const _LDBCPIR = "ListDistributionsByCachePolicyIdRequest";
const _LDBCPIRi = "ListDistributionsByCachePolicyIdResult";
const _LDBKG = "ListDistributionsByKeyGroup";
const _LDBKGR = "ListDistributionsByKeyGroupRequest";
const _LDBKGRi = "ListDistributionsByKeyGroupResult";
const _LDBOR = "ListDistributionsByOwnedResource";
const _LDBORPI = "ListDistributionsByOriginRequestPolicyId";
const _LDBORPIR = "ListDistributionsByOriginRequestPolicyIdRequest";
const _LDBORPIRi = "ListDistributionsByOriginRequestPolicyIdResult";
const _LDBORR = "ListDistributionsByOwnedResourceRequest";
const _LDBORRi = "ListDistributionsByOwnedResourceResult";
const _LDBRHPI = "ListDistributionsByResponseHeadersPolicyId";
const _LDBRHPIR = "ListDistributionsByResponseHeadersPolicyIdRequest";
const _LDBRHPIRi = "ListDistributionsByResponseHeadersPolicyIdResult";
const _LDBRLC = "ListDistributionsByRealtimeLogConfig";
const _LDBRLCR = "ListDistributionsByRealtimeLogConfigRequest";
const _LDBRLCRi = "ListDistributionsByRealtimeLogConfigResult";
const _LDBTS = "ListDistributionsByTrustStore";
const _LDBTSR = "ListDistributionsByTrustStoreRequest";
const _LDBTSRi = "ListDistributionsByTrustStoreResult";
const _LDBVOI = "ListDistributionsByVpcOriginId";
const _LDBVOIR = "ListDistributionsByVpcOriginIdRequest";
const _LDBVOIRi = "ListDistributionsByVpcOriginIdResult";
const _LDBWACLI = "ListDistributionsByWebACLId";
const _LDBWACLIR = "ListDistributionsByWebACLIdRequest";
const _LDBWACLIRi = "ListDistributionsByWebACLIdResult";
const _LDC = "ListDomainConflicts";
const _LDCR = "ListDomainConflictsRequest";
const _LDCRi = "ListDomainConflictsResult";
const _LDR = "ListDistributionsRequest";
const _LDRi = "ListDistributionsResult";
const _LDT = "ListDistributionTenants";
const _LDTBC = "ListDistributionTenantsByCustomization";
const _LDTBCR = "ListDistributionTenantsByCustomizationRequest";
const _LDTBCRi = "ListDistributionTenantsByCustomizationResult";
const _LDTR = "ListDistributionTenantsRequest";
const _LDTRi = "ListDistributionTenantsResult";
const _LF = "ListFunctions";
const _LFA = "LambdaFunctionAssociations";
const _LFAL = "LambdaFunctionAssociationList";
const _LFARN = "LambdaFunctionARN";
const _LFAa = "LambdaFunctionAssociation";
const _LFLEC = "ListFieldLevelEncryptionConfigs";
const _LFLECR = "ListFieldLevelEncryptionConfigsRequest";
const _LFLECRi = "ListFieldLevelEncryptionConfigsResult";
const _LFLEP = "ListFieldLevelEncryptionProfiles";
const _LFLEPR = "ListFieldLevelEncryptionProfilesRequest";
const _LFLEPRi = "ListFieldLevelEncryptionProfilesResult";
const _LFR = "ListFunctionsRequest";
const _LFRi = "ListFunctionsResult";
const _LI = "ListInvalidations";
const _LIFDT = "ListInvalidationsForDistributionTenant";
const _LIFDTR = "ListInvalidationsForDistributionTenantRequest";
const _LIFDTRi = "ListInvalidationsForDistributionTenantResult";
const _LIR = "ListInvalidationsRequest";
const _LIRi = "ListInvalidationsResult";
const _LKG = "ListKeyGroups";
const _LKGR = "ListKeyGroupsRequest";
const _LKGRi = "ListKeyGroupsResult";
const _LKVS = "ListKeyValueStores";
const _LKVSR = "ListKeyValueStoresRequest";
const _LKVSRi = "ListKeyValueStoresResult";
const _LL = "LocationList";
const _LMT = "LastModifiedTime";
const _LOAC = "ListOriginAccessControls";
const _LOACR = "ListOriginAccessControlsRequest";
const _LOACRi = "ListOriginAccessControlsResult";
const _LORP = "ListOriginRequestPolicies";
const _LORPR = "ListOriginRequestPoliciesRequest";
const _LORPRi = "ListOriginRequestPoliciesResult";
const _LPK = "ListPublicKeys";
const _LPKR = "ListPublicKeysRequest";
const _LPKRi = "ListPublicKeysResult";
const _LRHP = "ListResponseHeadersPolicies";
const _LRHPR = "ListResponseHeadersPoliciesRequest";
const _LRHPRi = "ListResponseHeadersPoliciesResult";
const _LRLC = "ListRealtimeLogConfigs";
const _LRLCR = "ListRealtimeLogConfigsRequest";
const _LRLCRi = "ListRealtimeLogConfigsResult";
const _LSD = "ListStreamingDistributions";
const _LSDR = "ListStreamingDistributionsRequest";
const _LSDRi = "ListStreamingDistributionsResult";
const _LTFR = "ListTagsForResource";
const _LTFRR = "ListTagsForResourceRequest";
const _LTFRRi = "ListTagsForResourceResult";
const _LTS = "ListTrustStores";
const _LTSR = "ListTrustStoresRequest";
const _LTSRi = "ListTrustStoresResult";
const _LVO = "ListVpcOrigins";
const _LVOR = "ListVpcOriginsRequest";
const _LVORi = "ListVpcOriginsResult";
const _Lo = "Logging";
const _Loc = "Locations";
const _M = "Message";
const _MB = "MissingBody";
const _MBo = "ModeBlock";
const _MCD = "ManagedCertificateDetails";
const _MCR = "ManagedCertificateRequest";
const _MI = "MaxItems";
const _ML = "MethodsList";
const _MPV = "MinimumProtocolVersion";
const _MS = "MonitoringSubscription";
const _MSAE = "MonitoringSubscriptionAlreadyExists";
const _MTTL = "MinTTL";
const _MTTLa = "MaxTTL";
const _MTTLax = "MaximumTTL";
const _Ma = "Marker";
const _Me = "Members";
const _Met = "Method";
const _Mo = "Mode";
const _N = "Name";
const _NM = "NextMarker";
const _NOCC = "NumberOfCaCertificates";
const _NSCDP = "NoSuchContinuousDeploymentPolicy";
const _NSCFOAI = "NoSuchCloudFrontOriginAccessIdentity";
const _NSCP = "NoSuchCachePolicy";
const _NSD = "NoSuchDistribution";
const _NSFE = "NoSuchFunctionExists";
const _NSFLEC = "NoSuchFieldLevelEncryptionConfig";
const _NSFLEP = "NoSuchFieldLevelEncryptionProfile";
const _NSI = "NoSuchInvalidation";
const _NSMS = "NoSuchMonitoringSubscription";
const _NSO = "NoSuchOrigin";
const _NSOAC = "NoSuchOriginAccessControl";
const _NSORP = "NoSuchOriginRequestPolicy";
const _NSPK = "NoSuchPublicKey";
const _NSR = "NoSuchResource";
const _NSRHP = "NoSuchResponseHeadersPolicy";
const _NSRLC = "NoSuchRealtimeLogConfig";
const _NSSD = "NoSuchStreamingDistribution";
const _O = "Origins";
const _OAC = "OriginAccessControl";
const _OACAE = "OriginAccessControlAlreadyExists";
const _OACC = "OriginAccessControlConfig";
const _OACI = "OriginAccessControlId";
const _OACIU = "OriginAccessControlInUse";
const _OACL = "OriginAccessControlList";
const _OACOT = "OriginAccessControlOriginType";
const _OACS = "OriginAccessControlSummary";
const _OACSL = "OriginAccessControlSummaryList";
const _OAI = "OwnerAccountId";
const _OAIr = "OriginAccessIdentity";
const _OCH = "OriginCustomHeader";
const _OCHL = "OriginCustomHeadersList";
const _OEA = "OriginEndpointArn";
const _OG = "OriginGroups";
const _OGFC = "OriginGroupFailoverCriteria";
const _OGL = "OriginGroupList";
const _OGM = "OriginGroupMember";
const _OGML = "OriginGroupMemberList";
const _OGMr = "OriginGroupMembers";
const _OGr = "OriginGroup";
const _OI = "OriginId";
const _OKT = "OriginKeepaliveTimeout";
const _OL = "OriginList";
const _OMC = "OriginMtlsConfig";
const _OO = "OriginOverride";
const _OP = "OriginPath";
const _OPP = "OriginProtocolPolicy";
const _ORP = "OriginRequestPolicy";
const _ORPAE = "OriginRequestPolicyAlreadyExists";
const _ORPC = "OriginRequestPolicyConfig";
const _ORPCC = "OriginRequestPolicyCookiesConfig";
const _ORPHC = "OriginRequestPolicyHeadersConfig";
const _ORPI = "OriginRequestPolicyId";
const _ORPIU = "OriginRequestPolicyInUse";
const _ORPL = "OriginRequestPolicyList";
const _ORPQSC = "OriginRequestPolicyQueryStringsConfig";
const _ORPS = "OriginRequestPolicySummary";
const _ORPSL = "OriginRequestPolicySummaryList";
const _ORT = "OriginReadTimeout";
const _OS = "OriginShield";
const _OSP = "OriginSslProtocols";
const _OSR = "OriginShieldRegion";
const _Or = "Origin";
const _Ov = "Override";
const _P = "Parameters";
const _PC = "PriceClass";
const _PCF = "PublishConnectionFunction";
const _PCFR = "PublishConnectionFunctionRequest";
const _PCFRu = "PublishConnectionFunctionResult";
const _PD = "PolicyDocument";
const _PDI = "PrimaryDistributionId";
const _PDN = "PrimaryDomainName";
const _PDS = "ParameterDefinitionSchema";
const _PDa = "ParameterDefinition";
const _PDar = "ParameterDefinitions";
const _PF = "PreconditionFailed";
const _PFR = "PublishFunctionRequest";
const _PFRu = "PublishFunctionResult";
const _PFu = "PublishFunction";
const _PI = "ProfileId";
const _PICKAFTO = "ParametersInCacheKeyAndForwardedToOrigin";
const _PIr = "ProviderId";
const _PK = "PublicKey";
const _PKAE = "PublicKeyAlreadyExists";
const _PKC = "PublicKeyConfig";
const _PKI = "PublicKeyId";
const _PKIL = "PublicKeyIdList";
const _PKIU = "PublicKeyInUse";
const _PKL = "PublicKeyList";
const _PKS = "PublicKeySummary";
const _PKSL = "PublicKeySummaryList";
const _PL = "PathList";
const _PP = "PathPattern";
const _PRP = "PutResourcePolicy";
const _PRPR = "PutResourcePolicyRequest";
const _PRPRu = "PutResourcePolicyResult";
const _Pa = "Paths";
const _Par = "Parameter";
const _Pat = "Path";
const _Pr = "Prefix";
const _Pre = "Preload";
const _Pro = "Protection";
const _Q = "Quantity";
const _QA = "QueryArg";
const _QAP = "QueryArgProfile";
const _QAPC = "QueryArgProfileConfig";
const _QAPE = "QueryArgProfileEmpty";
const _QAPL = "QueryArgProfileList";
const _QAPu = "QueryArgProfiles";
const _QS = "QueryStrings";
const _QSB = "QueryStringBehavior";
const _QSC = "QueryStringsConfig";
const _QSCK = "QueryStringCacheKeys";
const _QSCKL = "QueryStringCacheKeysList";
const _QSN = "QueryStringNames";
const _QSNL = "QueryStringNamesList";
const _QSu = "QueryString";
const _R = "Region";
const _RA = "ResourceArn";
const _RARN = "RoleARN";
const _RC = "ResponseCode";
const _RCT = "ResponseCompletionTimeout";
const _RE = "RoutingEndpoint";
const _RF = "RedirectFrom";
const _RHC = "RemoveHeadersConfig";
const _RHP = "ResponseHeadersPolicy";
const _RHPACAH = "ResponseHeadersPolicyAccessControlAllowHeaders";
const _RHPACAM = "ResponseHeadersPolicyAccessControlAllowMethods";
const _RHPACAO = "ResponseHeadersPolicyAccessControlAllowOrigins";
const _RHPACEH = "ResponseHeadersPolicyAccessControlExposeHeaders";
const _RHPAE = "ResponseHeadersPolicyAlreadyExists";
const _RHPC = "ResponseHeadersPolicyConfig";
const _RHPCC = "ResponseHeadersPolicyCorsConfig";
const _RHPCH = "ResponseHeadersPolicyCustomHeader";
const _RHPCHC = "ResponseHeadersPolicyCustomHeadersConfig";
const _RHPCHL = "ResponseHeadersPolicyCustomHeaderList";
const _RHPCSP = "ResponseHeadersPolicyContentSecurityPolicy";
const _RHPCTO = "ResponseHeadersPolicyContentTypeOptions";
const _RHPFO = "ResponseHeadersPolicyFrameOptions";
const _RHPI = "ResponseHeadersPolicyId";
const _RHPIU = "ResponseHeadersPolicyInUse";
const _RHPL = "ResponseHeadersPolicyList";
const _RHPRH = "ResponseHeadersPolicyRemoveHeader";
const _RHPRHC = "ResponseHeadersPolicyRemoveHeadersConfig";
const _RHPRHL = "ResponseHeadersPolicyRemoveHeaderList";
const _RHPRP = "ResponseHeadersPolicyReferrerPolicy";
const _RHPS = "ResponseHeadersPolicySummary";
const _RHPSHC = "ResponseHeadersPolicySecurityHeadersConfig";
const _RHPSL = "ResponseHeadersPolicySummaryList";
const _RHPSTHC = "ResponseHeadersPolicyServerTimingHeadersConfig";
const _RHPSTS = "ResponseHeadersPolicyStrictTransportSecurity";
const _RHPXSSP = "ResponseHeadersPolicyXSSProtection";
const _RI = "ResourceId";
const _RIU = "ResourceInUse";
const _RLC = "RealtimeLogConfig";
const _RLCA = "RealtimeLogConfigArn";
const _RLCAE = "RealtimeLogConfigAlreadyExists";
const _RLCIU = "RealtimeLogConfigInUse";
const _RLCL = "RealtimeLogConfigList";
const _RLCN = "RealtimeLogConfigName";
const _RLCOM = "RealtimeLogConfigOwnerMismatch";
const _RLCe = "RealtimeLogConfigs";
const _RMSC = "RealtimeMetricsSubscriptionConfig";
const _RMSS = "RealtimeMetricsSubscriptionStatus";
const _RND = "ResourceNotDisabled";
const _RP = "ReferrerPolicy";
const _RPP = "ResponsePagePath";
const _RT = "ResourceType";
const _RTe = "RestrictionType";
const _RTed = "RedirectTo";
const _RU = "ReportUri";
const _Re = "Restrictions";
const _Rea = "Reason";
const _Req = "Required";
const _Res = "Resource";
const _Ru = "Runtime";
const _S = "Status";
const _SARN = "SourceARN";
const _SARNt = "StreamARN";
const _SB = "SigningBehavior";
const _SC = "SelectionCriteria";
const _SCL = "StatusCodeList";
const _SCUI = "S3CanonicalUserId";
const _SCt = "StatusCodes";
const _SCta = "StatusCode";
const _SD = "StreamingDistribution";
const _SDAE = "StreamingDistributionAlreadyExists";
const _SDC = "StreamingDistributionConfig";
const _SDCWT = "StreamingDistributionConfigWithTags";
const _SDDN = "StagingDistributionDnsNames";
const _SDDNL = "StagingDistributionDnsNameList";
const _SDI = "StagingDistributionId";
const _SDIU = "StagingDistributionInUse";
const _SDL = "StreamingDistributionList";
const _SDND = "StreamingDistributionNotDisabled";
const _SDS = "StreamingDistributionSummary";
const _SDSL = "StreamingDistributionSummaryList";
const _SHC = "SecurityHeadersConfig";
const _SHCi = "SingleHeaderConfig";
const _SL = "SignerList";
const _SLC = "StreamingLoggingConfig";
const _SO = "S3Origin";
const _SOC = "S3OriginConfig";
const _SP = "SigningProtocol";
const _SPL = "SslProtocolsList";
const _SPs = "SslProtocol";
const _SR = "SamplingRate";
const _SS = "SmoothStreaming";
const _SSC = "SessionStickinessConfig";
const _SSCt = "StringSchemaConfig";
const _SSLSM = "SSLSupportMethod";
const _SSt = "StringSchema";
const _ST = "StreamType";
const _STHC = "ServerTimingHeadersConfig";
const _STS = "StrictTransportSecurity";
const _STo = "SourceType";
const _SWC = "SingleWeightConfig";
const _Si = "Signer";
const _St = "Stage";
const _Sta = "Staging";
const _T = "Type";
const _TC = "TrafficConfig";
const _TCF = "TestConnectionFunction";
const _TCFR = "TestConnectionFunctionRequest";
const _TCFRe = "TestConnectionFunctionResult";
const _TCe = "TenantConfig";
const _TDI = "TargetDistributionId";
const _TF = "TestFunction";
const _TFF = "TestFunctionFailed";
const _TFR = "TestFunctionRequest";
const _TFRe = "TestFunctionResult";
const _TK = "TagKeys";
const _TKG = "TrustedKeyGroups";
const _TKGDNE = "TrustedKeyGroupDoesNotExist";
const _TKGIL = "TrustedKeyGroupIdList";
const _TKL = "TagKeyList";
const _TL = "TagList";
const _TLCSPIRHP = "TooLongCSPInResponseHeadersPolicy";
const _TMC = "TooManyCertificates";
const _TMCB = "TooManyCacheBehaviors";
const _TMCDP = "TooManyContinuousDeploymentPolicies";
const _TMCFOAI = "TooManyCloudFrontOriginAccessIdentities";
const _TMCHIRHP = "TooManyCustomHeadersInResponseHeadersPolicy";
const _TMCICP = "TooManyCookiesInCachePolicy";
const _TMCIORP = "TooManyCookiesInOriginRequestPolicy";
const _TMCNIWL = "TooManyCookieNamesInWhiteList";
const _TMCP = "TooManyCachePolicies";
const _TMD = "TooManyDistributions";
const _TMDATCP = "TooManyDistributionsAssociatedToCachePolicy";
const _TMDATFLEC = "TooManyDistributionsAssociatedToFieldLevelEncryptionConfig";
const _TMDATKG = "TooManyDistributionsAssociatedToKeyGroup";
const _TMDATOAC = "TooManyDistributionsAssociatedToOriginAccessControl";
const _TMDATORP = "TooManyDistributionsAssociatedToOriginRequestPolicy";
const _TMDATRHP = "TooManyDistributionsAssociatedToResponseHeadersPolicy";
const _TMDCNAME = "TooManyDistributionCNAMEs";
const _TMDWFA = "TooManyDistributionsWithFunctionAssociations";
const _TMDWLA = "TooManyDistributionsWithLambdaAssociations";
const _TMDWSFARN = "TooManyDistributionsWithSingleFunctionARN";
const _TMF = "TooManyFunctions";
const _TMFA = "TooManyFunctionAssociations";
const _TMFLEC = "TooManyFieldLevelEncryptionConfigs";
const _TMFLECTP = "TooManyFieldLevelEncryptionContentTypeProfiles";
const _TMFLEEE = "TooManyFieldLevelEncryptionEncryptionEntities";
const _TMFLEFP = "TooManyFieldLevelEncryptionFieldPatterns";
const _TMFLEP = "TooManyFieldLevelEncryptionProfiles";
const _TMFLEQAP = "TooManyFieldLevelEncryptionQueryArgProfiles";
const _TMHICP = "TooManyHeadersInCachePolicy";
const _TMHIFV = "TooManyHeadersInForwardedValues";
const _TMHIORP = "TooManyHeadersInOriginRequestPolicy";
const _TMIIP = "TooManyInvalidationsInProgress";
const _TMKG = "TooManyKeyGroups";
const _TMKGATD = "TooManyKeyGroupsAssociatedToDistribution";
const _TMLFA = "TooManyLambdaFunctionAssociations";
const _TMO = "TooManyOrigins";
const _TMOAC = "TooManyOriginAccessControls";
const _TMOCH = "TooManyOriginCustomHeaders";
const _TMOGPD = "TooManyOriginGroupsPerDistribution";
const _TMORP = "TooManyOriginRequestPolicies";
const _TMPK = "TooManyPublicKeys";
const _TMPKIKG = "TooManyPublicKeysInKeyGroup";
const _TMQSICP = "TooManyQueryStringsInCachePolicy";
const _TMQSIORP = "TooManyQueryStringsInOriginRequestPolicy";
const _TMQSP = "TooManyQueryStringParameters";
const _TMRHIRHP = "TooManyRemoveHeadersInResponseHeadersPolicy";
const _TMRHP = "TooManyResponseHeadersPolicies";
const _TMRLC = "TooManyRealtimeLogConfigs";
const _TMSD = "TooManyStreamingDistributions";
const _TMSDCNAME = "TooManyStreamingDistributionCNAMEs";
const _TMTS = "TooManyTrustedSigners";
const _TOI = "TargetOriginId";
const _TR = "TestResult";
const _TRR = "TagResourceRequest";
const _TRa = "TargetResource";
const _TRag = "TagResource";
const _TS = "TrustedSigners";
const _TSC = "TrustStoreConfig";
const _TSDNE = "TrustedSignerDoesNotExist";
const _TSI = "TrustStoreIdentifier";
const _TSIr = "TrustStoreId";
const _TSL = "TrustStoreList";
const _TSS = "TrustStoreSummary";
const _TSr = "TrustStore";
const _Ta = "Tags";
const _Tag = "Tag";
const _UAIL = "UpdateAnycastIpList";
const _UAILR = "UpdateAnycastIpListRequest";
const _UAILRp = "UpdateAnycastIpListResult";
const _UCDP = "UpdateContinuousDeploymentPolicy";
const _UCDPR = "UpdateContinuousDeploymentPolicyRequest";
const _UCDPRp = "UpdateContinuousDeploymentPolicyResult";
const _UCF = "UpdateConnectionFunction";
const _UCFOAI = "UpdateCloudFrontOriginAccessIdentity";
const _UCFOAIR = "UpdateCloudFrontOriginAccessIdentityRequest";
const _UCFOAIRp = "UpdateCloudFrontOriginAccessIdentityResult";
const _UCFR = "UpdateConnectionFunctionRequest";
const _UCFRp = "UpdateConnectionFunctionResult";
const _UCG = "UpdateConnectionGroup";
const _UCGR = "UpdateConnectionGroupRequest";
const _UCGRp = "UpdateConnectionGroupResult";
const _UCP = "UpdateCachePolicy";
const _UCPR = "UpdateCachePolicyRequest";
const _UCPRp = "UpdateCachePolicyResult";
const _UD = "UpdateDistribution";
const _UDA = "UpdateDomainAssociation";
const _UDAR = "UpdateDomainAssociationRequest";
const _UDARp = "UpdateDomainAssociationResult";
const _UDR = "UpdateDistributionRequest";
const _UDRp = "UpdateDistributionResult";
const _UDT = "UpdateDistributionTenant";
const _UDTR = "UpdateDistributionTenantRequest";
const _UDTRp = "UpdateDistributionTenantResult";
const _UDWSC = "UpdateDistributionWithStagingConfig";
const _UDWSCR = "UpdateDistributionWithStagingConfigRequest";
const _UDWSCRp = "UpdateDistributionWithStagingConfigResult";
const _UF = "UpdateFunction";
const _UFLEC = "UpdateFieldLevelEncryptionConfig";
const _UFLECR = "UpdateFieldLevelEncryptionConfigRequest";
const _UFLECRp = "UpdateFieldLevelEncryptionConfigResult";
const _UFLEP = "UpdateFieldLevelEncryptionProfile";
const _UFLEPR = "UpdateFieldLevelEncryptionProfileRequest";
const _UFLEPRp = "UpdateFieldLevelEncryptionProfileResult";
const _UFR = "UpdateFunctionRequest";
const _UFRp = "UpdateFunctionResult";
const _UKG = "UpdateKeyGroup";
const _UKGR = "UpdateKeyGroupRequest";
const _UKGRp = "UpdateKeyGroupResult";
const _UKVS = "UpdateKeyValueStore";
const _UKVSR = "UpdateKeyValueStoreRequest";
const _UKVSRp = "UpdateKeyValueStoreResult";
const _UO = "UnsupportedOperation";
const _UOAC = "UpdateOriginAccessControl";
const _UOACR = "UpdateOriginAccessControlRequest";
const _UOACRp = "UpdateOriginAccessControlResult";
const _UORP = "UpdateOriginRequestPolicy";
const _UORPR = "UpdateOriginRequestPolicyRequest";
const _UORPRp = "UpdateOriginRequestPolicyResult";
const _UPK = "UpdatePublicKey";
const _UPKR = "UpdatePublicKeyRequest";
const _UPKRp = "UpdatePublicKeyResult";
const _UR = "UntagResource";
const _URHP = "UpdateResponseHeadersPolicy";
const _URHPR = "UpdateResponseHeadersPolicyRequest";
const _URHPRp = "UpdateResponseHeadersPolicyResult";
const _URLC = "UpdateRealtimeLogConfig";
const _URLCR = "UpdateRealtimeLogConfigRequest";
const _URLCRp = "UpdateRealtimeLogConfigResult";
const _URR = "UntagResourceRequest";
const _USD = "UpdateStreamingDistribution";
const _USDR = "UpdateStreamingDistributionRequest";
const _USDRp = "UpdateStreamingDistributionResult";
const _UTS = "UpdateTrustStore";
const _UTSR = "UpdateTrustStoreRequest";
const _UTSRp = "UpdateTrustStoreResult";
const _UVO = "UpdateVpcOrigin";
const _UVOR = "UpdateVpcOriginRequest";
const _UVORp = "UpdateVpcOriginResult";
const _V = "Version";
const _VC = "ViewerCertificate";
const _VDC = "VerifyDnsConfiguration";
const _VDCR = "VerifyDnsConfigurationRequest";
const _VDCRe = "VerifyDnsConfigurationResult";
const _VMC = "ViewerMtlsConfig";
const _VO = "VpcOrigin";
const _VOC = "VpcOriginConfig";
const _VOEC = "VpcOriginEndpointConfig";
const _VOI = "VpcOriginId";
const _VOL = "VpcOriginList";
const _VOS = "VpcOriginSummary";
const _VOSL = "VpcOriginSummaryList";
const _VPP = "ViewerProtocolPolicy";
const _VTD = "ValidationTokenDetails";
const _VTDL = "ValidationTokenDetailList";
const _VTDa = "ValidationTokenDetail";
const _VTH = "ValidationTokenHost";
const _Va = "Value";
const _W = "Weight";
const _WA = "WebAcl";
const _WAC = "WebAclCustomization";
const _WACLA = "WebACLArn";
const _WACLI = "WebACLId";
const _WN = "WhitelistedNames";
const _XSSP = "XSSProtection";
const _c = "client";
const _d = "domain";
const _e = "error";
const _h = "http";
const _hE = "httpError";
const _hH = "httpHeader";
const _hP = "httpPayload";
const _hQ = "httpQuery";
const _s = "smithy.ts.sdk.synthetic.com.amazonaws.cloudfront";
const _sST = "sensitiveStringType";
const _se = "server";
const _xN = "xmlName";
const n0 = "com.amazonaws.cloudfront";
const schema_1 = require("@smithy/core/schema");
const CloudFrontServiceException_1 = require("../models/CloudFrontServiceException");
const errors_1 = require("../models/errors");
const _s_registry = schema_1.TypeRegistry.for(_s);
exports.CloudFrontServiceException$ = [-3, _s, "CloudFrontServiceException", 0, [], []];
_s_registry.registerError(exports.CloudFrontServiceException$, CloudFrontServiceException_1.CloudFrontServiceException);
const n0_registry = schema_1.TypeRegistry.for(n0);
exports.AccessDenied$ = [-3, n0, _AD,
    { [_e]: _c, [_hE]: 403 },
    [_M],
    [0]
];
n0_registry.registerError(exports.AccessDenied$, errors_1.AccessDenied);
exports.BatchTooLarge$ = [-3, n0, _BTL,
    { [_e]: _c, [_hE]: 413 },
    [_M],
    [0]
];
n0_registry.registerError(exports.BatchTooLarge$, errors_1.BatchTooLarge);
exports.CachePolicyAlreadyExists$ = [-3, n0, _CPAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.CachePolicyAlreadyExists$, errors_1.CachePolicyAlreadyExists);
exports.CachePolicyInUse$ = [-3, n0, _CPIU,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.CachePolicyInUse$, errors_1.CachePolicyInUse);
exports.CannotChangeImmutablePublicKeyFields$ = [-3, n0, _CCIPKF,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.CannotChangeImmutablePublicKeyFields$, errors_1.CannotChangeImmutablePublicKeyFields);
exports.CannotDeleteEntityWhileInUse$ = [-3, n0, _CDEWIU,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.CannotDeleteEntityWhileInUse$, errors_1.CannotDeleteEntityWhileInUse);
exports.CannotUpdateEntityWhileInUse$ = [-3, n0, _CUEWIU,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.CannotUpdateEntityWhileInUse$, errors_1.CannotUpdateEntityWhileInUse);
exports.CloudFrontOriginAccessIdentityAlreadyExists$ = [-3, n0, _CFOAIAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.CloudFrontOriginAccessIdentityAlreadyExists$, errors_1.CloudFrontOriginAccessIdentityAlreadyExists);
exports.CloudFrontOriginAccessIdentityInUse$ = [-3, n0, _CFOAIIU,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.CloudFrontOriginAccessIdentityInUse$, errors_1.CloudFrontOriginAccessIdentityInUse);
exports.CNAMEAlreadyExists$ = [-3, n0, _CNAMEAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.CNAMEAlreadyExists$, errors_1.CNAMEAlreadyExists);
exports.ContinuousDeploymentPolicyAlreadyExists$ = [-3, n0, _CDPAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.ContinuousDeploymentPolicyAlreadyExists$, errors_1.ContinuousDeploymentPolicyAlreadyExists);
exports.ContinuousDeploymentPolicyInUse$ = [-3, n0, _CDPIU,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.ContinuousDeploymentPolicyInUse$, errors_1.ContinuousDeploymentPolicyInUse);
exports.DistributionAlreadyExists$ = [-3, n0, _DAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.DistributionAlreadyExists$, errors_1.DistributionAlreadyExists);
exports.DistributionNotDisabled$ = [-3, n0, _DND,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.DistributionNotDisabled$, errors_1.DistributionNotDisabled);
exports.EntityAlreadyExists$ = [-3, n0, _EAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.EntityAlreadyExists$, errors_1.EntityAlreadyExists);
exports.EntityLimitExceeded$ = [-3, n0, _ELE,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.EntityLimitExceeded$, errors_1.EntityLimitExceeded);
exports.EntityNotFound$ = [-3, n0, _ENF,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.EntityNotFound$, errors_1.EntityNotFound);
exports.EntitySizeLimitExceeded$ = [-3, n0, _ESLE,
    { [_e]: _c, [_hE]: 413 },
    [_M],
    [0]
];
n0_registry.registerError(exports.EntitySizeLimitExceeded$, errors_1.EntitySizeLimitExceeded);
exports.FieldLevelEncryptionConfigAlreadyExists$ = [-3, n0, _FLECAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.FieldLevelEncryptionConfigAlreadyExists$, errors_1.FieldLevelEncryptionConfigAlreadyExists);
exports.FieldLevelEncryptionConfigInUse$ = [-3, n0, _FLECIU,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.FieldLevelEncryptionConfigInUse$, errors_1.FieldLevelEncryptionConfigInUse);
exports.FieldLevelEncryptionProfileAlreadyExists$ = [-3, n0, _FLEPAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.FieldLevelEncryptionProfileAlreadyExists$, errors_1.FieldLevelEncryptionProfileAlreadyExists);
exports.FieldLevelEncryptionProfileInUse$ = [-3, n0, _FLEPIU,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.FieldLevelEncryptionProfileInUse$, errors_1.FieldLevelEncryptionProfileInUse);
exports.FieldLevelEncryptionProfileSizeExceeded$ = [-3, n0, _FLEPSE,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.FieldLevelEncryptionProfileSizeExceeded$, errors_1.FieldLevelEncryptionProfileSizeExceeded);
exports.FunctionAlreadyExists$ = [-3, n0, _FAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.FunctionAlreadyExists$, errors_1.FunctionAlreadyExists);
exports.FunctionInUse$ = [-3, n0, _FIU,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.FunctionInUse$, errors_1.FunctionInUse);
exports.FunctionSizeLimitExceeded$ = [-3, n0, _FSLE,
    { [_e]: _c, [_hE]: 413 },
    [_M],
    [0]
];
n0_registry.registerError(exports.FunctionSizeLimitExceeded$, errors_1.FunctionSizeLimitExceeded);
exports.IllegalDelete$ = [-3, n0, _ID,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.IllegalDelete$, errors_1.IllegalDelete);
exports.IllegalFieldLevelEncryptionConfigAssociationWithCacheBehavior$ = [-3, n0, _IFLECAWCB,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.IllegalFieldLevelEncryptionConfigAssociationWithCacheBehavior$, errors_1.IllegalFieldLevelEncryptionConfigAssociationWithCacheBehavior);
exports.IllegalOriginAccessConfiguration$ = [-3, n0, _IOAC,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.IllegalOriginAccessConfiguration$, errors_1.IllegalOriginAccessConfiguration);
exports.IllegalUpdate$ = [-3, n0, _IU,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.IllegalUpdate$, errors_1.IllegalUpdate);
exports.InconsistentQuantities$ = [-3, n0, _IQ,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InconsistentQuantities$, errors_1.InconsistentQuantities);
exports.InvalidArgument$ = [-3, n0, _IA,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidArgument$, errors_1.InvalidArgument);
exports.InvalidAssociation$ = [-3, n0, _IAn,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidAssociation$, errors_1.InvalidAssociation);
exports.InvalidDefaultRootObject$ = [-3, n0, _IDRO,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidDefaultRootObject$, errors_1.InvalidDefaultRootObject);
exports.InvalidDomainNameForOriginAccessControl$ = [-3, n0, _IDNFOAC,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidDomainNameForOriginAccessControl$, errors_1.InvalidDomainNameForOriginAccessControl);
exports.InvalidErrorCode$ = [-3, n0, _IEC,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidErrorCode$, errors_1.InvalidErrorCode);
exports.InvalidForwardCookies$ = [-3, n0, _IFC,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidForwardCookies$, errors_1.InvalidForwardCookies);
exports.InvalidFunctionAssociation$ = [-3, n0, _IFA,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidFunctionAssociation$, errors_1.InvalidFunctionAssociation);
exports.InvalidGeoRestrictionParameter$ = [-3, n0, _IGRP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidGeoRestrictionParameter$, errors_1.InvalidGeoRestrictionParameter);
exports.InvalidHeadersForS3Origin$ = [-3, n0, _IHFSO,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidHeadersForS3Origin$, errors_1.InvalidHeadersForS3Origin);
exports.InvalidIfMatchVersion$ = [-3, n0, _IIMV,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidIfMatchVersion$, errors_1.InvalidIfMatchVersion);
exports.InvalidLambdaFunctionAssociation$ = [-3, n0, _ILFA,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidLambdaFunctionAssociation$, errors_1.InvalidLambdaFunctionAssociation);
exports.InvalidLocationCode$ = [-3, n0, _ILC,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidLocationCode$, errors_1.InvalidLocationCode);
exports.InvalidMinimumProtocolVersion$ = [-3, n0, _IMPV,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidMinimumProtocolVersion$, errors_1.InvalidMinimumProtocolVersion);
exports.InvalidOrigin$ = [-3, n0, _IO,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidOrigin$, errors_1.InvalidOrigin);
exports.InvalidOriginAccessControl$ = [-3, n0, _IOACn,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidOriginAccessControl$, errors_1.InvalidOriginAccessControl);
exports.InvalidOriginAccessIdentity$ = [-3, n0, _IOAI,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidOriginAccessIdentity$, errors_1.InvalidOriginAccessIdentity);
exports.InvalidOriginKeepaliveTimeout$ = [-3, n0, _IOKT,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidOriginKeepaliveTimeout$, errors_1.InvalidOriginKeepaliveTimeout);
exports.InvalidOriginReadTimeout$ = [-3, n0, _IORT,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidOriginReadTimeout$, errors_1.InvalidOriginReadTimeout);
exports.InvalidProtocolSettings$ = [-3, n0, _IPS,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidProtocolSettings$, errors_1.InvalidProtocolSettings);
exports.InvalidQueryStringParameters$ = [-3, n0, _IQSP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidQueryStringParameters$, errors_1.InvalidQueryStringParameters);
exports.InvalidRelativePath$ = [-3, n0, _IRP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidRelativePath$, errors_1.InvalidRelativePath);
exports.InvalidRequiredProtocol$ = [-3, n0, _IRPn,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidRequiredProtocol$, errors_1.InvalidRequiredProtocol);
exports.InvalidResponseCode$ = [-3, n0, _IRC,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidResponseCode$, errors_1.InvalidResponseCode);
exports.InvalidTagging$ = [-3, n0, _IT,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidTagging$, errors_1.InvalidTagging);
exports.InvalidTTLOrder$ = [-3, n0, _ITTLO,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidTTLOrder$, errors_1.InvalidTTLOrder);
exports.InvalidViewerCertificate$ = [-3, n0, _IVC,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidViewerCertificate$, errors_1.InvalidViewerCertificate);
exports.InvalidWebACLId$ = [-3, n0, _IWACLI,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.InvalidWebACLId$, errors_1.InvalidWebACLId);
exports.KeyGroupAlreadyExists$ = [-3, n0, _KGAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.KeyGroupAlreadyExists$, errors_1.KeyGroupAlreadyExists);
exports.MissingBody$ = [-3, n0, _MB,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.MissingBody$, errors_1.MissingBody);
exports.MonitoringSubscriptionAlreadyExists$ = [-3, n0, _MSAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.MonitoringSubscriptionAlreadyExists$, errors_1.MonitoringSubscriptionAlreadyExists);
exports.NoSuchCachePolicy$ = [-3, n0, _NSCP,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchCachePolicy$, errors_1.NoSuchCachePolicy);
exports.NoSuchCloudFrontOriginAccessIdentity$ = [-3, n0, _NSCFOAI,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchCloudFrontOriginAccessIdentity$, errors_1.NoSuchCloudFrontOriginAccessIdentity);
exports.NoSuchContinuousDeploymentPolicy$ = [-3, n0, _NSCDP,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchContinuousDeploymentPolicy$, errors_1.NoSuchContinuousDeploymentPolicy);
exports.NoSuchDistribution$ = [-3, n0, _NSD,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchDistribution$, errors_1.NoSuchDistribution);
exports.NoSuchFieldLevelEncryptionConfig$ = [-3, n0, _NSFLEC,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchFieldLevelEncryptionConfig$, errors_1.NoSuchFieldLevelEncryptionConfig);
exports.NoSuchFieldLevelEncryptionProfile$ = [-3, n0, _NSFLEP,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchFieldLevelEncryptionProfile$, errors_1.NoSuchFieldLevelEncryptionProfile);
exports.NoSuchFunctionExists$ = [-3, n0, _NSFE,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchFunctionExists$, errors_1.NoSuchFunctionExists);
exports.NoSuchInvalidation$ = [-3, n0, _NSI,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchInvalidation$, errors_1.NoSuchInvalidation);
exports.NoSuchMonitoringSubscription$ = [-3, n0, _NSMS,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchMonitoringSubscription$, errors_1.NoSuchMonitoringSubscription);
exports.NoSuchOrigin$ = [-3, n0, _NSO,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchOrigin$, errors_1.NoSuchOrigin);
exports.NoSuchOriginAccessControl$ = [-3, n0, _NSOAC,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchOriginAccessControl$, errors_1.NoSuchOriginAccessControl);
exports.NoSuchOriginRequestPolicy$ = [-3, n0, _NSORP,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchOriginRequestPolicy$, errors_1.NoSuchOriginRequestPolicy);
exports.NoSuchPublicKey$ = [-3, n0, _NSPK,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchPublicKey$, errors_1.NoSuchPublicKey);
exports.NoSuchRealtimeLogConfig$ = [-3, n0, _NSRLC,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchRealtimeLogConfig$, errors_1.NoSuchRealtimeLogConfig);
exports.NoSuchResource$ = [-3, n0, _NSR,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchResource$, errors_1.NoSuchResource);
exports.NoSuchResponseHeadersPolicy$ = [-3, n0, _NSRHP,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchResponseHeadersPolicy$, errors_1.NoSuchResponseHeadersPolicy);
exports.NoSuchStreamingDistribution$ = [-3, n0, _NSSD,
    { [_e]: _c, [_hE]: 404 },
    [_M],
    [0]
];
n0_registry.registerError(exports.NoSuchStreamingDistribution$, errors_1.NoSuchStreamingDistribution);
exports.OriginAccessControlAlreadyExists$ = [-3, n0, _OACAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.OriginAccessControlAlreadyExists$, errors_1.OriginAccessControlAlreadyExists);
exports.OriginAccessControlInUse$ = [-3, n0, _OACIU,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.OriginAccessControlInUse$, errors_1.OriginAccessControlInUse);
exports.OriginRequestPolicyAlreadyExists$ = [-3, n0, _ORPAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.OriginRequestPolicyAlreadyExists$, errors_1.OriginRequestPolicyAlreadyExists);
exports.OriginRequestPolicyInUse$ = [-3, n0, _ORPIU,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.OriginRequestPolicyInUse$, errors_1.OriginRequestPolicyInUse);
exports.PreconditionFailed$ = [-3, n0, _PF,
    { [_e]: _c, [_hE]: 412 },
    [_M],
    [0]
];
n0_registry.registerError(exports.PreconditionFailed$, errors_1.PreconditionFailed);
exports.PublicKeyAlreadyExists$ = [-3, n0, _PKAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.PublicKeyAlreadyExists$, errors_1.PublicKeyAlreadyExists);
exports.PublicKeyInUse$ = [-3, n0, _PKIU,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.PublicKeyInUse$, errors_1.PublicKeyInUse);
exports.QueryArgProfileEmpty$ = [-3, n0, _QAPE,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.QueryArgProfileEmpty$, errors_1.QueryArgProfileEmpty);
exports.RealtimeLogConfigAlreadyExists$ = [-3, n0, _RLCAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.RealtimeLogConfigAlreadyExists$, errors_1.RealtimeLogConfigAlreadyExists);
exports.RealtimeLogConfigInUse$ = [-3, n0, _RLCIU,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.RealtimeLogConfigInUse$, errors_1.RealtimeLogConfigInUse);
exports.RealtimeLogConfigOwnerMismatch$ = [-3, n0, _RLCOM,
    { [_e]: _c, [_hE]: 401 },
    [_M],
    [0]
];
n0_registry.registerError(exports.RealtimeLogConfigOwnerMismatch$, errors_1.RealtimeLogConfigOwnerMismatch);
exports.ResourceInUse$ = [-3, n0, _RIU,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.ResourceInUse$, errors_1.ResourceInUse);
exports.ResourceNotDisabled$ = [-3, n0, _RND,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.ResourceNotDisabled$, errors_1.ResourceNotDisabled);
exports.ResponseHeadersPolicyAlreadyExists$ = [-3, n0, _RHPAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.ResponseHeadersPolicyAlreadyExists$, errors_1.ResponseHeadersPolicyAlreadyExists);
exports.ResponseHeadersPolicyInUse$ = [-3, n0, _RHPIU,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.ResponseHeadersPolicyInUse$, errors_1.ResponseHeadersPolicyInUse);
exports.StagingDistributionInUse$ = [-3, n0, _SDIU,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.StagingDistributionInUse$, errors_1.StagingDistributionInUse);
exports.StreamingDistributionAlreadyExists$ = [-3, n0, _SDAE,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.StreamingDistributionAlreadyExists$, errors_1.StreamingDistributionAlreadyExists);
exports.StreamingDistributionNotDisabled$ = [-3, n0, _SDND,
    { [_e]: _c, [_hE]: 409 },
    [_M],
    [0]
];
n0_registry.registerError(exports.StreamingDistributionNotDisabled$, errors_1.StreamingDistributionNotDisabled);
exports.TestFunctionFailed$ = [-3, n0, _TFF,
    { [_e]: _se, [_hE]: 500 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TestFunctionFailed$, errors_1.TestFunctionFailed);
exports.TooLongCSPInResponseHeadersPolicy$ = [-3, n0, _TLCSPIRHP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooLongCSPInResponseHeadersPolicy$, errors_1.TooLongCSPInResponseHeadersPolicy);
exports.TooManyCacheBehaviors$ = [-3, n0, _TMCB,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyCacheBehaviors$, errors_1.TooManyCacheBehaviors);
exports.TooManyCachePolicies$ = [-3, n0, _TMCP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyCachePolicies$, errors_1.TooManyCachePolicies);
exports.TooManyCertificates$ = [-3, n0, _TMC,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyCertificates$, errors_1.TooManyCertificates);
exports.TooManyCloudFrontOriginAccessIdentities$ = [-3, n0, _TMCFOAI,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyCloudFrontOriginAccessIdentities$, errors_1.TooManyCloudFrontOriginAccessIdentities);
exports.TooManyContinuousDeploymentPolicies$ = [-3, n0, _TMCDP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyContinuousDeploymentPolicies$, errors_1.TooManyContinuousDeploymentPolicies);
exports.TooManyCookieNamesInWhiteList$ = [-3, n0, _TMCNIWL,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyCookieNamesInWhiteList$, errors_1.TooManyCookieNamesInWhiteList);
exports.TooManyCookiesInCachePolicy$ = [-3, n0, _TMCICP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyCookiesInCachePolicy$, errors_1.TooManyCookiesInCachePolicy);
exports.TooManyCookiesInOriginRequestPolicy$ = [-3, n0, _TMCIORP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyCookiesInOriginRequestPolicy$, errors_1.TooManyCookiesInOriginRequestPolicy);
exports.TooManyCustomHeadersInResponseHeadersPolicy$ = [-3, n0, _TMCHIRHP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyCustomHeadersInResponseHeadersPolicy$, errors_1.TooManyCustomHeadersInResponseHeadersPolicy);
exports.TooManyDistributionCNAMEs$ = [-3, n0, _TMDCNAME,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyDistributionCNAMEs$, errors_1.TooManyDistributionCNAMEs);
exports.TooManyDistributions$ = [-3, n0, _TMD,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyDistributions$, errors_1.TooManyDistributions);
exports.TooManyDistributionsAssociatedToCachePolicy$ = [-3, n0, _TMDATCP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyDistributionsAssociatedToCachePolicy$, errors_1.TooManyDistributionsAssociatedToCachePolicy);
exports.TooManyDistributionsAssociatedToFieldLevelEncryptionConfig$ = [-3, n0, _TMDATFLEC,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyDistributionsAssociatedToFieldLevelEncryptionConfig$, errors_1.TooManyDistributionsAssociatedToFieldLevelEncryptionConfig);
exports.TooManyDistributionsAssociatedToKeyGroup$ = [-3, n0, _TMDATKG,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyDistributionsAssociatedToKeyGroup$, errors_1.TooManyDistributionsAssociatedToKeyGroup);
exports.TooManyDistributionsAssociatedToOriginAccessControl$ = [-3, n0, _TMDATOAC,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyDistributionsAssociatedToOriginAccessControl$, errors_1.TooManyDistributionsAssociatedToOriginAccessControl);
exports.TooManyDistributionsAssociatedToOriginRequestPolicy$ = [-3, n0, _TMDATORP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyDistributionsAssociatedToOriginRequestPolicy$, errors_1.TooManyDistributionsAssociatedToOriginRequestPolicy);
exports.TooManyDistributionsAssociatedToResponseHeadersPolicy$ = [-3, n0, _TMDATRHP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyDistributionsAssociatedToResponseHeadersPolicy$, errors_1.TooManyDistributionsAssociatedToResponseHeadersPolicy);
exports.TooManyDistributionsWithFunctionAssociations$ = [-3, n0, _TMDWFA,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyDistributionsWithFunctionAssociations$, errors_1.TooManyDistributionsWithFunctionAssociations);
exports.TooManyDistributionsWithLambdaAssociations$ = [-3, n0, _TMDWLA,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyDistributionsWithLambdaAssociations$, errors_1.TooManyDistributionsWithLambdaAssociations);
exports.TooManyDistributionsWithSingleFunctionARN$ = [-3, n0, _TMDWSFARN,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyDistributionsWithSingleFunctionARN$, errors_1.TooManyDistributionsWithSingleFunctionARN);
exports.TooManyFieldLevelEncryptionConfigs$ = [-3, n0, _TMFLEC,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyFieldLevelEncryptionConfigs$, errors_1.TooManyFieldLevelEncryptionConfigs);
exports.TooManyFieldLevelEncryptionContentTypeProfiles$ = [-3, n0, _TMFLECTP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyFieldLevelEncryptionContentTypeProfiles$, errors_1.TooManyFieldLevelEncryptionContentTypeProfiles);
exports.TooManyFieldLevelEncryptionEncryptionEntities$ = [-3, n0, _TMFLEEE,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyFieldLevelEncryptionEncryptionEntities$, errors_1.TooManyFieldLevelEncryptionEncryptionEntities);
exports.TooManyFieldLevelEncryptionFieldPatterns$ = [-3, n0, _TMFLEFP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyFieldLevelEncryptionFieldPatterns$, errors_1.TooManyFieldLevelEncryptionFieldPatterns);
exports.TooManyFieldLevelEncryptionProfiles$ = [-3, n0, _TMFLEP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyFieldLevelEncryptionProfiles$, errors_1.TooManyFieldLevelEncryptionProfiles);
exports.TooManyFieldLevelEncryptionQueryArgProfiles$ = [-3, n0, _TMFLEQAP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyFieldLevelEncryptionQueryArgProfiles$, errors_1.TooManyFieldLevelEncryptionQueryArgProfiles);
exports.TooManyFunctionAssociations$ = [-3, n0, _TMFA,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyFunctionAssociations$, errors_1.TooManyFunctionAssociations);
exports.TooManyFunctions$ = [-3, n0, _TMF,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyFunctions$, errors_1.TooManyFunctions);
exports.TooManyHeadersInCachePolicy$ = [-3, n0, _TMHICP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyHeadersInCachePolicy$, errors_1.TooManyHeadersInCachePolicy);
exports.TooManyHeadersInForwardedValues$ = [-3, n0, _TMHIFV,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyHeadersInForwardedValues$, errors_1.TooManyHeadersInForwardedValues);
exports.TooManyHeadersInOriginRequestPolicy$ = [-3, n0, _TMHIORP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyHeadersInOriginRequestPolicy$, errors_1.TooManyHeadersInOriginRequestPolicy);
exports.TooManyInvalidationsInProgress$ = [-3, n0, _TMIIP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyInvalidationsInProgress$, errors_1.TooManyInvalidationsInProgress);
exports.TooManyKeyGroups$ = [-3, n0, _TMKG,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyKeyGroups$, errors_1.TooManyKeyGroups);
exports.TooManyKeyGroupsAssociatedToDistribution$ = [-3, n0, _TMKGATD,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyKeyGroupsAssociatedToDistribution$, errors_1.TooManyKeyGroupsAssociatedToDistribution);
exports.TooManyLambdaFunctionAssociations$ = [-3, n0, _TMLFA,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyLambdaFunctionAssociations$, errors_1.TooManyLambdaFunctionAssociations);
exports.TooManyOriginAccessControls$ = [-3, n0, _TMOAC,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyOriginAccessControls$, errors_1.TooManyOriginAccessControls);
exports.TooManyOriginCustomHeaders$ = [-3, n0, _TMOCH,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyOriginCustomHeaders$, errors_1.TooManyOriginCustomHeaders);
exports.TooManyOriginGroupsPerDistribution$ = [-3, n0, _TMOGPD,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyOriginGroupsPerDistribution$, errors_1.TooManyOriginGroupsPerDistribution);
exports.TooManyOriginRequestPolicies$ = [-3, n0, _TMORP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyOriginRequestPolicies$, errors_1.TooManyOriginRequestPolicies);
exports.TooManyOrigins$ = [-3, n0, _TMO,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyOrigins$, errors_1.TooManyOrigins);
exports.TooManyPublicKeys$ = [-3, n0, _TMPK,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyPublicKeys$, errors_1.TooManyPublicKeys);
exports.TooManyPublicKeysInKeyGroup$ = [-3, n0, _TMPKIKG,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyPublicKeysInKeyGroup$, errors_1.TooManyPublicKeysInKeyGroup);
exports.TooManyQueryStringParameters$ = [-3, n0, _TMQSP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyQueryStringParameters$, errors_1.TooManyQueryStringParameters);
exports.TooManyQueryStringsInCachePolicy$ = [-3, n0, _TMQSICP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyQueryStringsInCachePolicy$, errors_1.TooManyQueryStringsInCachePolicy);
exports.TooManyQueryStringsInOriginRequestPolicy$ = [-3, n0, _TMQSIORP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyQueryStringsInOriginRequestPolicy$, errors_1.TooManyQueryStringsInOriginRequestPolicy);
exports.TooManyRealtimeLogConfigs$ = [-3, n0, _TMRLC,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyRealtimeLogConfigs$, errors_1.TooManyRealtimeLogConfigs);
exports.TooManyRemoveHeadersInResponseHeadersPolicy$ = [-3, n0, _TMRHIRHP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyRemoveHeadersInResponseHeadersPolicy$, errors_1.TooManyRemoveHeadersInResponseHeadersPolicy);
exports.TooManyResponseHeadersPolicies$ = [-3, n0, _TMRHP,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyResponseHeadersPolicies$, errors_1.TooManyResponseHeadersPolicies);
exports.TooManyStreamingDistributionCNAMEs$ = [-3, n0, _TMSDCNAME,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyStreamingDistributionCNAMEs$, errors_1.TooManyStreamingDistributionCNAMEs);
exports.TooManyStreamingDistributions$ = [-3, n0, _TMSD,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyStreamingDistributions$, errors_1.TooManyStreamingDistributions);
exports.TooManyTrustedSigners$ = [-3, n0, _TMTS,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TooManyTrustedSigners$, errors_1.TooManyTrustedSigners);
exports.TrustedKeyGroupDoesNotExist$ = [-3, n0, _TKGDNE,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TrustedKeyGroupDoesNotExist$, errors_1.TrustedKeyGroupDoesNotExist);
exports.TrustedSignerDoesNotExist$ = [-3, n0, _TSDNE,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.TrustedSignerDoesNotExist$, errors_1.TrustedSignerDoesNotExist);
exports.UnsupportedOperation$ = [-3, n0, _UO,
    { [_e]: _c, [_hE]: 400 },
    [_M],
    [0]
];
n0_registry.registerError(exports.UnsupportedOperation$, errors_1.UnsupportedOperation);
exports.errorTypeRegistries = [
    _s_registry,
    n0_registry,
];
var CommentType = [0, n0, _CT, 8, 0];
var FunctionBlob = [0, n0, _FB, 8, 21];
var FunctionEventObject = [0, n0, _FEO, 8, 21];
var sensitiveStringType = [0, n0, _sST, 8, 0];
exports.ActiveTrustedKeyGroups$ = [3, n0, _ATKG,
    0,
    [_E, _Q, _I],
    [2, 1, [() => KGKeyPairIdsList, 0]], 2
];
exports.ActiveTrustedSigners$ = [3, n0, _ATS,
    0,
    [_E, _Q, _I],
    [2, 1, [() => SignerList, 0]], 2
];
exports.Aliases$ = [3, n0, _A,
    0,
    [_Q, _I],
    [1, [() => AliasList, 0]], 1
];
exports.AliasICPRecordal$ = [3, n0, _AICPR,
    0,
    [_CNAME, _ICPRS],
    [0, 0]
];
exports.AllowedMethods$ = [3, n0, _AM,
    0,
    [_Q, _I, _CM],
    [1, [() => MethodsList, 0], [() => exports.CachedMethods$, 0]], 2
];
exports.AnycastIpList$ = [3, n0, _AIL,
    0,
    [_Id, _N, _S, _Ar, _AI, _IC, _LMT, _IAT, _ICp],
    [0, 0, 0, 0, [() => AnycastIps, 0], 1, 4, 0, [() => exports.IpamConfig$, 0]], 7
];
exports.AnycastIpListCollection$ = [3, n0, _AILC,
    0,
    [_Ma, _MI, _ITs, _Q, _I, _NM],
    [0, 1, 2, 1, [() => AnycastIpListSummaries, 0], 0], 4
];
exports.AnycastIpListSummary$ = [3, n0, _AILS,
    0,
    [_Id, _N, _S, _Ar, _IC, _LMT, _IAT, _ET, _ICp],
    [0, 0, 0, 0, 1, 4, 0, 0, [() => exports.IpamConfig$, 0]], 6
];
exports.AssociateAliasRequest$ = [3, n0, _AAR,
    0,
    [_TDI, _Al],
    [[0, 1], [0, { [_hQ]: _Al }]], 2
];
exports.AssociateDistributionTenantWebACLRequest$ = [3, n0, _ADTWACLR,
    0,
    [_Id, _WACLA, _IM],
    [[0, 1], 0, [0, { [_hH]: _IM_ }]], 2
];
exports.AssociateDistributionTenantWebACLResult$ = [3, n0, _ADTWACLRs,
    0,
    [_Id, _WACLA, _ET],
    [0, 0, [0, { [_hH]: _ET }]]
];
exports.AssociateDistributionWebACLRequest$ = [3, n0, _ADWACLR,
    0,
    [_Id, _WACLA, _IM],
    [[0, 1], 0, [0, { [_hH]: _IM_ }]], 2
];
exports.AssociateDistributionWebACLResult$ = [3, n0, _ADWACLRs,
    0,
    [_Id, _WACLA, _ET],
    [0, 0, [0, { [_hH]: _ET }]]
];
exports.CaCertificatesBundleS3Location$ = [3, n0, _CCBSL,
    0,
    [_B, _K, _R, _V],
    [0, 0, 0, 0], 3
];
exports.CacheBehavior$ = [3, n0, _CB,
    0,
    [_PP, _TOI, _VPP, _TS, _TKG, _AM, _SS, _C, _LFA, _FA, _FLEI, _RLCA, _CPI, _ORPI, _RHPI, _GC, _FV, _MTTL, _DTTL, _MTTLa],
    [0, 0, 0, [() => exports.TrustedSigners$, 0], [() => exports.TrustedKeyGroups$, 0], [() => exports.AllowedMethods$, 0], 2, 2, [() => exports.LambdaFunctionAssociations$, 0], [() => exports.FunctionAssociations$, 0], 0, 0, 0, 0, 0, () => exports.GrpcConfig$, [() => exports.ForwardedValues$, 0], 1, 1, 1], 3
];
exports.CacheBehaviors$ = [3, n0, _CBa,
    0,
    [_Q, _I],
    [1, [() => CacheBehaviorList, 0]], 1
];
exports.CachedMethods$ = [3, n0, _CM,
    0,
    [_Q, _I],
    [1, [() => MethodsList, 0]], 2
];
exports.CachePolicy$ = [3, n0, _CP,
    0,
    [_Id, _LMT, _CPC],
    [0, 4, [() => exports.CachePolicyConfig$, 0]], 3
];
exports.CachePolicyConfig$ = [3, n0, _CPC,
    0,
    [_N, _MTTL, _Co, _DTTL, _MTTLa, _PICKAFTO],
    [0, 1, 0, 1, 1, [() => exports.ParametersInCacheKeyAndForwardedToOrigin$, 0]], 2
];
exports.CachePolicyCookiesConfig$ = [3, n0, _CPCC,
    0,
    [_CBo, _Coo],
    [0, [() => exports.CookieNames$, 0]], 1
];
exports.CachePolicyHeadersConfig$ = [3, n0, _CPHC,
    0,
    [_HB, _H],
    [0, [() => exports.Headers$, 0]], 1
];
exports.CachePolicyList$ = [3, n0, _CPL,
    0,
    [_MI, _Q, _NM, _I],
    [1, 1, 0, [() => CachePolicySummaryList, 0]], 2
];
exports.CachePolicyQueryStringsConfig$ = [3, n0, _CPQSC,
    0,
    [_QSB, _QS],
    [0, [() => exports.QueryStringNames$, 0]], 1
];
exports.CachePolicySummary$ = [3, n0, _CPS,
    0,
    [_T, _CP],
    [0, [() => exports.CachePolicy$, 0]], 2
];
exports.Certificate$ = [3, n0, _Ce,
    0,
    [_Ar],
    [0], 1
];
exports.CloudFrontOriginAccessIdentity$ = [3, n0, _CFOAI,
    0,
    [_Id, _SCUI, _CFOAIC],
    [0, 0, () => exports.CloudFrontOriginAccessIdentityConfig$], 2
];
exports.CloudFrontOriginAccessIdentityConfig$ = [3, n0, _CFOAIC,
    0,
    [_CR, _Co],
    [0, 0], 2
];
exports.CloudFrontOriginAccessIdentityList$ = [3, n0, _CFOAIL,
    0,
    [_Ma, _MI, _ITs, _Q, _NM, _I],
    [0, 1, 2, 1, 0, [() => CloudFrontOriginAccessIdentitySummaryList, 0]], 4
];
exports.CloudFrontOriginAccessIdentitySummary$ = [3, n0, _CFOAIS,
    0,
    [_Id, _SCUI, _Co],
    [0, 0, 0], 3
];
exports.ConflictingAlias$ = [3, n0, _CA,
    0,
    [_Al, _DI, _AIc],
    [0, 0, 0]
];
exports.ConflictingAliasesList$ = [3, n0, _CAL,
    0,
    [_NM, _MI, _Q, _I],
    [0, 1, 1, [() => ConflictingAliases, 0]]
];
exports.ConnectionFunctionAssociation$ = [3, n0, _CFA,
    0,
    [_Id],
    [0], 1
];
exports.ConnectionFunctionSummary$ = [3, n0, _CFS,
    0,
    [_N, _Id, _CFC, _CFAo, _S, _St, _CTr, _LMT],
    [0, 0, [() => exports.FunctionConfig$, 0], 0, 0, 0, 4, 4], 8
];
exports.ConnectionFunctionTestResult$ = [3, n0, _CFTR,
    0,
    [_CFS, _CU, _CFEL, _CFEM, _CFO],
    [[() => exports.ConnectionFunctionSummary$, 0], 0, [() => FunctionExecutionLogList, 0], [() => sensitiveStringType, 0], [() => sensitiveStringType, 0]]
];
exports.ConnectionGroup$ = [3, n0, _CG,
    0,
    [_Id, _N, _Ar, _CTr, _LMT, _Ta, _IE, _RE, _AILI, _S, _E, _IDs],
    [0, 0, 0, 4, 4, [() => exports.Tags$, 0], 2, 0, 0, 0, 2, 2]
];
exports.ConnectionGroupAssociationFilter$ = [3, n0, _CGAF,
    0,
    [_AILI],
    [0]
];
exports.ConnectionGroupSummary$ = [3, n0, _CGS,
    0,
    [_Id, _N, _Ar, _RE, _CTr, _LMT, _ET, _AILI, _E, _S, _IDs],
    [0, 0, 0, 0, 4, 4, 0, 0, 2, 0, 2], 7
];
exports.ContentTypeProfile$ = [3, n0, _CTP,
    0,
    [_F, _CTo, _PI],
    [0, 0, 0], 2
];
exports.ContentTypeProfileConfig$ = [3, n0, _CTPC,
    0,
    [_FWCTIU, _CTPo],
    [2, [() => exports.ContentTypeProfiles$, 0]], 1
];
exports.ContentTypeProfiles$ = [3, n0, _CTPo,
    0,
    [_Q, _I],
    [1, [() => ContentTypeProfileList, 0]], 1
];
exports.ContinuousDeploymentPolicy$ = [3, n0, _CDP,
    0,
    [_Id, _LMT, _CDPC],
    [0, 4, [() => exports.ContinuousDeploymentPolicyConfig$, 0]], 3
];
exports.ContinuousDeploymentPolicyConfig$ = [3, n0, _CDPC,
    0,
    [_SDDN, _E, _TC],
    [[() => exports.StagingDistributionDnsNames$, 0], 2, () => exports.TrafficConfig$], 2
];
exports.ContinuousDeploymentPolicyList$ = [3, n0, _CDPL,
    0,
    [_MI, _Q, _NM, _I],
    [1, 1, 0, [() => ContinuousDeploymentPolicySummaryList, 0]], 2
];
exports.ContinuousDeploymentPolicySummary$ = [3, n0, _CDPS,
    0,
    [_CDP],
    [[() => exports.ContinuousDeploymentPolicy$, 0]], 1
];
exports.ContinuousDeploymentSingleHeaderConfig$ = [3, n0, _CDSHC,
    0,
    [_He, _Va],
    [0, 0], 2
];
exports.ContinuousDeploymentSingleWeightConfig$ = [3, n0, _CDSWC,
    0,
    [_W, _SSC],
    [1, () => exports.SessionStickinessConfig$], 1
];
exports.CookieNames$ = [3, n0, _CN,
    0,
    [_Q, _I],
    [1, [() => CookieNameList, 0]], 1
];
exports.CookiePreference$ = [3, n0, _CPo,
    0,
    [_Fo, _WN],
    [0, [() => exports.CookieNames$, 0]], 1
];
exports.CopyDistributionRequest$ = [3, n0, _CDR,
    0,
    [_PDI, _CR, _Sta, _IM, _E],
    [[0, 1], 0, [2, { [_hH]: _Sta }], [0, { [_hH]: _IM_ }], 2], 2
];
exports.CopyDistributionResult$ = [3, n0, _CDRo,
    0,
    [_D, _L, _ET],
    [[() => exports.Distribution$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreateAnycastIpListRequest$ = [3, n0, _CAILR,
    0,
    [_N, _IC, _Ta, _IAT, _ICC],
    [0, 1, [() => exports.Tags$, 0], 0, [() => IpamCidrConfigList, 0]], 2
];
exports.CreateAnycastIpListResult$ = [3, n0, _CAILRr,
    0,
    [_AIL, _ET],
    [[() => exports.AnycastIpList$, 16], [0, { [_hH]: _ET }]]
];
exports.CreateCachePolicyRequest$ = [3, n0, _CCPR,
    0,
    [_CPC],
    [[() => exports.CachePolicyConfig$, { [_hP]: 1, [_xN]: _CPC }]], 1
];
exports.CreateCachePolicyResult$ = [3, n0, _CCPRr,
    0,
    [_CP, _L, _ET],
    [[() => exports.CachePolicy$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreateCloudFrontOriginAccessIdentityRequest$ = [3, n0, _CCFOAIR,
    0,
    [_CFOAIC],
    [[() => exports.CloudFrontOriginAccessIdentityConfig$, { [_hP]: 1, [_xN]: _CFOAIC }]], 1
];
exports.CreateCloudFrontOriginAccessIdentityResult$ = [3, n0, _CCFOAIRr,
    0,
    [_CFOAI, _L, _ET],
    [[() => exports.CloudFrontOriginAccessIdentity$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreateConnectionFunctionRequest$ = [3, n0, _CCFR,
    0,
    [_N, _CFC, _CFCo, _Ta],
    [0, [() => exports.FunctionConfig$, 0], [() => FunctionBlob, 0], [() => exports.Tags$, 0]], 3
];
exports.CreateConnectionFunctionResult$ = [3, n0, _CCFRr,
    0,
    [_CFS, _L, _ET],
    [[() => exports.ConnectionFunctionSummary$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreateConnectionGroupRequest$ = [3, n0, _CCGR,
    0,
    [_N, _IE, _Ta, _AILI, _E],
    [0, 2, [() => exports.Tags$, 0], 0, 2], 1
];
exports.CreateConnectionGroupResult$ = [3, n0, _CCGRr,
    0,
    [_CG, _ET],
    [[() => exports.ConnectionGroup$, 16], [0, { [_hH]: _ET }]]
];
exports.CreateContinuousDeploymentPolicyRequest$ = [3, n0, _CCDPR,
    0,
    [_CDPC],
    [[() => exports.ContinuousDeploymentPolicyConfig$, { [_hP]: 1, [_xN]: _CDPC }]], 1
];
exports.CreateContinuousDeploymentPolicyResult$ = [3, n0, _CCDPRr,
    0,
    [_CDP, _L, _ET],
    [[() => exports.ContinuousDeploymentPolicy$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreateDistributionRequest$ = [3, n0, _CDRr,
    0,
    [_DC],
    [[() => exports.DistributionConfig$, { [_hP]: 1, [_xN]: _DC }]], 1
];
exports.CreateDistributionResult$ = [3, n0, _CDRre,
    0,
    [_D, _L, _ET],
    [[() => exports.Distribution$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreateDistributionTenantRequest$ = [3, n0, _CDTR,
    0,
    [_DI, _N, _Do, _Ta, _Cu, _P, _CGI, _MCR, _E],
    [0, 0, () => DomainList, [() => exports.Tags$, 0], [() => exports.Customizations$, 0], () => _Parameters, 0, () => exports.ManagedCertificateRequest$, 2], 3
];
exports.CreateDistributionTenantResult$ = [3, n0, _CDTRr,
    0,
    [_DT, _ET],
    [[() => exports.DistributionTenant$, 16], [0, { [_hH]: _ET }]]
];
exports.CreateDistributionWithTagsRequest$ = [3, n0, _CDWTR,
    0,
    [_DCWT],
    [[() => exports.DistributionConfigWithTags$, { [_hP]: 1, [_xN]: _DCWT }]], 1
];
exports.CreateDistributionWithTagsResult$ = [3, n0, _CDWTRr,
    0,
    [_D, _L, _ET],
    [[() => exports.Distribution$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreateFieldLevelEncryptionConfigRequest$ = [3, n0, _CFLECR,
    0,
    [_FLEC],
    [[() => exports.FieldLevelEncryptionConfig$, { [_hP]: 1, [_xN]: _FLEC }]], 1
];
exports.CreateFieldLevelEncryptionConfigResult$ = [3, n0, _CFLECRr,
    0,
    [_FLE, _L, _ET],
    [[() => exports.FieldLevelEncryption$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreateFieldLevelEncryptionProfileRequest$ = [3, n0, _CFLEPR,
    0,
    [_FLEPC],
    [[() => exports.FieldLevelEncryptionProfileConfig$, { [_hP]: 1, [_xN]: _FLEPC }]], 1
];
exports.CreateFieldLevelEncryptionProfileResult$ = [3, n0, _CFLEPRr,
    0,
    [_FLEP, _L, _ET],
    [[() => exports.FieldLevelEncryptionProfile$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreateFunctionRequest$ = [3, n0, _CFR,
    0,
    [_N, _FC, _FCu],
    [0, [() => exports.FunctionConfig$, 0], [() => FunctionBlob, 0]], 3
];
exports.CreateFunctionResult$ = [3, n0, _CFRr,
    0,
    [_FS, _L, _ET],
    [[() => exports.FunctionSummary$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreateInvalidationForDistributionTenantRequest$ = [3, n0, _CIFDTR,
    0,
    [_Id, _IB],
    [[0, 1], [() => exports.InvalidationBatch$, { [_hP]: 1, [_xN]: _IB }]], 2
];
exports.CreateInvalidationForDistributionTenantResult$ = [3, n0, _CIFDTRr,
    0,
    [_L, _In],
    [[0, { [_hH]: _L }], [() => exports.Invalidation$, 16]]
];
exports.CreateInvalidationRequest$ = [3, n0, _CIR,
    0,
    [_DI, _IB],
    [[0, 1], [() => exports.InvalidationBatch$, { [_hP]: 1, [_xN]: _IB }]], 2
];
exports.CreateInvalidationResult$ = [3, n0, _CIRr,
    0,
    [_L, _In],
    [[0, { [_hH]: _L }], [() => exports.Invalidation$, 16]]
];
exports.CreateKeyGroupRequest$ = [3, n0, _CKGR,
    0,
    [_KGC],
    [[() => exports.KeyGroupConfig$, { [_hP]: 1, [_xN]: _KGC }]], 1
];
exports.CreateKeyGroupResult$ = [3, n0, _CKGRr,
    0,
    [_KG, _L, _ET],
    [[() => exports.KeyGroup$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreateKeyValueStoreRequest$ = [3, n0, _CKVSR,
    0,
    [_N, _Co, _IS],
    [0, 0, () => exports.ImportSource$], 1
];
exports.CreateKeyValueStoreResult$ = [3, n0, _CKVSRr,
    0,
    [_KVS, _ET, _L],
    [[() => exports.KeyValueStore$, 16], [0, { [_hH]: _ET }], [0, { [_hH]: _L }]]
];
exports.CreateMonitoringSubscriptionRequest$ = [3, n0, _CMSR,
    0,
    [_DI, _MS],
    [[0, 1], [() => exports.MonitoringSubscription$, { [_hP]: 1, [_xN]: _MS }]], 2
];
exports.CreateMonitoringSubscriptionResult$ = [3, n0, _CMSRr,
    0,
    [_MS],
    [[() => exports.MonitoringSubscription$, 16]]
];
exports.CreateOriginAccessControlRequest$ = [3, n0, _COACR,
    0,
    [_OACC],
    [[() => exports.OriginAccessControlConfig$, { [_hP]: 1, [_xN]: _OACC }]], 1
];
exports.CreateOriginAccessControlResult$ = [3, n0, _COACRr,
    0,
    [_OAC, _L, _ET],
    [[() => exports.OriginAccessControl$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreateOriginRequestPolicyRequest$ = [3, n0, _CORPR,
    0,
    [_ORPC],
    [[() => exports.OriginRequestPolicyConfig$, { [_hP]: 1, [_xN]: _ORPC }]], 1
];
exports.CreateOriginRequestPolicyResult$ = [3, n0, _CORPRr,
    0,
    [_ORP, _L, _ET],
    [[() => exports.OriginRequestPolicy$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreatePublicKeyRequest$ = [3, n0, _CPKR,
    0,
    [_PKC],
    [[() => exports.PublicKeyConfig$, { [_hP]: 1, [_xN]: _PKC }]], 1
];
exports.CreatePublicKeyResult$ = [3, n0, _CPKRr,
    0,
    [_PK, _L, _ET],
    [[() => exports.PublicKey$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreateRealtimeLogConfigRequest$ = [3, n0, _CRLCR,
    0,
    [_EP, _Fi, _N, _SR],
    [() => EndPointList, [() => FieldList, 0], 0, 1], 4
];
exports.CreateRealtimeLogConfigResult$ = [3, n0, _CRLCRr,
    0,
    [_RLC],
    [[() => exports.RealtimeLogConfig$, 0]]
];
exports.CreateResponseHeadersPolicyRequest$ = [3, n0, _CRHPR,
    0,
    [_RHPC],
    [[() => exports.ResponseHeadersPolicyConfig$, { [_hP]: 1, [_xN]: _RHPC }]], 1
];
exports.CreateResponseHeadersPolicyResult$ = [3, n0, _CRHPRr,
    0,
    [_RHP, _L, _ET],
    [[() => exports.ResponseHeadersPolicy$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreateStreamingDistributionRequest$ = [3, n0, _CSDR,
    0,
    [_SDC],
    [[() => exports.StreamingDistributionConfig$, { [_hP]: 1, [_xN]: _SDC }]], 1
];
exports.CreateStreamingDistributionResult$ = [3, n0, _CSDRr,
    0,
    [_SD, _L, _ET],
    [[() => exports.StreamingDistribution$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreateStreamingDistributionWithTagsRequest$ = [3, n0, _CSDWTR,
    0,
    [_SDCWT],
    [[() => exports.StreamingDistributionConfigWithTags$, { [_hP]: 1, [_xN]: _SDCWT }]], 1
];
exports.CreateStreamingDistributionWithTagsResult$ = [3, n0, _CSDWTRr,
    0,
    [_SD, _L, _ET],
    [[() => exports.StreamingDistribution$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CreateTrustStoreRequest$ = [3, n0, _CTSR,
    0,
    [_N, _CCBS, _Ta],
    [0, () => exports.CaCertificatesBundleSource$, [() => exports.Tags$, 0]], 2
];
exports.CreateTrustStoreResult$ = [3, n0, _CTSRr,
    0,
    [_TSr, _ET],
    [[() => exports.TrustStore$, 16], [0, { [_hH]: _ET }]]
];
exports.CreateVpcOriginRequest$ = [3, n0, _CVOR,
    0,
    [_VOEC, _Ta],
    [[() => exports.VpcOriginEndpointConfig$, 0], [() => exports.Tags$, 0]], 1
];
exports.CreateVpcOriginResult$ = [3, n0, _CVORr,
    0,
    [_VO, _L, _ET],
    [[() => exports.VpcOrigin$, 16], [0, { [_hH]: _L }], [0, { [_hH]: _ET }]]
];
exports.CustomErrorResponse$ = [3, n0, _CER,
    0,
    [_EC, _RPP, _RC, _ECMTTL],
    [1, 0, 0, 1], 1
];
exports.CustomErrorResponses$ = [3, n0, _CERu,
    0,
    [_Q, _I],
    [1, [() => CustomErrorResponseList, 0]], 1
];
exports.CustomHeaders$ = [3, n0, _CH,
    0,
    [_Q, _I],
    [1, [() => OriginCustomHeadersList, 0]], 1
];
exports.Customizations$ = [3, n0, _Cu,
    0,
    [_WA, _Ce, _GR],
    [() => exports.WebAclCustomization$, () => exports.Certificate$, [() => exports.GeoRestrictionCustomization$, 0]]
];
exports.CustomOriginConfig$ = [3, n0, _COC,
    0,
    [_HTTPP, _HTTPSP, _OPP, _OSP, _ORT, _OKT, _IAT, _OMC],
    [1, 1, 0, [() => exports.OriginSslProtocols$, 0], 1, 1, 0, () => exports.OriginMtlsConfig$], 3
];
exports.DefaultCacheBehavior$ = [3, n0, _DCB,
    0,
    [_TOI, _VPP, _TS, _TKG, _AM, _SS, _C, _LFA, _FA, _FLEI, _RLCA, _CPI, _ORPI, _RHPI, _GC, _FV, _MTTL, _DTTL, _MTTLa],
    [0, 0, [() => exports.TrustedSigners$, 0], [() => exports.TrustedKeyGroups$, 0], [() => exports.AllowedMethods$, 0], 2, 2, [() => exports.LambdaFunctionAssociations$, 0], [() => exports.FunctionAssociations$, 0], 0, 0, 0, 0, 0, () => exports.GrpcConfig$, [() => exports.ForwardedValues$, 0], 1, 1, 1], 2
];
exports.DeleteAnycastIpListRequest$ = [3, n0, _DAILR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.DeleteCachePolicyRequest$ = [3, n0, _DCPR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 1
];
exports.DeleteCloudFrontOriginAccessIdentityRequest$ = [3, n0, _DCFOAIR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 1
];
exports.DeleteConnectionFunctionRequest$ = [3, n0, _DCFR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.DeleteConnectionGroupRequest$ = [3, n0, _DCGR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.DeleteContinuousDeploymentPolicyRequest$ = [3, n0, _DCDPR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 1
];
exports.DeleteDistributionRequest$ = [3, n0, _DDR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 1
];
exports.DeleteDistributionTenantRequest$ = [3, n0, _DDTR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.DeleteFieldLevelEncryptionConfigRequest$ = [3, n0, _DFLECR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 1
];
exports.DeleteFieldLevelEncryptionProfileRequest$ = [3, n0, _DFLEPR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 1
];
exports.DeleteFunctionRequest$ = [3, n0, _DFR,
    0,
    [_N, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.DeleteKeyGroupRequest$ = [3, n0, _DKGR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 1
];
exports.DeleteKeyValueStoreRequest$ = [3, n0, _DKVSR,
    0,
    [_N, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.DeleteMonitoringSubscriptionRequest$ = [3, n0, _DMSR,
    0,
    [_DI],
    [[0, 1]], 1
];
exports.DeleteMonitoringSubscriptionResult$ = [3, n0, _DMSRe,
    0,
    [],
    []
];
exports.DeleteOriginAccessControlRequest$ = [3, n0, _DOACR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 1
];
exports.DeleteOriginRequestPolicyRequest$ = [3, n0, _DORPR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 1
];
exports.DeletePublicKeyRequest$ = [3, n0, _DPKR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 1
];
exports.DeleteRealtimeLogConfigRequest$ = [3, n0, _DRLCR,
    0,
    [_N, _ARN],
    [0, 0]
];
exports.DeleteResourcePolicyRequest$ = [3, n0, _DRPR,
    0,
    [_RA],
    [0], 1
];
exports.DeleteResponseHeadersPolicyRequest$ = [3, n0, _DRHPR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 1
];
exports.DeleteStreamingDistributionRequest$ = [3, n0, _DSDR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 1
];
exports.DeleteTrustStoreRequest$ = [3, n0, _DTSR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.DeleteVpcOriginRequest$ = [3, n0, _DVOR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.DeleteVpcOriginResult$ = [3, n0, _DVORe,
    0,
    [_VO, _ET],
    [[() => exports.VpcOrigin$, 16], [0, { [_hH]: _ET }]]
];
exports.DescribeConnectionFunctionRequest$ = [3, n0, _DCFRe,
    0,
    [_Ide, _St],
    [[0, 1], [0, { [_hQ]: _St }]], 1
];
exports.DescribeConnectionFunctionResult$ = [3, n0, _DCFRes,
    0,
    [_CFS, _ET],
    [[() => exports.ConnectionFunctionSummary$, 16], [0, { [_hH]: _ET }]]
];
exports.DescribeFunctionRequest$ = [3, n0, _DFRe,
    0,
    [_N, _St],
    [[0, 1], [0, { [_hQ]: _St }]], 1
];
exports.DescribeFunctionResult$ = [3, n0, _DFRes,
    0,
    [_FS, _ET],
    [[() => exports.FunctionSummary$, 16], [0, { [_hH]: _ET }]]
];
exports.DescribeKeyValueStoreRequest$ = [3, n0, _DKVSRe,
    0,
    [_N],
    [[0, 1]], 1
];
exports.DescribeKeyValueStoreResult$ = [3, n0, _DKVSRes,
    0,
    [_KVS, _ET],
    [[() => exports.KeyValueStore$, 16], [0, { [_hH]: _ET }]]
];
exports.DisassociateDistributionTenantWebACLRequest$ = [3, n0, _DDTWACLR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 1
];
exports.DisassociateDistributionTenantWebACLResult$ = [3, n0, _DDTWACLRi,
    0,
    [_Id, _ET],
    [0, [0, { [_hH]: _ET }]]
];
exports.DisassociateDistributionWebACLRequest$ = [3, n0, _DDWACLR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 1
];
exports.DisassociateDistributionWebACLResult$ = [3, n0, _DDWACLRi,
    0,
    [_Id, _ET],
    [0, [0, { [_hH]: _ET }]]
];
exports.Distribution$ = [3, n0, _D,
    0,
    [_Id, _ARN, _S, _LMT, _IPIB, _DN, _DC, _ATS, _ATKG, _AICPRl],
    [0, 0, 0, 4, 1, 0, [() => exports.DistributionConfig$, 0], [() => exports.ActiveTrustedSigners$, 0], [() => exports.ActiveTrustedKeyGroups$, 0], [() => AliasICPRecordals, 0]], 7
];
exports.DistributionConfig$ = [3, n0, _DC,
    0,
    [_CR, _O, _DCB, _Co, _E, _A, _DRO, _OG, _CBa, _CERu, _Lo, _PC, _VC, _Re, _WACLI, _HV, _IIPVE, _CDPI, _Sta, _AILI, _TCe, _CMo, _VMC, _CFA],
    [0, [() => exports.Origins$, 0], [() => exports.DefaultCacheBehavior$, 0], [() => CommentType, 0], 2, [() => exports.Aliases$, 0], 0, [() => exports.OriginGroups$, 0], [() => exports.CacheBehaviors$, 0], [() => exports.CustomErrorResponses$, 0], () => exports.LoggingConfig$, 0, () => exports.ViewerCertificate$, [() => exports.Restrictions$, 0], 0, 0, 2, 0, 2, 0, [() => exports.TenantConfig$, 0], 0, () => exports.ViewerMtlsConfig$, () => exports.ConnectionFunctionAssociation$], 5
];
exports.DistributionConfigWithTags$ = [3, n0, _DCWT,
    0,
    [_DC, _Ta],
    [[() => exports.DistributionConfig$, 0], [() => exports.Tags$, 0]], 2
];
exports.DistributionIdList$ = [3, n0, _DIL,
    0,
    [_Ma, _MI, _ITs, _Q, _NM, _I],
    [0, 1, 2, 1, 0, [() => DistributionIdListSummary, 0]], 4
];
exports.DistributionIdOwner$ = [3, n0, _DIO,
    0,
    [_DI, _OAI],
    [0, 0], 2
];
exports.DistributionIdOwnerList$ = [3, n0, _DIOL,
    0,
    [_Ma, _MI, _ITs, _Q, _NM, _I],
    [0, 1, 2, 1, 0, [() => DistributionIdOwnerItemList, 0]], 4
];
exports.DistributionList$ = [3, n0, _DL,
    0,
    [_Ma, _MI, _ITs, _Q, _NM, _I],
    [0, 1, 2, 1, 0, [() => DistributionSummaryList, 0]], 4
];
exports.DistributionResourceId$ = [3, n0, _DRI,
    0,
    [_DI, _DTI],
    [0, 0]
];
exports.DistributionSummary$ = [3, n0, _DS,
    0,
    [_Id, _ARN, _S, _LMT, _DN, _A, _O, _DCB, _CBa, _CERu, _Co, _PC, _E, _VC, _Re, _WACLI, _HV, _IIPVE, _Sta, _ET, _OG, _AICPRl, _CMo, _AILI, _VMC, _CFA],
    [0, 0, 0, 4, 0, [() => exports.Aliases$, 0], [() => exports.Origins$, 0], [() => exports.DefaultCacheBehavior$, 0], [() => exports.CacheBehaviors$, 0], [() => exports.CustomErrorResponses$, 0], [() => sensitiveStringType, 0], 0, 2, () => exports.ViewerCertificate$, [() => exports.Restrictions$, 0], 0, 0, 2, 2, 0, [() => exports.OriginGroups$, 0], [() => AliasICPRecordals, 0], 0, 0, () => exports.ViewerMtlsConfig$, () => exports.ConnectionFunctionAssociation$], 19
];
exports.DistributionTenant$ = [3, n0, _DT,
    0,
    [_Id, _DI, _N, _Ar, _Do, _Ta, _Cu, _P, _CGI, _CTr, _LMT, _E, _S],
    [0, 0, 0, 0, () => DomainResultList, [() => exports.Tags$, 0], [() => exports.Customizations$, 0], () => _Parameters, 0, 4, 4, 2, 0]
];
exports.DistributionTenantAssociationFilter$ = [3, n0, _DTAF,
    0,
    [_DI, _CGI],
    [0, 0]
];
exports.DistributionTenantSummary$ = [3, n0, _DTS,
    0,
    [_Id, _DI, _N, _Ar, _Do, _CTr, _LMT, _ET, _CGI, _Cu, _E, _S],
    [0, 0, 0, 0, () => DomainResultList, 4, 4, 0, 0, [() => exports.Customizations$, 0], 2, 0], 8
];
exports.DnsConfiguration$ = [3, n0, _DCn,
    0,
    [_Dom, _S, _Rea],
    [0, 0, 0], 2
];
exports.DomainConflict$ = [3, n0, _DCo,
    0,
    [_Dom, _RT, _RI, _AIc],
    [0, 0, 0, 0], 4
];
exports.DomainItem$ = [3, n0, _DIo,
    0,
    [_Dom],
    [0], 1
];
exports.DomainResult$ = [3, n0, _DR,
    0,
    [_Dom, _S],
    [0, 0], 1
];
exports.EncryptionEntities$ = [3, n0, _EE,
    0,
    [_Q, _I],
    [1, [() => EncryptionEntityList, 0]], 1
];
exports.EncryptionEntity$ = [3, n0, _EEn,
    0,
    [_PKI, _PIr, _FP],
    [0, 0, [() => exports.FieldPatterns$, 0]], 3
];
exports.EndPoint$ = [3, n0, _EPn,
    0,
    [_ST, _KSC],
    [0, () => exports.KinesisStreamConfig$], 1
];
exports.FieldLevelEncryption$ = [3, n0, _FLE,
    0,
    [_Id, _LMT, _FLEC],
    [0, 4, [() => exports.FieldLevelEncryptionConfig$, 0]], 3
];
exports.FieldLevelEncryptionConfig$ = [3, n0, _FLEC,
    0,
    [_CR, _Co, _QAPC, _CTPC],
    [0, 0, [() => exports.QueryArgProfileConfig$, 0], [() => exports.ContentTypeProfileConfig$, 0]], 1
];
exports.FieldLevelEncryptionList$ = [3, n0, _FLEL,
    0,
    [_MI, _Q, _NM, _I],
    [1, 1, 0, [() => FieldLevelEncryptionSummaryList, 0]], 2
];
exports.FieldLevelEncryptionProfile$ = [3, n0, _FLEP,
    0,
    [_Id, _LMT, _FLEPC],
    [0, 4, [() => exports.FieldLevelEncryptionProfileConfig$, 0]], 3
];
exports.FieldLevelEncryptionProfileConfig$ = [3, n0, _FLEPC,
    0,
    [_N, _CR, _EE, _Co],
    [0, 0, [() => exports.EncryptionEntities$, 0], 0], 3
];
exports.FieldLevelEncryptionProfileList$ = [3, n0, _FLEPL,
    0,
    [_MI, _Q, _NM, _I],
    [1, 1, 0, [() => FieldLevelEncryptionProfileSummaryList, 0]], 2
];
exports.FieldLevelEncryptionProfileSummary$ = [3, n0, _FLEPS,
    0,
    [_Id, _LMT, _N, _EE, _Co],
    [0, 4, 0, [() => exports.EncryptionEntities$, 0], 0], 4
];
exports.FieldLevelEncryptionSummary$ = [3, n0, _FLES,
    0,
    [_Id, _LMT, _Co, _QAPC, _CTPC],
    [0, 4, 0, [() => exports.QueryArgProfileConfig$, 0], [() => exports.ContentTypeProfileConfig$, 0]], 2
];
exports.FieldPatterns$ = [3, n0, _FP,
    0,
    [_Q, _I],
    [1, [() => FieldPatternList, 0]], 1
];
exports.ForwardedValues$ = [3, n0, _FV,
    0,
    [_QSu, _Coo, _H, _QSCK],
    [2, [() => exports.CookiePreference$, 0], [() => exports.Headers$, 0], [() => exports.QueryStringCacheKeys$, 0]], 2
];
exports.FunctionAssociation$ = [3, n0, _FAu,
    0,
    [_FARN, _ETv],
    [0, 0], 2
];
exports.FunctionAssociations$ = [3, n0, _FA,
    0,
    [_Q, _I],
    [1, [() => FunctionAssociationList, 0]], 1
];
exports.FunctionConfig$ = [3, n0, _FC,
    0,
    [_Co, _Ru, _KVSA],
    [0, 0, [() => exports.KeyValueStoreAssociations$, 0]], 2
];
exports.FunctionList$ = [3, n0, _FL,
    0,
    [_MI, _Q, _NM, _I],
    [1, 1, 0, [() => FunctionSummaryList, 0]], 2
];
exports.FunctionMetadata$ = [3, n0, _FM,
    0,
    [_FARN, _LMT, _St, _CTr],
    [0, 4, 0, 4], 2
];
exports.FunctionSummary$ = [3, n0, _FS,
    0,
    [_N, _FC, _FM, _S],
    [0, [() => exports.FunctionConfig$, 0], () => exports.FunctionMetadata$, 0], 3
];
exports.GeoRestriction$ = [3, n0, _GRe,
    0,
    [_RTe, _Q, _I],
    [0, 1, [() => LocationList, 0]], 2
];
exports.GeoRestrictionCustomization$ = [3, n0, _GRC,
    0,
    [_RTe, _Loc],
    [0, [() => LocationList, 0]], 1
];
exports.GetAnycastIpListRequest$ = [3, n0, _GAILR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetAnycastIpListResult$ = [3, n0, _GAILRe,
    0,
    [_AIL, _ET],
    [[() => exports.AnycastIpList$, 16], [0, { [_hH]: _ET }]]
];
exports.GetCachePolicyConfigRequest$ = [3, n0, _GCPCR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetCachePolicyConfigResult$ = [3, n0, _GCPCRe,
    0,
    [_CPC, _ET],
    [[() => exports.CachePolicyConfig$, 16], [0, { [_hH]: _ET }]]
];
exports.GetCachePolicyRequest$ = [3, n0, _GCPR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetCachePolicyResult$ = [3, n0, _GCPRe,
    0,
    [_CP, _ET],
    [[() => exports.CachePolicy$, 16], [0, { [_hH]: _ET }]]
];
exports.GetCloudFrontOriginAccessIdentityConfigRequest$ = [3, n0, _GCFOAICR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetCloudFrontOriginAccessIdentityConfigResult$ = [3, n0, _GCFOAICRe,
    0,
    [_CFOAIC, _ET],
    [[() => exports.CloudFrontOriginAccessIdentityConfig$, 16], [0, { [_hH]: _ET }]]
];
exports.GetCloudFrontOriginAccessIdentityRequest$ = [3, n0, _GCFOAIR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetCloudFrontOriginAccessIdentityResult$ = [3, n0, _GCFOAIRe,
    0,
    [_CFOAI, _ET],
    [[() => exports.CloudFrontOriginAccessIdentity$, 16], [0, { [_hH]: _ET }]]
];
exports.GetConnectionFunctionRequest$ = [3, n0, _GCFR,
    0,
    [_Ide, _St],
    [[0, 1], [0, { [_hQ]: _St }]], 1
];
exports.GetConnectionFunctionResult$ = [3, n0, _GCFRe,
    0,
    [_CFCo, _ET, _CTo],
    [[() => FunctionBlob, 16], [0, { [_hH]: _ET }], [0, { [_hH]: _CT_ }]]
];
exports.GetConnectionGroupByRoutingEndpointRequest$ = [3, n0, _GCGBRER,
    0,
    [_RE],
    [[0, { [_hQ]: _RE }]], 1
];
exports.GetConnectionGroupByRoutingEndpointResult$ = [3, n0, _GCGBRERe,
    0,
    [_CG, _ET],
    [[() => exports.ConnectionGroup$, 16], [0, { [_hH]: _ET }]]
];
exports.GetConnectionGroupRequest$ = [3, n0, _GCGR,
    0,
    [_Ide],
    [[0, 1]], 1
];
exports.GetConnectionGroupResult$ = [3, n0, _GCGRe,
    0,
    [_CG, _ET],
    [[() => exports.ConnectionGroup$, 16], [0, { [_hH]: _ET }]]
];
exports.GetContinuousDeploymentPolicyConfigRequest$ = [3, n0, _GCDPCR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetContinuousDeploymentPolicyConfigResult$ = [3, n0, _GCDPCRe,
    0,
    [_CDPC, _ET],
    [[() => exports.ContinuousDeploymentPolicyConfig$, 16], [0, { [_hH]: _ET }]]
];
exports.GetContinuousDeploymentPolicyRequest$ = [3, n0, _GCDPR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetContinuousDeploymentPolicyResult$ = [3, n0, _GCDPRe,
    0,
    [_CDP, _ET],
    [[() => exports.ContinuousDeploymentPolicy$, 16], [0, { [_hH]: _ET }]]
];
exports.GetDistributionConfigRequest$ = [3, n0, _GDCR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetDistributionConfigResult$ = [3, n0, _GDCRe,
    0,
    [_DC, _ET],
    [[() => exports.DistributionConfig$, 16], [0, { [_hH]: _ET }]]
];
exports.GetDistributionRequest$ = [3, n0, _GDR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetDistributionResult$ = [3, n0, _GDRe,
    0,
    [_D, _ET],
    [[() => exports.Distribution$, 16], [0, { [_hH]: _ET }]]
];
exports.GetDistributionTenantByDomainRequest$ = [3, n0, _GDTBDR,
    0,
    [_Dom],
    [[0, { [_hQ]: _d }]], 1
];
exports.GetDistributionTenantByDomainResult$ = [3, n0, _GDTBDRe,
    0,
    [_DT, _ET],
    [[() => exports.DistributionTenant$, 16], [0, { [_hH]: _ET }]]
];
exports.GetDistributionTenantRequest$ = [3, n0, _GDTR,
    0,
    [_Ide],
    [[0, 1]], 1
];
exports.GetDistributionTenantResult$ = [3, n0, _GDTRe,
    0,
    [_DT, _ET],
    [[() => exports.DistributionTenant$, 16], [0, { [_hH]: _ET }]]
];
exports.GetFieldLevelEncryptionConfigRequest$ = [3, n0, _GFLECR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetFieldLevelEncryptionConfigResult$ = [3, n0, _GFLECRe,
    0,
    [_FLEC, _ET],
    [[() => exports.FieldLevelEncryptionConfig$, 16], [0, { [_hH]: _ET }]]
];
exports.GetFieldLevelEncryptionProfileConfigRequest$ = [3, n0, _GFLEPCR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetFieldLevelEncryptionProfileConfigResult$ = [3, n0, _GFLEPCRe,
    0,
    [_FLEPC, _ET],
    [[() => exports.FieldLevelEncryptionProfileConfig$, 16], [0, { [_hH]: _ET }]]
];
exports.GetFieldLevelEncryptionProfileRequest$ = [3, n0, _GFLEPR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetFieldLevelEncryptionProfileResult$ = [3, n0, _GFLEPRe,
    0,
    [_FLEP, _ET],
    [[() => exports.FieldLevelEncryptionProfile$, 16], [0, { [_hH]: _ET }]]
];
exports.GetFieldLevelEncryptionRequest$ = [3, n0, _GFLER,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetFieldLevelEncryptionResult$ = [3, n0, _GFLERe,
    0,
    [_FLE, _ET],
    [[() => exports.FieldLevelEncryption$, 16], [0, { [_hH]: _ET }]]
];
exports.GetFunctionRequest$ = [3, n0, _GFR,
    0,
    [_N, _St],
    [[0, 1], [0, { [_hQ]: _St }]], 1
];
exports.GetFunctionResult$ = [3, n0, _GFRe,
    0,
    [_FCu, _ET, _CTo],
    [[() => FunctionBlob, 16], [0, { [_hH]: _ET }], [0, { [_hH]: _CT_ }]]
];
exports.GetInvalidationForDistributionTenantRequest$ = [3, n0, _GIFDTR,
    0,
    [_DTI, _Id],
    [[0, 1], [0, 1]], 2
];
exports.GetInvalidationForDistributionTenantResult$ = [3, n0, _GIFDTRe,
    0,
    [_In],
    [[() => exports.Invalidation$, 16]]
];
exports.GetInvalidationRequest$ = [3, n0, _GIR,
    0,
    [_DI, _Id],
    [[0, 1], [0, 1]], 2
];
exports.GetInvalidationResult$ = [3, n0, _GIRe,
    0,
    [_In],
    [[() => exports.Invalidation$, 16]]
];
exports.GetKeyGroupConfigRequest$ = [3, n0, _GKGCR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetKeyGroupConfigResult$ = [3, n0, _GKGCRe,
    0,
    [_KGC, _ET],
    [[() => exports.KeyGroupConfig$, 16], [0, { [_hH]: _ET }]]
];
exports.GetKeyGroupRequest$ = [3, n0, _GKGR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetKeyGroupResult$ = [3, n0, _GKGRe,
    0,
    [_KG, _ET],
    [[() => exports.KeyGroup$, 16], [0, { [_hH]: _ET }]]
];
exports.GetManagedCertificateDetailsRequest$ = [3, n0, _GMCDR,
    0,
    [_Ide],
    [[0, 1]], 1
];
exports.GetManagedCertificateDetailsResult$ = [3, n0, _GMCDRe,
    0,
    [_MCD],
    [[() => exports.ManagedCertificateDetails$, 16]]
];
exports.GetMonitoringSubscriptionRequest$ = [3, n0, _GMSR,
    0,
    [_DI],
    [[0, 1]], 1
];
exports.GetMonitoringSubscriptionResult$ = [3, n0, _GMSRe,
    0,
    [_MS],
    [[() => exports.MonitoringSubscription$, 16]]
];
exports.GetOriginAccessControlConfigRequest$ = [3, n0, _GOACCR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetOriginAccessControlConfigResult$ = [3, n0, _GOACCRe,
    0,
    [_OACC, _ET],
    [[() => exports.OriginAccessControlConfig$, 16], [0, { [_hH]: _ET }]]
];
exports.GetOriginAccessControlRequest$ = [3, n0, _GOACR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetOriginAccessControlResult$ = [3, n0, _GOACRe,
    0,
    [_OAC, _ET],
    [[() => exports.OriginAccessControl$, 16], [0, { [_hH]: _ET }]]
];
exports.GetOriginRequestPolicyConfigRequest$ = [3, n0, _GORPCR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetOriginRequestPolicyConfigResult$ = [3, n0, _GORPCRe,
    0,
    [_ORPC, _ET],
    [[() => exports.OriginRequestPolicyConfig$, 16], [0, { [_hH]: _ET }]]
];
exports.GetOriginRequestPolicyRequest$ = [3, n0, _GORPR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetOriginRequestPolicyResult$ = [3, n0, _GORPRe,
    0,
    [_ORP, _ET],
    [[() => exports.OriginRequestPolicy$, 16], [0, { [_hH]: _ET }]]
];
exports.GetPublicKeyConfigRequest$ = [3, n0, _GPKCR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetPublicKeyConfigResult$ = [3, n0, _GPKCRe,
    0,
    [_PKC, _ET],
    [[() => exports.PublicKeyConfig$, 16], [0, { [_hH]: _ET }]]
];
exports.GetPublicKeyRequest$ = [3, n0, _GPKR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetPublicKeyResult$ = [3, n0, _GPKRe,
    0,
    [_PK, _ET],
    [[() => exports.PublicKey$, 16], [0, { [_hH]: _ET }]]
];
exports.GetRealtimeLogConfigRequest$ = [3, n0, _GRLCR,
    0,
    [_N, _ARN],
    [0, 0]
];
exports.GetRealtimeLogConfigResult$ = [3, n0, _GRLCRe,
    0,
    [_RLC],
    [[() => exports.RealtimeLogConfig$, 0]]
];
exports.GetResourcePolicyRequest$ = [3, n0, _GRPR,
    0,
    [_RA],
    [0], 1
];
exports.GetResourcePolicyResult$ = [3, n0, _GRPRe,
    0,
    [_RA, _PD],
    [0, 0]
];
exports.GetResponseHeadersPolicyConfigRequest$ = [3, n0, _GRHPCR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetResponseHeadersPolicyConfigResult$ = [3, n0, _GRHPCRe,
    0,
    [_RHPC, _ET],
    [[() => exports.ResponseHeadersPolicyConfig$, 16], [0, { [_hH]: _ET }]]
];
exports.GetResponseHeadersPolicyRequest$ = [3, n0, _GRHPR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetResponseHeadersPolicyResult$ = [3, n0, _GRHPRe,
    0,
    [_RHP, _ET],
    [[() => exports.ResponseHeadersPolicy$, 16], [0, { [_hH]: _ET }]]
];
exports.GetStreamingDistributionConfigRequest$ = [3, n0, _GSDCR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetStreamingDistributionConfigResult$ = [3, n0, _GSDCRe,
    0,
    [_SDC, _ET],
    [[() => exports.StreamingDistributionConfig$, 16], [0, { [_hH]: _ET }]]
];
exports.GetStreamingDistributionRequest$ = [3, n0, _GSDR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetStreamingDistributionResult$ = [3, n0, _GSDRe,
    0,
    [_SD, _ET],
    [[() => exports.StreamingDistribution$, 16], [0, { [_hH]: _ET }]]
];
exports.GetTrustStoreRequest$ = [3, n0, _GTSR,
    0,
    [_Ide],
    [[0, 1]], 1
];
exports.GetTrustStoreResult$ = [3, n0, _GTSRe,
    0,
    [_TSr, _ET],
    [[() => exports.TrustStore$, 16], [0, { [_hH]: _ET }]]
];
exports.GetVpcOriginRequest$ = [3, n0, _GVOR,
    0,
    [_Id],
    [[0, 1]], 1
];
exports.GetVpcOriginResult$ = [3, n0, _GVORe,
    0,
    [_VO, _ET],
    [[() => exports.VpcOrigin$, 16], [0, { [_hH]: _ET }]]
];
exports.GrpcConfig$ = [3, n0, _GC,
    0,
    [_E],
    [2], 1
];
exports.Headers$ = [3, n0, _H,
    0,
    [_Q, _I],
    [1, [() => HeaderList, 0]], 1
];
exports.ImportSource$ = [3, n0, _IS,
    0,
    [_STo, _SARN],
    [0, 0], 2
];
exports.Invalidation$ = [3, n0, _In,
    0,
    [_Id, _S, _CTre, _IB],
    [0, 0, 4, [() => exports.InvalidationBatch$, 0]], 4
];
exports.InvalidationBatch$ = [3, n0, _IB,
    0,
    [_Pa, _CR],
    [[() => exports.Paths$, 0], 0], 2
];
exports.InvalidationList$ = [3, n0, _IL,
    0,
    [_Ma, _MI, _ITs, _Q, _NM, _I],
    [0, 1, 2, 1, 0, [() => InvalidationSummaryList, 0]], 4
];
exports.InvalidationSummary$ = [3, n0, _ISn,
    0,
    [_Id, _CTre, _S],
    [0, 4, 0], 3
];
exports.IpamCidrConfig$ = [3, n0, _ICCp,
    0,
    [_Ci, _IPA, _AIn, _S],
    [0, 0, 0, 0], 2
];
exports.IpamConfig$ = [3, n0, _ICp,
    0,
    [_Q, _ICC],
    [1, [() => IpamCidrConfigList, 0]], 2
];
exports.KeyGroup$ = [3, n0, _KG,
    0,
    [_Id, _LMT, _KGC],
    [0, 4, [() => exports.KeyGroupConfig$, 0]], 3
];
exports.KeyGroupConfig$ = [3, n0, _KGC,
    0,
    [_N, _I, _Co],
    [0, [() => PublicKeyIdList, 0], 0], 2
];
exports.KeyGroupList$ = [3, n0, _KGL,
    0,
    [_MI, _Q, _NM, _I],
    [1, 1, 0, [() => KeyGroupSummaryList, 0]], 2
];
exports.KeyGroupSummary$ = [3, n0, _KGS,
    0,
    [_KG],
    [[() => exports.KeyGroup$, 0]], 1
];
exports.KeyPairIds$ = [3, n0, _KPI,
    0,
    [_Q, _I],
    [1, [() => KeyPairIdList, 0]], 1
];
exports.KeyValueStore$ = [3, n0, _KVS,
    0,
    [_N, _Id, _Co, _ARN, _LMT, _S],
    [0, 0, 0, 0, 4, 0], 5
];
exports.KeyValueStoreAssociation$ = [3, n0, _KVSAe,
    0,
    [_KVSARN],
    [0], 1
];
exports.KeyValueStoreAssociations$ = [3, n0, _KVSA,
    0,
    [_Q, _I],
    [1, [() => KeyValueStoreAssociationList, 0]], 1
];
exports.KeyValueStoreList$ = [3, n0, _KVSL,
    0,
    [_MI, _Q, _NM, _I],
    [1, 1, 0, [() => KeyValueStoreSummaryList, 0]], 2
];
exports.KGKeyPairIds$ = [3, n0, _KGKPI,
    0,
    [_KGI, _KPI],
    [0, [() => exports.KeyPairIds$, 0]]
];
exports.KinesisStreamConfig$ = [3, n0, _KSC,
    0,
    [_RARN, _SARNt],
    [0, 0], 2
];
exports.LambdaFunctionAssociation$ = [3, n0, _LFAa,
    0,
    [_LFARN, _ETv, _IBn],
    [0, 0, 2], 2
];
exports.LambdaFunctionAssociations$ = [3, n0, _LFA,
    0,
    [_Q, _I],
    [1, [() => LambdaFunctionAssociationList, 0]], 1
];
exports.ListAnycastIpListsRequest$ = [3, n0, _LAILR,
    0,
    [_Ma, _MI],
    [[0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]]
];
exports.ListAnycastIpListsResult$ = [3, n0, _LAILRi,
    0,
    [_AILn],
    [[() => exports.AnycastIpListCollection$, { [_hP]: 1, [_xN]: _AILC }]]
];
exports.ListCachePoliciesRequest$ = [3, n0, _LCPR,
    0,
    [_T, _Ma, _MI],
    [[0, { [_hQ]: _T }], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]]
];
exports.ListCachePoliciesResult$ = [3, n0, _LCPRi,
    0,
    [_CPL],
    [[() => exports.CachePolicyList$, 16]]
];
exports.ListCloudFrontOriginAccessIdentitiesRequest$ = [3, n0, _LCFOAIR,
    0,
    [_Ma, _MI],
    [[0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]]
];
exports.ListCloudFrontOriginAccessIdentitiesResult$ = [3, n0, _LCFOAIRi,
    0,
    [_CFOAIL],
    [[() => exports.CloudFrontOriginAccessIdentityList$, 16]]
];
exports.ListConflictingAliasesRequest$ = [3, n0, _LCAR,
    0,
    [_DI, _Al, _Ma, _MI],
    [[0, { [_hQ]: _DI }], [0, { [_hQ]: _Al }], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]], 2
];
exports.ListConflictingAliasesResult$ = [3, n0, _LCARi,
    0,
    [_CAL],
    [[() => exports.ConflictingAliasesList$, 16]]
];
exports.ListConnectionFunctionsRequest$ = [3, n0, _LCFR,
    0,
    [_Ma, _MI, _St],
    [0, 1, 0]
];
exports.ListConnectionFunctionsResult$ = [3, n0, _LCFRi,
    0,
    [_NM, _CF],
    [0, [() => ConnectionFunctionSummaryList, 0]]
];
exports.ListConnectionGroupsRequest$ = [3, n0, _LCGR,
    0,
    [_AF, _Ma, _MI],
    [() => exports.ConnectionGroupAssociationFilter$, 0, 1]
];
exports.ListConnectionGroupsResult$ = [3, n0, _LCGRi,
    0,
    [_NM, _CGo],
    [0, [() => ConnectionGroupSummaryList, 0]]
];
exports.ListContinuousDeploymentPoliciesRequest$ = [3, n0, _LCDPR,
    0,
    [_Ma, _MI],
    [[0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]]
];
exports.ListContinuousDeploymentPoliciesResult$ = [3, n0, _LCDPRi,
    0,
    [_CDPL],
    [[() => exports.ContinuousDeploymentPolicyList$, 16]]
];
exports.ListDistributionsByAnycastIpListIdRequest$ = [3, n0, _LDBAILIR,
    0,
    [_AILI, _Ma, _MI],
    [[0, 1], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]], 1
];
exports.ListDistributionsByAnycastIpListIdResult$ = [3, n0, _LDBAILIRi,
    0,
    [_DL],
    [[() => exports.DistributionList$, 16]]
];
exports.ListDistributionsByCachePolicyIdRequest$ = [3, n0, _LDBCPIR,
    0,
    [_CPI, _Ma, _MI],
    [[0, 1], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]], 1
];
exports.ListDistributionsByCachePolicyIdResult$ = [3, n0, _LDBCPIRi,
    0,
    [_DIL],
    [[() => exports.DistributionIdList$, 16]]
];
exports.ListDistributionsByConnectionFunctionRequest$ = [3, n0, _LDBCFR,
    0,
    [_CFI, _Ma, _MI],
    [[0, { [_hQ]: _CFI }], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]], 1
];
exports.ListDistributionsByConnectionFunctionResult$ = [3, n0, _LDBCFRi,
    0,
    [_DL],
    [[() => exports.DistributionList$, 16]]
];
exports.ListDistributionsByConnectionModeRequest$ = [3, n0, _LDBCMR,
    0,
    [_CMo, _Ma, _MI],
    [[0, 1], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]], 1
];
exports.ListDistributionsByConnectionModeResult$ = [3, n0, _LDBCMRi,
    0,
    [_DL],
    [[() => exports.DistributionList$, 16]]
];
exports.ListDistributionsByKeyGroupRequest$ = [3, n0, _LDBKGR,
    0,
    [_KGI, _Ma, _MI],
    [[0, 1], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]], 1
];
exports.ListDistributionsByKeyGroupResult$ = [3, n0, _LDBKGRi,
    0,
    [_DIL],
    [[() => exports.DistributionIdList$, 16]]
];
exports.ListDistributionsByOriginRequestPolicyIdRequest$ = [3, n0, _LDBORPIR,
    0,
    [_ORPI, _Ma, _MI],
    [[0, 1], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]], 1
];
exports.ListDistributionsByOriginRequestPolicyIdResult$ = [3, n0, _LDBORPIRi,
    0,
    [_DIL],
    [[() => exports.DistributionIdList$, 16]]
];
exports.ListDistributionsByOwnedResourceRequest$ = [3, n0, _LDBORR,
    0,
    [_RA, _Ma, _MI],
    [[0, 1], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]], 1
];
exports.ListDistributionsByOwnedResourceResult$ = [3, n0, _LDBORRi,
    0,
    [_DL],
    [[() => exports.DistributionIdOwnerList$, 16]]
];
exports.ListDistributionsByRealtimeLogConfigRequest$ = [3, n0, _LDBRLCR,
    0,
    [_Ma, _MI, _RLCN, _RLCA],
    [0, 1, 0, 0]
];
exports.ListDistributionsByRealtimeLogConfigResult$ = [3, n0, _LDBRLCRi,
    0,
    [_DL],
    [[() => exports.DistributionList$, 16]]
];
exports.ListDistributionsByResponseHeadersPolicyIdRequest$ = [3, n0, _LDBRHPIR,
    0,
    [_RHPI, _Ma, _MI],
    [[0, 1], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]], 1
];
exports.ListDistributionsByResponseHeadersPolicyIdResult$ = [3, n0, _LDBRHPIRi,
    0,
    [_DIL],
    [[() => exports.DistributionIdList$, 16]]
];
exports.ListDistributionsByTrustStoreRequest$ = [3, n0, _LDBTSR,
    0,
    [_TSI, _Ma, _MI],
    [[0, { [_hQ]: _TSI }], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]], 1
];
exports.ListDistributionsByTrustStoreResult$ = [3, n0, _LDBTSRi,
    0,
    [_DL],
    [[() => exports.DistributionList$, 16]]
];
exports.ListDistributionsByVpcOriginIdRequest$ = [3, n0, _LDBVOIR,
    0,
    [_VOI, _Ma, _MI],
    [[0, 1], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]], 1
];
exports.ListDistributionsByVpcOriginIdResult$ = [3, n0, _LDBVOIRi,
    0,
    [_DIL],
    [[() => exports.DistributionIdList$, 16]]
];
exports.ListDistributionsByWebACLIdRequest$ = [3, n0, _LDBWACLIR,
    0,
    [_WACLI, _Ma, _MI],
    [[0, 1], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]], 1
];
exports.ListDistributionsByWebACLIdResult$ = [3, n0, _LDBWACLIRi,
    0,
    [_DL],
    [[() => exports.DistributionList$, 16]]
];
exports.ListDistributionsRequest$ = [3, n0, _LDR,
    0,
    [_Ma, _MI],
    [[0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]]
];
exports.ListDistributionsResult$ = [3, n0, _LDRi,
    0,
    [_DL],
    [[() => exports.DistributionList$, 16]]
];
exports.ListDistributionTenantsByCustomizationRequest$ = [3, n0, _LDTBCR,
    0,
    [_WACLA, _CAe, _Ma, _MI],
    [0, 0, 0, 1]
];
exports.ListDistributionTenantsByCustomizationResult$ = [3, n0, _LDTBCRi,
    0,
    [_NM, _DTL],
    [0, [() => DistributionTenantList, 0]]
];
exports.ListDistributionTenantsRequest$ = [3, n0, _LDTR,
    0,
    [_AF, _Ma, _MI],
    [() => exports.DistributionTenantAssociationFilter$, 0, 1]
];
exports.ListDistributionTenantsResult$ = [3, n0, _LDTRi,
    0,
    [_NM, _DTL],
    [0, [() => DistributionTenantList, 0]]
];
exports.ListDomainConflictsRequest$ = [3, n0, _LDCR,
    0,
    [_Dom, _DCVR, _MI, _Ma],
    [0, () => exports.DistributionResourceId$, 1, 0], 2
];
exports.ListDomainConflictsResult$ = [3, n0, _LDCRi,
    0,
    [_DCom, _NM],
    [[() => DomainConflictsList, 0], 0]
];
exports.ListFieldLevelEncryptionConfigsRequest$ = [3, n0, _LFLECR,
    0,
    [_Ma, _MI],
    [[0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]]
];
exports.ListFieldLevelEncryptionConfigsResult$ = [3, n0, _LFLECRi,
    0,
    [_FLEL],
    [[() => exports.FieldLevelEncryptionList$, 16]]
];
exports.ListFieldLevelEncryptionProfilesRequest$ = [3, n0, _LFLEPR,
    0,
    [_Ma, _MI],
    [[0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]]
];
exports.ListFieldLevelEncryptionProfilesResult$ = [3, n0, _LFLEPRi,
    0,
    [_FLEPL],
    [[() => exports.FieldLevelEncryptionProfileList$, 16]]
];
exports.ListFunctionsRequest$ = [3, n0, _LFR,
    0,
    [_Ma, _MI, _St],
    [[0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }], [0, { [_hQ]: _St }]]
];
exports.ListFunctionsResult$ = [3, n0, _LFRi,
    0,
    [_FL],
    [[() => exports.FunctionList$, 16]]
];
exports.ListInvalidationsForDistributionTenantRequest$ = [3, n0, _LIFDTR,
    0,
    [_Id, _Ma, _MI],
    [[0, 1], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]], 1
];
exports.ListInvalidationsForDistributionTenantResult$ = [3, n0, _LIFDTRi,
    0,
    [_IL],
    [[() => exports.InvalidationList$, 16]]
];
exports.ListInvalidationsRequest$ = [3, n0, _LIR,
    0,
    [_DI, _Ma, _MI],
    [[0, 1], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]], 1
];
exports.ListInvalidationsResult$ = [3, n0, _LIRi,
    0,
    [_IL],
    [[() => exports.InvalidationList$, 16]]
];
exports.ListKeyGroupsRequest$ = [3, n0, _LKGR,
    0,
    [_Ma, _MI],
    [[0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]]
];
exports.ListKeyGroupsResult$ = [3, n0, _LKGRi,
    0,
    [_KGL],
    [[() => exports.KeyGroupList$, 16]]
];
exports.ListKeyValueStoresRequest$ = [3, n0, _LKVSR,
    0,
    [_Ma, _MI, _S],
    [[0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }], [0, { [_hQ]: _S }]]
];
exports.ListKeyValueStoresResult$ = [3, n0, _LKVSRi,
    0,
    [_KVSL],
    [[() => exports.KeyValueStoreList$, 16]]
];
exports.ListOriginAccessControlsRequest$ = [3, n0, _LOACR,
    0,
    [_Ma, _MI],
    [[0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]]
];
exports.ListOriginAccessControlsResult$ = [3, n0, _LOACRi,
    0,
    [_OACL],
    [[() => exports.OriginAccessControlList$, 16]]
];
exports.ListOriginRequestPoliciesRequest$ = [3, n0, _LORPR,
    0,
    [_T, _Ma, _MI],
    [[0, { [_hQ]: _T }], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]]
];
exports.ListOriginRequestPoliciesResult$ = [3, n0, _LORPRi,
    0,
    [_ORPL],
    [[() => exports.OriginRequestPolicyList$, 16]]
];
exports.ListPublicKeysRequest$ = [3, n0, _LPKR,
    0,
    [_Ma, _MI],
    [[0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]]
];
exports.ListPublicKeysResult$ = [3, n0, _LPKRi,
    0,
    [_PKL],
    [[() => exports.PublicKeyList$, 16]]
];
exports.ListRealtimeLogConfigsRequest$ = [3, n0, _LRLCR,
    0,
    [_MI, _Ma],
    [[1, { [_hQ]: _MI }], [0, { [_hQ]: _Ma }]]
];
exports.ListRealtimeLogConfigsResult$ = [3, n0, _LRLCRi,
    0,
    [_RLCe],
    [[() => exports.RealtimeLogConfigs$, 16]]
];
exports.ListResponseHeadersPoliciesRequest$ = [3, n0, _LRHPR,
    0,
    [_T, _Ma, _MI],
    [[0, { [_hQ]: _T }], [0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]]
];
exports.ListResponseHeadersPoliciesResult$ = [3, n0, _LRHPRi,
    0,
    [_RHPL],
    [[() => exports.ResponseHeadersPolicyList$, 16]]
];
exports.ListStreamingDistributionsRequest$ = [3, n0, _LSDR,
    0,
    [_Ma, _MI],
    [[0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]]
];
exports.ListStreamingDistributionsResult$ = [3, n0, _LSDRi,
    0,
    [_SDL],
    [[() => exports.StreamingDistributionList$, 16]]
];
exports.ListTagsForResourceRequest$ = [3, n0, _LTFRR,
    0,
    [_Res],
    [[0, { [_hQ]: _Res }]], 1
];
exports.ListTagsForResourceResult$ = [3, n0, _LTFRRi,
    0,
    [_Ta],
    [[() => exports.Tags$, 16]], 1
];
exports.ListTrustStoresRequest$ = [3, n0, _LTSR,
    0,
    [_Ma, _MI],
    [0, 1]
];
exports.ListTrustStoresResult$ = [3, n0, _LTSRi,
    0,
    [_NM, _TSL],
    [0, [() => TrustStoreList, 0]]
];
exports.ListVpcOriginsRequest$ = [3, n0, _LVOR,
    0,
    [_Ma, _MI],
    [[0, { [_hQ]: _Ma }], [1, { [_hQ]: _MI }]]
];
exports.ListVpcOriginsResult$ = [3, n0, _LVORi,
    0,
    [_VOL],
    [[() => exports.VpcOriginList$, 16]]
];
exports.LoggingConfig$ = [3, n0, _LC,
    0,
    [_E, _ICn, _B, _Pr],
    [2, 2, 0, 0]
];
exports.ManagedCertificateDetails$ = [3, n0, _MCD,
    0,
    [_CAe, _CS, _VTH, _VTD],
    [0, 0, 0, () => ValidationTokenDetailList]
];
exports.ManagedCertificateRequest$ = [3, n0, _MCR,
    0,
    [_VTH, _PDN, _CTLP],
    [0, 0, 0], 1
];
exports.MonitoringSubscription$ = [3, n0, _MS,
    0,
    [_RMSC],
    [() => exports.RealtimeMetricsSubscriptionConfig$]
];
exports.Origin$ = [3, n0, _Or,
    0,
    [_Id, _DN, _OP, _CH, _SOC, _COC, _VOC, _CAo, _CTon, _RCT, _OS, _OACI],
    [0, 0, 0, [() => exports.CustomHeaders$, 0], () => exports.S3OriginConfig$, [() => exports.CustomOriginConfig$, 0], () => exports.VpcOriginConfig$, 1, 1, 1, () => exports.OriginShield$, 0], 2
];
exports.OriginAccessControl$ = [3, n0, _OAC,
    0,
    [_Id, _OACC],
    [0, () => exports.OriginAccessControlConfig$], 1
];
exports.OriginAccessControlConfig$ = [3, n0, _OACC,
    0,
    [_N, _SP, _SB, _OACOT, _De],
    [0, 0, 0, 0, 0], 4
];
exports.OriginAccessControlList$ = [3, n0, _OACL,
    0,
    [_Ma, _MI, _ITs, _Q, _NM, _I],
    [0, 1, 2, 1, 0, [() => OriginAccessControlSummaryList, 0]], 4
];
exports.OriginAccessControlSummary$ = [3, n0, _OACS,
    0,
    [_Id, _De, _N, _SP, _SB, _OACOT],
    [0, 0, 0, 0, 0, 0], 6
];
exports.OriginCustomHeader$ = [3, n0, _OCH,
    0,
    [_HN, _HVe],
    [0, [() => sensitiveStringType, 0]], 2
];
exports.OriginGroup$ = [3, n0, _OGr,
    0,
    [_Id, _FCa, _Me, _SC],
    [0, [() => exports.OriginGroupFailoverCriteria$, 0], [() => exports.OriginGroupMembers$, 0], 0], 3
];
exports.OriginGroupFailoverCriteria$ = [3, n0, _OGFC,
    0,
    [_SCt],
    [[() => exports.StatusCodes$, 0]], 1
];
exports.OriginGroupMember$ = [3, n0, _OGM,
    0,
    [_OI],
    [0], 1
];
exports.OriginGroupMembers$ = [3, n0, _OGMr,
    0,
    [_Q, _I],
    [1, [() => OriginGroupMemberList, 0]], 2
];
exports.OriginGroups$ = [3, n0, _OG,
    0,
    [_Q, _I],
    [1, [() => OriginGroupList, 0]], 1
];
exports.OriginMtlsConfig$ = [3, n0, _OMC,
    0,
    [_CCA],
    [0], 1
];
exports.OriginRequestPolicy$ = [3, n0, _ORP,
    0,
    [_Id, _LMT, _ORPC],
    [0, 4, [() => exports.OriginRequestPolicyConfig$, 0]], 3
];
exports.OriginRequestPolicyConfig$ = [3, n0, _ORPC,
    0,
    [_N, _HC, _CC, _QSC, _Co],
    [0, [() => exports.OriginRequestPolicyHeadersConfig$, 0], [() => exports.OriginRequestPolicyCookiesConfig$, 0], [() => exports.OriginRequestPolicyQueryStringsConfig$, 0], 0], 4
];
exports.OriginRequestPolicyCookiesConfig$ = [3, n0, _ORPCC,
    0,
    [_CBo, _Coo],
    [0, [() => exports.CookieNames$, 0]], 1
];
exports.OriginRequestPolicyHeadersConfig$ = [3, n0, _ORPHC,
    0,
    [_HB, _H],
    [0, [() => exports.Headers$, 0]], 1
];
exports.OriginRequestPolicyList$ = [3, n0, _ORPL,
    0,
    [_MI, _Q, _NM, _I],
    [1, 1, 0, [() => OriginRequestPolicySummaryList, 0]], 2
];
exports.OriginRequestPolicyQueryStringsConfig$ = [3, n0, _ORPQSC,
    0,
    [_QSB, _QS],
    [0, [() => exports.QueryStringNames$, 0]], 1
];
exports.OriginRequestPolicySummary$ = [3, n0, _ORPS,
    0,
    [_T, _ORP],
    [0, [() => exports.OriginRequestPolicy$, 0]], 2
];
exports.Origins$ = [3, n0, _O,
    0,
    [_Q, _I],
    [1, [() => OriginList, 0]], 2
];
exports.OriginShield$ = [3, n0, _OS,
    0,
    [_E, _OSR],
    [2, 0], 1
];
exports.OriginSslProtocols$ = [3, n0, _OSP,
    0,
    [_Q, _I],
    [1, [() => SslProtocolsList, 0]], 2
];
exports.Parameter$ = [3, n0, _Par,
    0,
    [_N, _Va],
    [0, 0], 2
];
exports.ParameterDefinition$ = [3, n0, _PDa,
    0,
    [_N, _Def],
    [0, [() => exports.ParameterDefinitionSchema$, 0]], 2
];
exports.ParameterDefinitionSchema$ = [3, n0, _PDS,
    0,
    [_SSt],
    [[() => exports.StringSchemaConfig$, 0]]
];
exports.ParametersInCacheKeyAndForwardedToOrigin$ = [3, n0, _PICKAFTO,
    0,
    [_EAEG, _HC, _CC, _QSC, _EAEB],
    [2, [() => exports.CachePolicyHeadersConfig$, 0], [() => exports.CachePolicyCookiesConfig$, 0], [() => exports.CachePolicyQueryStringsConfig$, 0], 2], 4
];
exports.Paths$ = [3, n0, _Pa,
    0,
    [_Q, _I],
    [1, [() => PathList, 0]], 1
];
exports.PublicKey$ = [3, n0, _PK,
    0,
    [_Id, _CTr, _PKC],
    [0, 4, () => exports.PublicKeyConfig$], 3
];
exports.PublicKeyConfig$ = [3, n0, _PKC,
    0,
    [_CR, _N, _EK, _Co],
    [0, 0, 0, 0], 3
];
exports.PublicKeyList$ = [3, n0, _PKL,
    0,
    [_MI, _Q, _NM, _I],
    [1, 1, 0, [() => PublicKeySummaryList, 0]], 2
];
exports.PublicKeySummary$ = [3, n0, _PKS,
    0,
    [_Id, _N, _CTr, _EK, _Co],
    [0, 0, 4, 0, 0], 4
];
exports.PublishConnectionFunctionRequest$ = [3, n0, _PCFR,
    0,
    [_Id, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.PublishConnectionFunctionResult$ = [3, n0, _PCFRu,
    0,
    [_CFS],
    [[() => exports.ConnectionFunctionSummary$, 16]]
];
exports.PublishFunctionRequest$ = [3, n0, _PFR,
    0,
    [_N, _IM],
    [[0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.PublishFunctionResult$ = [3, n0, _PFRu,
    0,
    [_FS],
    [[() => exports.FunctionSummary$, 16]]
];
exports.PutResourcePolicyRequest$ = [3, n0, _PRPR,
    0,
    [_RA, _PD],
    [0, 0], 2
];
exports.PutResourcePolicyResult$ = [3, n0, _PRPRu,
    0,
    [_RA],
    [0]
];
exports.QueryArgProfile$ = [3, n0, _QAP,
    0,
    [_QA, _PI],
    [0, 0], 2
];
exports.QueryArgProfileConfig$ = [3, n0, _QAPC,
    0,
    [_FWQAPIU, _QAPu],
    [2, [() => exports.QueryArgProfiles$, 0]], 1
];
exports.QueryArgProfiles$ = [3, n0, _QAPu,
    0,
    [_Q, _I],
    [1, [() => QueryArgProfileList, 0]], 1
];
exports.QueryStringCacheKeys$ = [3, n0, _QSCK,
    0,
    [_Q, _I],
    [1, [() => QueryStringCacheKeysList, 0]], 1
];
exports.QueryStringNames$ = [3, n0, _QSN,
    0,
    [_Q, _I],
    [1, [() => QueryStringNamesList, 0]], 1
];
exports.RealtimeLogConfig$ = [3, n0, _RLC,
    0,
    [_ARN, _N, _SR, _EP, _Fi],
    [0, 0, 1, () => EndPointList, [() => FieldList, 0]], 5
];
exports.RealtimeLogConfigs$ = [3, n0, _RLCe,
    0,
    [_MI, _ITs, _Ma, _I, _NM],
    [1, 2, 0, [() => RealtimeLogConfigList, 0], 0], 3
];
exports.RealtimeMetricsSubscriptionConfig$ = [3, n0, _RMSC,
    0,
    [_RMSS],
    [0], 1
];
exports.ResponseHeadersPolicy$ = [3, n0, _RHP,
    0,
    [_Id, _LMT, _RHPC],
    [0, 4, [() => exports.ResponseHeadersPolicyConfig$, 0]], 3
];
exports.ResponseHeadersPolicyAccessControlAllowHeaders$ = [3, n0, _RHPACAH,
    0,
    [_Q, _I],
    [1, [() => AccessControlAllowHeadersList, 0]], 2
];
exports.ResponseHeadersPolicyAccessControlAllowMethods$ = [3, n0, _RHPACAM,
    0,
    [_Q, _I],
    [1, [() => AccessControlAllowMethodsList, 0]], 2
];
exports.ResponseHeadersPolicyAccessControlAllowOrigins$ = [3, n0, _RHPACAO,
    0,
    [_Q, _I],
    [1, [() => AccessControlAllowOriginsList, 0]], 2
];
exports.ResponseHeadersPolicyAccessControlExposeHeaders$ = [3, n0, _RHPACEH,
    0,
    [_Q, _I],
    [1, [() => AccessControlExposeHeadersList, 0]], 1
];
exports.ResponseHeadersPolicyConfig$ = [3, n0, _RHPC,
    0,
    [_N, _Co, _CCo, _SHC, _STHC, _CHC, _RHC],
    [0, 0, [() => exports.ResponseHeadersPolicyCorsConfig$, 0], () => exports.ResponseHeadersPolicySecurityHeadersConfig$, () => exports.ResponseHeadersPolicyServerTimingHeadersConfig$, [() => exports.ResponseHeadersPolicyCustomHeadersConfig$, 0], [() => exports.ResponseHeadersPolicyRemoveHeadersConfig$, 0]], 1
];
exports.ResponseHeadersPolicyContentSecurityPolicy$ = [3, n0, _RHPCSP,
    0,
    [_Ov, _CSP],
    [2, 0], 2
];
exports.ResponseHeadersPolicyContentTypeOptions$ = [3, n0, _RHPCTO,
    0,
    [_Ov],
    [2], 1
];
exports.ResponseHeadersPolicyCorsConfig$ = [3, n0, _RHPCC,
    0,
    [_ACAO, _ACAH, _ACAM, _ACAC, _OO, _ACEH, _ACMAS],
    [[() => exports.ResponseHeadersPolicyAccessControlAllowOrigins$, 0], [() => exports.ResponseHeadersPolicyAccessControlAllowHeaders$, 0], [() => exports.ResponseHeadersPolicyAccessControlAllowMethods$, 0], 2, 2, [() => exports.ResponseHeadersPolicyAccessControlExposeHeaders$, 0], 1], 5
];
exports.ResponseHeadersPolicyCustomHeader$ = [3, n0, _RHPCH,
    0,
    [_He, _Va, _Ov],
    [0, 0, 2], 3
];
exports.ResponseHeadersPolicyCustomHeadersConfig$ = [3, n0, _RHPCHC,
    0,
    [_Q, _I],
    [1, [() => ResponseHeadersPolicyCustomHeaderList, 0]], 1
];
exports.ResponseHeadersPolicyFrameOptions$ = [3, n0, _RHPFO,
    0,
    [_Ov, _FO],
    [2, 0], 2
];
exports.ResponseHeadersPolicyList$ = [3, n0, _RHPL,
    0,
    [_MI, _Q, _NM, _I],
    [1, 1, 0, [() => ResponseHeadersPolicySummaryList, 0]], 2
];
exports.ResponseHeadersPolicyReferrerPolicy$ = [3, n0, _RHPRP,
    0,
    [_Ov, _RP],
    [2, 0], 2
];
exports.ResponseHeadersPolicyRemoveHeader$ = [3, n0, _RHPRH,
    0,
    [_He],
    [0], 1
];
exports.ResponseHeadersPolicyRemoveHeadersConfig$ = [3, n0, _RHPRHC,
    0,
    [_Q, _I],
    [1, [() => ResponseHeadersPolicyRemoveHeaderList, 0]], 1
];
exports.ResponseHeadersPolicySecurityHeadersConfig$ = [3, n0, _RHPSHC,
    0,
    [_XSSP, _FOr, _RP, _CSP, _CTO, _STS],
    [() => exports.ResponseHeadersPolicyXSSProtection$, () => exports.ResponseHeadersPolicyFrameOptions$, () => exports.ResponseHeadersPolicyReferrerPolicy$, () => exports.ResponseHeadersPolicyContentSecurityPolicy$, () => exports.ResponseHeadersPolicyContentTypeOptions$, () => exports.ResponseHeadersPolicyStrictTransportSecurity$]
];
exports.ResponseHeadersPolicyServerTimingHeadersConfig$ = [3, n0, _RHPSTHC,
    0,
    [_E, _SR],
    [2, 1], 1
];
exports.ResponseHeadersPolicyStrictTransportSecurity$ = [3, n0, _RHPSTS,
    0,
    [_Ov, _ACMAS, _ISnc, _Pre],
    [2, 1, 2, 2], 2
];
exports.ResponseHeadersPolicySummary$ = [3, n0, _RHPS,
    0,
    [_T, _RHP],
    [0, [() => exports.ResponseHeadersPolicy$, 0]], 2
];
exports.ResponseHeadersPolicyXSSProtection$ = [3, n0, _RHPXSSP,
    0,
    [_Ov, _Pro, _MBo, _RU],
    [2, 2, 2, 0], 2
];
exports.Restrictions$ = [3, n0, _Re,
    0,
    [_GRe],
    [[() => exports.GeoRestriction$, 0]], 1
];
exports.S3Origin$ = [3, n0, _SO,
    0,
    [_DN, _OAIr],
    [0, 0], 2
];
exports.S3OriginConfig$ = [3, n0, _SOC,
    0,
    [_OAIr, _ORT],
    [0, 1], 1
];
exports.SessionStickinessConfig$ = [3, n0, _SSC,
    0,
    [_ITTL, _MTTLax],
    [1, 1], 2
];
exports.Signer$ = [3, n0, _Si,
    0,
    [_AAN, _KPI],
    [0, [() => exports.KeyPairIds$, 0]]
];
exports.StagingDistributionDnsNames$ = [3, n0, _SDDN,
    0,
    [_Q, _I],
    [1, [() => StagingDistributionDnsNameList, 0]], 1
];
exports.StatusCodes$ = [3, n0, _SCt,
    0,
    [_Q, _I],
    [1, [() => StatusCodeList, 0]], 2
];
exports.StreamingDistribution$ = [3, n0, _SD,
    0,
    [_Id, _ARN, _S, _DN, _ATS, _SDC, _LMT],
    [0, 0, 0, 0, [() => exports.ActiveTrustedSigners$, 0], [() => exports.StreamingDistributionConfig$, 0], 4], 6
];
exports.StreamingDistributionConfig$ = [3, n0, _SDC,
    0,
    [_CR, _SO, _Co, _TS, _E, _A, _Lo, _PC],
    [0, () => exports.S3Origin$, 0, [() => exports.TrustedSigners$, 0], 2, [() => exports.Aliases$, 0], () => exports.StreamingLoggingConfig$, 0], 5
];
exports.StreamingDistributionConfigWithTags$ = [3, n0, _SDCWT,
    0,
    [_SDC, _Ta],
    [[() => exports.StreamingDistributionConfig$, 0], [() => exports.Tags$, 0]], 2
];
exports.StreamingDistributionList$ = [3, n0, _SDL,
    0,
    [_Ma, _MI, _ITs, _Q, _NM, _I],
    [0, 1, 2, 1, 0, [() => StreamingDistributionSummaryList, 0]], 4
];
exports.StreamingDistributionSummary$ = [3, n0, _SDS,
    0,
    [_Id, _ARN, _S, _LMT, _DN, _SO, _A, _TS, _Co, _PC, _E],
    [0, 0, 0, 4, 0, () => exports.S3Origin$, [() => exports.Aliases$, 0], [() => exports.TrustedSigners$, 0], 0, 0, 2], 11
];
exports.StreamingLoggingConfig$ = [3, n0, _SLC,
    0,
    [_E, _B, _Pr],
    [2, 0, 0], 3
];
exports.StringSchemaConfig$ = [3, n0, _SSCt,
    0,
    [_Req, _Co, _DV],
    [2, [() => sensitiveStringType, 0], 0], 1
];
exports.Tag$ = [3, n0, _Tag,
    0,
    [_K, _Va],
    [0, 0], 1
];
exports.TagKeys$ = [3, n0, _TK,
    0,
    [_I],
    [[() => TagKeyList, 0]]
];
exports.TagResourceRequest$ = [3, n0, _TRR,
    0,
    [_Res, _Ta],
    [[0, { [_hQ]: _Res }], [() => exports.Tags$, { [_hP]: 1, [_xN]: _Ta }]], 2
];
exports.Tags$ = [3, n0, _Ta,
    0,
    [_I],
    [[() => TagList, 0]]
];
exports.TenantConfig$ = [3, n0, _TCe,
    0,
    [_PDar],
    [[() => ParameterDefinitions, 0]]
];
exports.TestConnectionFunctionRequest$ = [3, n0, _TCFR,
    0,
    [_Id, _IM, _CO, _St],
    [[0, 1], [0, { [_hH]: _IM_ }], [() => FunctionEventObject, 0], 0], 3
];
exports.TestConnectionFunctionResult$ = [3, n0, _TCFRe,
    0,
    [_CFTR],
    [[() => exports.ConnectionFunctionTestResult$, 16]]
];
exports.TestFunctionRequest$ = [3, n0, _TFR,
    0,
    [_N, _IM, _EO, _St],
    [[0, 1], [0, { [_hH]: _IM_ }], [() => FunctionEventObject, 0], 0], 3
];
exports.TestFunctionResult$ = [3, n0, _TFRe,
    0,
    [_TR],
    [[() => exports.TestResult$, 16]]
];
exports.TestResult$ = [3, n0, _TR,
    0,
    [_FS, _CU, _FEL, _FEM, _FOu],
    [[() => exports.FunctionSummary$, 0], 0, [() => FunctionExecutionLogList, 0], [() => sensitiveStringType, 0], [() => sensitiveStringType, 0]]
];
exports.TrafficConfig$ = [3, n0, _TC,
    0,
    [_T, _SWC, _SHCi],
    [0, () => exports.ContinuousDeploymentSingleWeightConfig$, () => exports.ContinuousDeploymentSingleHeaderConfig$], 1
];
exports.TrustedKeyGroups$ = [3, n0, _TKG,
    0,
    [_E, _Q, _I],
    [2, 1, [() => TrustedKeyGroupIdList, 0]], 2
];
exports.TrustedSigners$ = [3, n0, _TS,
    0,
    [_E, _Q, _I],
    [2, 1, [() => AwsAccountNumberList, 0]], 2
];
exports.TrustStore$ = [3, n0, _TSr,
    0,
    [_Id, _Ar, _N, _S, _NOCC, _LMT, _Rea],
    [0, 0, 0, 0, 1, 4, 0]
];
exports.TrustStoreConfig$ = [3, n0, _TSC,
    0,
    [_TSIr, _ATSCN, _ICE],
    [0, 2, 2], 1
];
exports.TrustStoreSummary$ = [3, n0, _TSS,
    0,
    [_Id, _Ar, _N, _S, _NOCC, _LMT, _ET, _Rea],
    [0, 0, 0, 0, 1, 4, 0, 0], 7
];
exports.UntagResourceRequest$ = [3, n0, _URR,
    0,
    [_Res, _TK],
    [[0, { [_hQ]: _Res }], [() => exports.TagKeys$, { [_hP]: 1, [_xN]: _TK }]], 2
];
exports.UpdateAnycastIpListRequest$ = [3, n0, _UAILR,
    0,
    [_Id, _IM, _IAT],
    [[0, 1], [0, { [_hH]: _IM_ }], 0], 2
];
exports.UpdateAnycastIpListResult$ = [3, n0, _UAILRp,
    0,
    [_AIL, _ET],
    [[() => exports.AnycastIpList$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateCachePolicyRequest$ = [3, n0, _UCPR,
    0,
    [_CPC, _Id, _IM],
    [[() => exports.CachePolicyConfig$, { [_hP]: 1, [_xN]: _CPC }], [0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.UpdateCachePolicyResult$ = [3, n0, _UCPRp,
    0,
    [_CP, _ET],
    [[() => exports.CachePolicy$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateCloudFrontOriginAccessIdentityRequest$ = [3, n0, _UCFOAIR,
    0,
    [_CFOAIC, _Id, _IM],
    [[() => exports.CloudFrontOriginAccessIdentityConfig$, { [_hP]: 1, [_xN]: _CFOAIC }], [0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.UpdateCloudFrontOriginAccessIdentityResult$ = [3, n0, _UCFOAIRp,
    0,
    [_CFOAI, _ET],
    [[() => exports.CloudFrontOriginAccessIdentity$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateConnectionFunctionRequest$ = [3, n0, _UCFR,
    0,
    [_Id, _IM, _CFC, _CFCo],
    [[0, 1], [0, { [_hH]: _IM_ }], [() => exports.FunctionConfig$, 0], [() => FunctionBlob, 0]], 4
];
exports.UpdateConnectionFunctionResult$ = [3, n0, _UCFRp,
    0,
    [_CFS, _ET],
    [[() => exports.ConnectionFunctionSummary$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateConnectionGroupRequest$ = [3, n0, _UCGR,
    0,
    [_Id, _IM, _IE, _AILI, _E],
    [[0, 1], [0, { [_hH]: _IM_ }], 2, 0, 2], 2
];
exports.UpdateConnectionGroupResult$ = [3, n0, _UCGRp,
    0,
    [_CG, _ET],
    [[() => exports.ConnectionGroup$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateContinuousDeploymentPolicyRequest$ = [3, n0, _UCDPR,
    0,
    [_CDPC, _Id, _IM],
    [[() => exports.ContinuousDeploymentPolicyConfig$, { [_hP]: 1, [_xN]: _CDPC }], [0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.UpdateContinuousDeploymentPolicyResult$ = [3, n0, _UCDPRp,
    0,
    [_CDP, _ET],
    [[() => exports.ContinuousDeploymentPolicy$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateDistributionRequest$ = [3, n0, _UDR,
    0,
    [_DC, _Id, _IM],
    [[() => exports.DistributionConfig$, { [_hP]: 1, [_xN]: _DC }], [0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.UpdateDistributionResult$ = [3, n0, _UDRp,
    0,
    [_D, _ET],
    [[() => exports.Distribution$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateDistributionTenantRequest$ = [3, n0, _UDTR,
    0,
    [_Id, _IM, _DI, _Do, _Cu, _P, _CGI, _MCR, _E],
    [[0, 1], [0, { [_hH]: _IM_ }], 0, () => DomainList, [() => exports.Customizations$, 0], () => _Parameters, 0, () => exports.ManagedCertificateRequest$, 2], 2
];
exports.UpdateDistributionTenantResult$ = [3, n0, _UDTRp,
    0,
    [_DT, _ET],
    [[() => exports.DistributionTenant$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateDistributionWithStagingConfigRequest$ = [3, n0, _UDWSCR,
    0,
    [_Id, _SDI, _IM],
    [[0, 1], [0, { [_hQ]: _SDI }], [0, { [_hH]: _IM_ }]], 1
];
exports.UpdateDistributionWithStagingConfigResult$ = [3, n0, _UDWSCRp,
    0,
    [_D, _ET],
    [[() => exports.Distribution$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateDomainAssociationRequest$ = [3, n0, _UDAR,
    0,
    [_Dom, _TRa, _IM],
    [0, () => exports.DistributionResourceId$, [0, { [_hH]: _IM_ }]], 2
];
exports.UpdateDomainAssociationResult$ = [3, n0, _UDARp,
    0,
    [_Dom, _RI, _ET],
    [0, 0, [0, { [_hH]: _ET }]]
];
exports.UpdateFieldLevelEncryptionConfigRequest$ = [3, n0, _UFLECR,
    0,
    [_FLEC, _Id, _IM],
    [[() => exports.FieldLevelEncryptionConfig$, { [_hP]: 1, [_xN]: _FLEC }], [0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.UpdateFieldLevelEncryptionConfigResult$ = [3, n0, _UFLECRp,
    0,
    [_FLE, _ET],
    [[() => exports.FieldLevelEncryption$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateFieldLevelEncryptionProfileRequest$ = [3, n0, _UFLEPR,
    0,
    [_FLEPC, _Id, _IM],
    [[() => exports.FieldLevelEncryptionProfileConfig$, { [_hP]: 1, [_xN]: _FLEPC }], [0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.UpdateFieldLevelEncryptionProfileResult$ = [3, n0, _UFLEPRp,
    0,
    [_FLEP, _ET],
    [[() => exports.FieldLevelEncryptionProfile$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateFunctionRequest$ = [3, n0, _UFR,
    0,
    [_N, _IM, _FC, _FCu],
    [[0, 1], [0, { [_hH]: _IM_ }], [() => exports.FunctionConfig$, 0], [() => FunctionBlob, 0]], 4
];
exports.UpdateFunctionResult$ = [3, n0, _UFRp,
    0,
    [_FS, _ET],
    [[() => exports.FunctionSummary$, 16], [0, { [_hH]: _ETt }]]
];
exports.UpdateKeyGroupRequest$ = [3, n0, _UKGR,
    0,
    [_KGC, _Id, _IM],
    [[() => exports.KeyGroupConfig$, { [_hP]: 1, [_xN]: _KGC }], [0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.UpdateKeyGroupResult$ = [3, n0, _UKGRp,
    0,
    [_KG, _ET],
    [[() => exports.KeyGroup$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateKeyValueStoreRequest$ = [3, n0, _UKVSR,
    0,
    [_N, _Co, _IM],
    [[0, 1], 0, [0, { [_hH]: _IM_ }]], 3
];
exports.UpdateKeyValueStoreResult$ = [3, n0, _UKVSRp,
    0,
    [_KVS, _ET],
    [[() => exports.KeyValueStore$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateOriginAccessControlRequest$ = [3, n0, _UOACR,
    0,
    [_OACC, _Id, _IM],
    [[() => exports.OriginAccessControlConfig$, { [_hP]: 1, [_xN]: _OACC }], [0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.UpdateOriginAccessControlResult$ = [3, n0, _UOACRp,
    0,
    [_OAC, _ET],
    [[() => exports.OriginAccessControl$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateOriginRequestPolicyRequest$ = [3, n0, _UORPR,
    0,
    [_ORPC, _Id, _IM],
    [[() => exports.OriginRequestPolicyConfig$, { [_hP]: 1, [_xN]: _ORPC }], [0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.UpdateOriginRequestPolicyResult$ = [3, n0, _UORPRp,
    0,
    [_ORP, _ET],
    [[() => exports.OriginRequestPolicy$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdatePublicKeyRequest$ = [3, n0, _UPKR,
    0,
    [_PKC, _Id, _IM],
    [[() => exports.PublicKeyConfig$, { [_hP]: 1, [_xN]: _PKC }], [0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.UpdatePublicKeyResult$ = [3, n0, _UPKRp,
    0,
    [_PK, _ET],
    [[() => exports.PublicKey$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateRealtimeLogConfigRequest$ = [3, n0, _URLCR,
    0,
    [_EP, _Fi, _N, _ARN, _SR],
    [() => EndPointList, [() => FieldList, 0], 0, 0, 1]
];
exports.UpdateRealtimeLogConfigResult$ = [3, n0, _URLCRp,
    0,
    [_RLC],
    [[() => exports.RealtimeLogConfig$, 0]]
];
exports.UpdateResponseHeadersPolicyRequest$ = [3, n0, _URHPR,
    0,
    [_RHPC, _Id, _IM],
    [[() => exports.ResponseHeadersPolicyConfig$, { [_hP]: 1, [_xN]: _RHPC }], [0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.UpdateResponseHeadersPolicyResult$ = [3, n0, _URHPRp,
    0,
    [_RHP, _ET],
    [[() => exports.ResponseHeadersPolicy$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateStreamingDistributionRequest$ = [3, n0, _USDR,
    0,
    [_SDC, _Id, _IM],
    [[() => exports.StreamingDistributionConfig$, { [_hP]: 1, [_xN]: _SDC }], [0, 1], [0, { [_hH]: _IM_ }]], 2
];
exports.UpdateStreamingDistributionResult$ = [3, n0, _USDRp,
    0,
    [_SD, _ET],
    [[() => exports.StreamingDistribution$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateTrustStoreRequest$ = [3, n0, _UTSR,
    0,
    [_Id, _CCBS, _IM],
    [[0, 1], [() => exports.CaCertificatesBundleSource$, 16], [0, { [_hH]: _IM_ }]], 3
];
exports.UpdateTrustStoreResult$ = [3, n0, _UTSRp,
    0,
    [_TSr, _ET],
    [[() => exports.TrustStore$, 16], [0, { [_hH]: _ET }]]
];
exports.UpdateVpcOriginRequest$ = [3, n0, _UVOR,
    0,
    [_VOEC, _Id, _IM],
    [[() => exports.VpcOriginEndpointConfig$, { [_hP]: 1, [_xN]: _VOEC }], [0, 1], [0, { [_hH]: _IM_ }]], 3
];
exports.UpdateVpcOriginResult$ = [3, n0, _UVORp,
    0,
    [_VO, _ET],
    [[() => exports.VpcOrigin$, 16], [0, { [_hH]: _ET }]]
];
exports.ValidationTokenDetail$ = [3, n0, _VTDa,
    0,
    [_Dom, _RTed, _RF],
    [0, 0, 0], 1
];
exports.VerifyDnsConfigurationRequest$ = [3, n0, _VDCR,
    0,
    [_Ide, _Dom],
    [0, 0], 1
];
exports.VerifyDnsConfigurationResult$ = [3, n0, _VDCRe,
    0,
    [_DCL],
    [[() => DnsConfigurationList, 0]]
];
exports.ViewerCertificate$ = [3, n0, _VC,
    0,
    [_CFDC, _IAMCI, _ACMCA, _SSLSM, _MPV, _Ce, _CSe],
    [2, 0, 0, 0, 0, 0, 0]
];
exports.ViewerMtlsConfig$ = [3, n0, _VMC,
    0,
    [_Mo, _TSC],
    [0, () => exports.TrustStoreConfig$]
];
exports.VpcOrigin$ = [3, n0, _VO,
    0,
    [_Id, _Ar, _S, _CTr, _LMT, _VOEC, _AIc],
    [0, 0, 0, 4, 4, [() => exports.VpcOriginEndpointConfig$, 0], 0], 6
];
exports.VpcOriginConfig$ = [3, n0, _VOC,
    0,
    [_VOI, _OAI, _ORT, _OKT],
    [0, 0, 1, 1], 1
];
exports.VpcOriginEndpointConfig$ = [3, n0, _VOEC,
    0,
    [_N, _Ar, _HTTPP, _HTTPSP, _OPP, _OSP],
    [0, 0, 1, 1, 0, [() => exports.OriginSslProtocols$, 0]], 5
];
exports.VpcOriginList$ = [3, n0, _VOL,
    0,
    [_Ma, _MI, _ITs, _Q, _NM, _I],
    [0, 1, 2, 1, 0, [() => VpcOriginSummaryList, 0]], 4
];
exports.VpcOriginSummary$ = [3, n0, _VOS,
    0,
    [_Id, _N, _S, _CTr, _LMT, _Ar, _OEA, _AIc],
    [0, 0, 0, 4, 4, 0, 0, 0], 7
];
exports.WebAclCustomization$ = [3, n0, _WAC,
    0,
    [_Ac, _Ar],
    [0, 0], 1
];
var __Unit = "unit";
var AccessControlAllowHeadersList = [1, n0, _ACAHL,
    0, [0,
        { [_xN]: _He }]
];
var AccessControlAllowMethodsList = [1, n0, _ACAML,
    0, [0,
        { [_xN]: _Met }]
];
var AccessControlAllowOriginsList = [1, n0, _ACAOL,
    0, [0,
        { [_xN]: _Or }]
];
var AccessControlExposeHeadersList = [1, n0, _ACEHL,
    0, [0,
        { [_xN]: _He }]
];
var AliasICPRecordals = [1, n0, _AICPRl,
    0, [() => exports.AliasICPRecordal$,
        { [_xN]: _AICPR }]
];
var AliasList = [1, n0, _AL,
    0, [0,
        { [_xN]: _CNAME }]
];
var AnycastIpListSummaries = [1, n0, _AILSn,
    0, [() => exports.AnycastIpListSummary$,
        { [_xN]: _AILS }]
];
var AnycastIps = [1, n0, _AI,
    0, [0,
        { [_xN]: _AIn }]
];
var AwsAccountNumberList = [1, n0, _AANL,
    0, [0,
        { [_xN]: _AAN }]
];
var CacheBehaviorList = [1, n0, _CBL,
    0, [() => exports.CacheBehavior$,
        { [_xN]: _CB }]
];
var CachePolicySummaryList = [1, n0, _CPSL,
    0, [() => exports.CachePolicySummary$,
        { [_xN]: _CPS }]
];
var CloudFrontOriginAccessIdentitySummaryList = [1, n0, _CFOAISL,
    0, [() => exports.CloudFrontOriginAccessIdentitySummary$,
        { [_xN]: _CFOAIS }]
];
var ConflictingAliases = [1, n0, _CAon,
    0, [() => exports.ConflictingAlias$,
        { [_xN]: _CA }]
];
var ConnectionFunctionSummaryList = [1, n0, _CFSL,
    0, [() => exports.ConnectionFunctionSummary$,
        { [_xN]: _CFS }]
];
var ConnectionGroupSummaryList = [1, n0, _CGSL,
    0, [() => exports.ConnectionGroupSummary$,
        { [_xN]: _CGS }]
];
var ContentTypeProfileList = [1, n0, _CTPL,
    0, [() => exports.ContentTypeProfile$,
        { [_xN]: _CTP }]
];
var ContinuousDeploymentPolicySummaryList = [1, n0, _CDPSL,
    0, [() => exports.ContinuousDeploymentPolicySummary$,
        { [_xN]: _CDPS }]
];
var CookieNameList = [1, n0, _CNL,
    0, [0,
        { [_xN]: _N }]
];
var CustomErrorResponseList = [1, n0, _CERL,
    0, [() => exports.CustomErrorResponse$,
        { [_xN]: _CER }]
];
var DistributionIdListSummary = [1, n0, _DILS,
    0, [0,
        { [_xN]: _DI }]
];
var DistributionIdOwnerItemList = [1, n0, _DIOIL,
    0, [() => exports.DistributionIdOwner$,
        { [_xN]: _DIO }]
];
var DistributionSummaryList = [1, n0, _DSL,
    0, [() => exports.DistributionSummary$,
        { [_xN]: _DS }]
];
var DistributionTenantList = [1, n0, _DTL,
    0, [() => exports.DistributionTenantSummary$,
        { [_xN]: _DTS }]
];
var DnsConfigurationList = [1, n0, _DCL,
    0, [() => exports.DnsConfiguration$,
        { [_xN]: _DCn }]
];
var DomainConflictsList = [1, n0, _DCLo,
    0, [() => exports.DomainConflict$,
        { [_xN]: _DCom }]
];
var DomainList = [1, n0, _DLo,
    0, () => exports.DomainItem$
];
var DomainResultList = [1, n0, _DRL,
    0, () => exports.DomainResult$
];
var EncryptionEntityList = [1, n0, _EEL,
    0, [() => exports.EncryptionEntity$,
        { [_xN]: _EEn }]
];
var EndPointList = [1, n0, _EPL,
    0, () => exports.EndPoint$
];
var FieldLevelEncryptionProfileSummaryList = [1, n0, _FLEPSL,
    0, [() => exports.FieldLevelEncryptionProfileSummary$,
        { [_xN]: _FLEPS }]
];
var FieldLevelEncryptionSummaryList = [1, n0, _FLESL,
    0, [() => exports.FieldLevelEncryptionSummary$,
        { [_xN]: _FLES }]
];
var FieldList = [1, n0, _FLi,
    0, [0,
        { [_xN]: _Fie }]
];
var FieldPatternList = [1, n0, _FPL,
    0, [0,
        { [_xN]: _FPi }]
];
var FunctionAssociationList = [1, n0, _FAL,
    0, [() => exports.FunctionAssociation$,
        { [_xN]: _FAu }]
];
var FunctionExecutionLogList = [1, n0, _FELL,
    8, 0
];
var FunctionSummaryList = [1, n0, _FSL,
    0, [() => exports.FunctionSummary$,
        { [_xN]: _FS }]
];
var HeaderList = [1, n0, _HL,
    0, [0,
        { [_xN]: _N }]
];
var InvalidationSummaryList = [1, n0, _ISL,
    0, [() => exports.InvalidationSummary$,
        { [_xN]: _ISn }]
];
var IpamCidrConfigList = [1, n0, _ICCL,
    0, [() => exports.IpamCidrConfig$,
        { [_xN]: _ICCp }]
];
var KeyGroupSummaryList = [1, n0, _KGSL,
    0, [() => exports.KeyGroupSummary$,
        { [_xN]: _KGS }]
];
var KeyPairIdList = [1, n0, _KPIL,
    0, [0,
        { [_xN]: _KPIe }]
];
var KeyValueStoreAssociationList = [1, n0, _KVSAL,
    0, [() => exports.KeyValueStoreAssociation$,
        { [_xN]: _KVSAe }]
];
var KeyValueStoreSummaryList = [1, n0, _KVSSL,
    0, [() => exports.KeyValueStore$,
        { [_xN]: _KVS }]
];
var KGKeyPairIdsList = [1, n0, _KGKPIL,
    0, [() => exports.KGKeyPairIds$,
        { [_xN]: _KG }]
];
var LambdaFunctionAssociationList = [1, n0, _LFAL,
    0, [() => exports.LambdaFunctionAssociation$,
        { [_xN]: _LFAa }]
];
var LocationList = [1, n0, _LL,
    0, [0,
        { [_xN]: _L }]
];
var MethodsList = [1, n0, _ML,
    0, [0,
        { [_xN]: _Met }]
];
var OriginAccessControlSummaryList = [1, n0, _OACSL,
    0, [() => exports.OriginAccessControlSummary$,
        { [_xN]: _OACS }]
];
var OriginCustomHeadersList = [1, n0, _OCHL,
    0, [() => exports.OriginCustomHeader$,
        { [_xN]: _OCH }]
];
var OriginGroupList = [1, n0, _OGL,
    0, [() => exports.OriginGroup$,
        { [_xN]: _OGr }]
];
var OriginGroupMemberList = [1, n0, _OGML,
    0, [() => exports.OriginGroupMember$,
        { [_xN]: _OGM }]
];
var OriginList = [1, n0, _OL,
    0, [() => exports.Origin$,
        { [_xN]: _Or }]
];
var OriginRequestPolicySummaryList = [1, n0, _ORPSL,
    0, [() => exports.OriginRequestPolicySummary$,
        { [_xN]: _ORPS }]
];
var ParameterDefinitions = [1, n0, _PDar,
    0, [() => exports.ParameterDefinition$,
        0]
];
var _Parameters = [1, n0, _P,
    0, () => exports.Parameter$
];
var PathList = [1, n0, _PL,
    0, [0,
        { [_xN]: _Pat }]
];
var PublicKeyIdList = [1, n0, _PKIL,
    0, [0,
        { [_xN]: _PK }]
];
var PublicKeySummaryList = [1, n0, _PKSL,
    0, [() => exports.PublicKeySummary$,
        { [_xN]: _PKS }]
];
var QueryArgProfileList = [1, n0, _QAPL,
    0, [() => exports.QueryArgProfile$,
        { [_xN]: _QAP }]
];
var QueryStringCacheKeysList = [1, n0, _QSCKL,
    0, [0,
        { [_xN]: _N }]
];
var QueryStringNamesList = [1, n0, _QSNL,
    0, [0,
        { [_xN]: _N }]
];
var RealtimeLogConfigList = [1, n0, _RLCL,
    0, [() => exports.RealtimeLogConfig$,
        0]
];
var ResponseHeadersPolicyCustomHeaderList = [1, n0, _RHPCHL,
    0, [() => exports.ResponseHeadersPolicyCustomHeader$,
        { [_xN]: _RHPCH }]
];
var ResponseHeadersPolicyRemoveHeaderList = [1, n0, _RHPRHL,
    0, [() => exports.ResponseHeadersPolicyRemoveHeader$,
        { [_xN]: _RHPRH }]
];
var ResponseHeadersPolicySummaryList = [1, n0, _RHPSL,
    0, [() => exports.ResponseHeadersPolicySummary$,
        { [_xN]: _RHPS }]
];
var SignerList = [1, n0, _SL,
    0, [() => exports.Signer$,
        { [_xN]: _Si }]
];
var SslProtocolsList = [1, n0, _SPL,
    0, [0,
        { [_xN]: _SPs }]
];
var StagingDistributionDnsNameList = [1, n0, _SDDNL,
    0, [0,
        { [_xN]: _DNn }]
];
var StatusCodeList = [1, n0, _SCL,
    0, [1,
        { [_xN]: _SCta }]
];
var StreamingDistributionSummaryList = [1, n0, _SDSL,
    0, [() => exports.StreamingDistributionSummary$,
        { [_xN]: _SDS }]
];
var TagKeyList = [1, n0, _TKL,
    0, [0,
        { [_xN]: _K }]
];
var TagList = [1, n0, _TL,
    0, [() => exports.Tag$,
        { [_xN]: _Tag }]
];
var TrustedKeyGroupIdList = [1, n0, _TKGIL,
    0, [0,
        { [_xN]: _KG }]
];
var TrustStoreList = [1, n0, _TSL,
    0, [() => exports.TrustStoreSummary$,
        { [_xN]: _TSS }]
];
var ValidationTokenDetailList = [1, n0, _VTDL,
    0, () => exports.ValidationTokenDetail$
];
var VpcOriginSummaryList = [1, n0, _VOSL,
    0, [() => exports.VpcOriginSummary$,
        { [_xN]: _VOS }]
];
exports.CaCertificatesBundleSource$ = [4, n0, _CCBS,
    0,
    [_CCBSL],
    [() => exports.CaCertificatesBundleS3Location$]
];
exports.AssociateAlias$ = [9, n0, _AA,
    { [_h]: ["PUT", "/2020-05-31/distribution/{TargetDistributionId}/associate-alias", 200] }, () => exports.AssociateAliasRequest$, () => __Unit
];
exports.AssociateDistributionTenantWebACL$ = [9, n0, _ADTWACL,
    { [_h]: ["PUT", "/2020-05-31/distribution-tenant/{Id}/associate-web-acl", 200] }, () => exports.AssociateDistributionTenantWebACLRequest$, () => exports.AssociateDistributionTenantWebACLResult$
];
exports.AssociateDistributionWebACL$ = [9, n0, _ADWACL,
    { [_h]: ["PUT", "/2020-05-31/distribution/{Id}/associate-web-acl", 200] }, () => exports.AssociateDistributionWebACLRequest$, () => exports.AssociateDistributionWebACLResult$
];
exports.CopyDistribution$ = [9, n0, _CD,
    { [_h]: ["POST", "/2020-05-31/distribution/{PrimaryDistributionId}/copy", 201] }, () => exports.CopyDistributionRequest$, () => exports.CopyDistributionResult$
];
exports.CreateAnycastIpList$ = [9, n0, _CAIL,
    { [_h]: ["POST", "/2020-05-31/anycast-ip-list", 202] }, () => exports.CreateAnycastIpListRequest$, () => exports.CreateAnycastIpListResult$
];
exports.CreateCachePolicy$ = [9, n0, _CCP,
    { [_h]: ["POST", "/2020-05-31/cache-policy", 201] }, () => exports.CreateCachePolicyRequest$, () => exports.CreateCachePolicyResult$
];
exports.CreateCloudFrontOriginAccessIdentity$ = [9, n0, _CCFOAI,
    { [_h]: ["POST", "/2020-05-31/origin-access-identity/cloudfront", 201] }, () => exports.CreateCloudFrontOriginAccessIdentityRequest$, () => exports.CreateCloudFrontOriginAccessIdentityResult$
];
exports.CreateConnectionFunction$ = [9, n0, _CCF,
    { [_h]: ["POST", "/2020-05-31/connection-function", 201] }, () => exports.CreateConnectionFunctionRequest$, () => exports.CreateConnectionFunctionResult$
];
exports.CreateConnectionGroup$ = [9, n0, _CCG,
    { [_h]: ["POST", "/2020-05-31/connection-group", 201] }, () => exports.CreateConnectionGroupRequest$, () => exports.CreateConnectionGroupResult$
];
exports.CreateContinuousDeploymentPolicy$ = [9, n0, _CCDP,
    { [_h]: ["POST", "/2020-05-31/continuous-deployment-policy", 201] }, () => exports.CreateContinuousDeploymentPolicyRequest$, () => exports.CreateContinuousDeploymentPolicyResult$
];
exports.CreateDistribution$ = [9, n0, _CDr,
    { [_h]: ["POST", "/2020-05-31/distribution", 201] }, () => exports.CreateDistributionRequest$, () => exports.CreateDistributionResult$
];
exports.CreateDistributionTenant$ = [9, n0, _CDT,
    { [_h]: ["POST", "/2020-05-31/distribution-tenant", 201] }, () => exports.CreateDistributionTenantRequest$, () => exports.CreateDistributionTenantResult$
];
exports.CreateDistributionWithTags$ = [9, n0, _CDWT,
    { [_h]: ["POST", "/2020-05-31/distribution?WithTags", 201] }, () => exports.CreateDistributionWithTagsRequest$, () => exports.CreateDistributionWithTagsResult$
];
exports.CreateFieldLevelEncryptionConfig$ = [9, n0, _CFLEC,
    { [_h]: ["POST", "/2020-05-31/field-level-encryption", 201] }, () => exports.CreateFieldLevelEncryptionConfigRequest$, () => exports.CreateFieldLevelEncryptionConfigResult$
];
exports.CreateFieldLevelEncryptionProfile$ = [9, n0, _CFLEP,
    { [_h]: ["POST", "/2020-05-31/field-level-encryption-profile", 201] }, () => exports.CreateFieldLevelEncryptionProfileRequest$, () => exports.CreateFieldLevelEncryptionProfileResult$
];
exports.CreateFunction$ = [9, n0, _CFr,
    { [_h]: ["POST", "/2020-05-31/function", 201] }, () => exports.CreateFunctionRequest$, () => exports.CreateFunctionResult$
];
exports.CreateInvalidation$ = [9, n0, _CI,
    { [_h]: ["POST", "/2020-05-31/distribution/{DistributionId}/invalidation", 201] }, () => exports.CreateInvalidationRequest$, () => exports.CreateInvalidationResult$
];
exports.CreateInvalidationForDistributionTenant$ = [9, n0, _CIFDT,
    { [_h]: ["POST", "/2020-05-31/distribution-tenant/{Id}/invalidation", 201] }, () => exports.CreateInvalidationForDistributionTenantRequest$, () => exports.CreateInvalidationForDistributionTenantResult$
];
exports.CreateKeyGroup$ = [9, n0, _CKG,
    { [_h]: ["POST", "/2020-05-31/key-group", 201] }, () => exports.CreateKeyGroupRequest$, () => exports.CreateKeyGroupResult$
];
exports.CreateKeyValueStore$ = [9, n0, _CKVS,
    { [_h]: ["POST", "/2020-05-31/key-value-store", 201] }, () => exports.CreateKeyValueStoreRequest$, () => exports.CreateKeyValueStoreResult$
];
exports.CreateMonitoringSubscription$ = [9, n0, _CMS,
    { [_h]: ["POST", "/2020-05-31/distributions/{DistributionId}/monitoring-subscription", 200] }, () => exports.CreateMonitoringSubscriptionRequest$, () => exports.CreateMonitoringSubscriptionResult$
];
exports.CreateOriginAccessControl$ = [9, n0, _COAC,
    { [_h]: ["POST", "/2020-05-31/origin-access-control", 201] }, () => exports.CreateOriginAccessControlRequest$, () => exports.CreateOriginAccessControlResult$
];
exports.CreateOriginRequestPolicy$ = [9, n0, _CORP,
    { [_h]: ["POST", "/2020-05-31/origin-request-policy", 201] }, () => exports.CreateOriginRequestPolicyRequest$, () => exports.CreateOriginRequestPolicyResult$
];
exports.CreatePublicKey$ = [9, n0, _CPK,
    { [_h]: ["POST", "/2020-05-31/public-key", 201] }, () => exports.CreatePublicKeyRequest$, () => exports.CreatePublicKeyResult$
];
exports.CreateRealtimeLogConfig$ = [9, n0, _CRLC,
    { [_h]: ["POST", "/2020-05-31/realtime-log-config", 201] }, () => exports.CreateRealtimeLogConfigRequest$, () => exports.CreateRealtimeLogConfigResult$
];
exports.CreateResponseHeadersPolicy$ = [9, n0, _CRHP,
    { [_h]: ["POST", "/2020-05-31/response-headers-policy", 201] }, () => exports.CreateResponseHeadersPolicyRequest$, () => exports.CreateResponseHeadersPolicyResult$
];
exports.CreateStreamingDistribution$ = [9, n0, _CSD,
    { [_h]: ["POST", "/2020-05-31/streaming-distribution", 201] }, () => exports.CreateStreamingDistributionRequest$, () => exports.CreateStreamingDistributionResult$
];
exports.CreateStreamingDistributionWithTags$ = [9, n0, _CSDWT,
    { [_h]: ["POST", "/2020-05-31/streaming-distribution?WithTags", 201] }, () => exports.CreateStreamingDistributionWithTagsRequest$, () => exports.CreateStreamingDistributionWithTagsResult$
];
exports.CreateTrustStore$ = [9, n0, _CTS,
    { [_h]: ["POST", "/2020-05-31/trust-store", 201] }, () => exports.CreateTrustStoreRequest$, () => exports.CreateTrustStoreResult$
];
exports.CreateVpcOrigin$ = [9, n0, _CVO,
    { [_h]: ["POST", "/2020-05-31/vpc-origin", 202] }, () => exports.CreateVpcOriginRequest$, () => exports.CreateVpcOriginResult$
];
exports.DeleteAnycastIpList$ = [9, n0, _DAIL,
    { [_h]: ["DELETE", "/2020-05-31/anycast-ip-list/{Id}", 204] }, () => exports.DeleteAnycastIpListRequest$, () => __Unit
];
exports.DeleteCachePolicy$ = [9, n0, _DCP,
    { [_h]: ["DELETE", "/2020-05-31/cache-policy/{Id}", 204] }, () => exports.DeleteCachePolicyRequest$, () => __Unit
];
exports.DeleteCloudFrontOriginAccessIdentity$ = [9, n0, _DCFOAI,
    { [_h]: ["DELETE", "/2020-05-31/origin-access-identity/cloudfront/{Id}", 204] }, () => exports.DeleteCloudFrontOriginAccessIdentityRequest$, () => __Unit
];
exports.DeleteConnectionFunction$ = [9, n0, _DCF,
    { [_h]: ["DELETE", "/2020-05-31/connection-function/{Id}", 204] }, () => exports.DeleteConnectionFunctionRequest$, () => __Unit
];
exports.DeleteConnectionGroup$ = [9, n0, _DCG,
    { [_h]: ["DELETE", "/2020-05-31/connection-group/{Id}", 204] }, () => exports.DeleteConnectionGroupRequest$, () => __Unit
];
exports.DeleteContinuousDeploymentPolicy$ = [9, n0, _DCDP,
    { [_h]: ["DELETE", "/2020-05-31/continuous-deployment-policy/{Id}", 204] }, () => exports.DeleteContinuousDeploymentPolicyRequest$, () => __Unit
];
exports.DeleteDistribution$ = [9, n0, _DD,
    { [_h]: ["DELETE", "/2020-05-31/distribution/{Id}", 204] }, () => exports.DeleteDistributionRequest$, () => __Unit
];
exports.DeleteDistributionTenant$ = [9, n0, _DDT,
    { [_h]: ["DELETE", "/2020-05-31/distribution-tenant/{Id}", 204] }, () => exports.DeleteDistributionTenantRequest$, () => __Unit
];
exports.DeleteFieldLevelEncryptionConfig$ = [9, n0, _DFLEC,
    { [_h]: ["DELETE", "/2020-05-31/field-level-encryption/{Id}", 204] }, () => exports.DeleteFieldLevelEncryptionConfigRequest$, () => __Unit
];
exports.DeleteFieldLevelEncryptionProfile$ = [9, n0, _DFLEP,
    { [_h]: ["DELETE", "/2020-05-31/field-level-encryption-profile/{Id}", 204] }, () => exports.DeleteFieldLevelEncryptionProfileRequest$, () => __Unit
];
exports.DeleteFunction$ = [9, n0, _DF,
    { [_h]: ["DELETE", "/2020-05-31/function/{Name}", 204] }, () => exports.DeleteFunctionRequest$, () => __Unit
];
exports.DeleteKeyGroup$ = [9, n0, _DKG,
    { [_h]: ["DELETE", "/2020-05-31/key-group/{Id}", 204] }, () => exports.DeleteKeyGroupRequest$, () => __Unit
];
exports.DeleteKeyValueStore$ = [9, n0, _DKVS,
    { [_h]: ["DELETE", "/2020-05-31/key-value-store/{Name}", 204] }, () => exports.DeleteKeyValueStoreRequest$, () => __Unit
];
exports.DeleteMonitoringSubscription$ = [9, n0, _DMS,
    { [_h]: ["DELETE", "/2020-05-31/distributions/{DistributionId}/monitoring-subscription", 200] }, () => exports.DeleteMonitoringSubscriptionRequest$, () => exports.DeleteMonitoringSubscriptionResult$
];
exports.DeleteOriginAccessControl$ = [9, n0, _DOAC,
    { [_h]: ["DELETE", "/2020-05-31/origin-access-control/{Id}", 204] }, () => exports.DeleteOriginAccessControlRequest$, () => __Unit
];
exports.DeleteOriginRequestPolicy$ = [9, n0, _DORP,
    { [_h]: ["DELETE", "/2020-05-31/origin-request-policy/{Id}", 204] }, () => exports.DeleteOriginRequestPolicyRequest$, () => __Unit
];
exports.DeletePublicKey$ = [9, n0, _DPK,
    { [_h]: ["DELETE", "/2020-05-31/public-key/{Id}", 204] }, () => exports.DeletePublicKeyRequest$, () => __Unit
];
exports.DeleteRealtimeLogConfig$ = [9, n0, _DRLC,
    { [_h]: ["POST", "/2020-05-31/delete-realtime-log-config", 204] }, () => exports.DeleteRealtimeLogConfigRequest$, () => __Unit
];
exports.DeleteResourcePolicy$ = [9, n0, _DRP,
    { [_h]: ["POST", "/2020-05-31/delete-resource-policy", 200] }, () => exports.DeleteResourcePolicyRequest$, () => __Unit
];
exports.DeleteResponseHeadersPolicy$ = [9, n0, _DRHP,
    { [_h]: ["DELETE", "/2020-05-31/response-headers-policy/{Id}", 204] }, () => exports.DeleteResponseHeadersPolicyRequest$, () => __Unit
];
exports.DeleteStreamingDistribution$ = [9, n0, _DSD,
    { [_h]: ["DELETE", "/2020-05-31/streaming-distribution/{Id}", 204] }, () => exports.DeleteStreamingDistributionRequest$, () => __Unit
];
exports.DeleteTrustStore$ = [9, n0, _DTSe,
    { [_h]: ["DELETE", "/2020-05-31/trust-store/{Id}", 204] }, () => exports.DeleteTrustStoreRequest$, () => __Unit
];
exports.DeleteVpcOrigin$ = [9, n0, _DVO,
    { [_h]: ["DELETE", "/2020-05-31/vpc-origin/{Id}", 202] }, () => exports.DeleteVpcOriginRequest$, () => exports.DeleteVpcOriginResult$
];
exports.DescribeConnectionFunction$ = [9, n0, _DCFe,
    { [_h]: ["GET", "/2020-05-31/connection-function/{Identifier}/describe", 200] }, () => exports.DescribeConnectionFunctionRequest$, () => exports.DescribeConnectionFunctionResult$
];
exports.DescribeFunction$ = [9, n0, _DFe,
    { [_h]: ["GET", "/2020-05-31/function/{Name}/describe", 200] }, () => exports.DescribeFunctionRequest$, () => exports.DescribeFunctionResult$
];
exports.DescribeKeyValueStore$ = [9, n0, _DKVSe,
    { [_h]: ["GET", "/2020-05-31/key-value-store/{Name}", 200] }, () => exports.DescribeKeyValueStoreRequest$, () => exports.DescribeKeyValueStoreResult$
];
exports.DisassociateDistributionTenantWebACL$ = [9, n0, _DDTWACL,
    { [_h]: ["PUT", "/2020-05-31/distribution-tenant/{Id}/disassociate-web-acl", 200] }, () => exports.DisassociateDistributionTenantWebACLRequest$, () => exports.DisassociateDistributionTenantWebACLResult$
];
exports.DisassociateDistributionWebACL$ = [9, n0, _DDWACL,
    { [_h]: ["PUT", "/2020-05-31/distribution/{Id}/disassociate-web-acl", 200] }, () => exports.DisassociateDistributionWebACLRequest$, () => exports.DisassociateDistributionWebACLResult$
];
exports.GetAnycastIpList$ = [9, n0, _GAIL,
    { [_h]: ["GET", "/2020-05-31/anycast-ip-list/{Id}", 200] }, () => exports.GetAnycastIpListRequest$, () => exports.GetAnycastIpListResult$
];
exports.GetCachePolicy$ = [9, n0, _GCP,
    { [_h]: ["GET", "/2020-05-31/cache-policy/{Id}", 200] }, () => exports.GetCachePolicyRequest$, () => exports.GetCachePolicyResult$
];
exports.GetCachePolicyConfig$ = [9, n0, _GCPC,
    { [_h]: ["GET", "/2020-05-31/cache-policy/{Id}/config", 200] }, () => exports.GetCachePolicyConfigRequest$, () => exports.GetCachePolicyConfigResult$
];
exports.GetCloudFrontOriginAccessIdentity$ = [9, n0, _GCFOAI,
    { [_h]: ["GET", "/2020-05-31/origin-access-identity/cloudfront/{Id}", 200] }, () => exports.GetCloudFrontOriginAccessIdentityRequest$, () => exports.GetCloudFrontOriginAccessIdentityResult$
];
exports.GetCloudFrontOriginAccessIdentityConfig$ = [9, n0, _GCFOAIC,
    { [_h]: ["GET", "/2020-05-31/origin-access-identity/cloudfront/{Id}/config", 200] }, () => exports.GetCloudFrontOriginAccessIdentityConfigRequest$, () => exports.GetCloudFrontOriginAccessIdentityConfigResult$
];
exports.GetConnectionFunction$ = [9, n0, _GCF,
    { [_h]: ["GET", "/2020-05-31/connection-function/{Identifier}", 200] }, () => exports.GetConnectionFunctionRequest$, () => exports.GetConnectionFunctionResult$
];
exports.GetConnectionGroup$ = [9, n0, _GCG,
    { [_h]: ["GET", "/2020-05-31/connection-group/{Identifier}", 200] }, () => exports.GetConnectionGroupRequest$, () => exports.GetConnectionGroupResult$
];
exports.GetConnectionGroupByRoutingEndpoint$ = [9, n0, _GCGBRE,
    { [_h]: ["GET", "/2020-05-31/connection-group", 200] }, () => exports.GetConnectionGroupByRoutingEndpointRequest$, () => exports.GetConnectionGroupByRoutingEndpointResult$
];
exports.GetContinuousDeploymentPolicy$ = [9, n0, _GCDP,
    { [_h]: ["GET", "/2020-05-31/continuous-deployment-policy/{Id}", 200] }, () => exports.GetContinuousDeploymentPolicyRequest$, () => exports.GetContinuousDeploymentPolicyResult$
];
exports.GetContinuousDeploymentPolicyConfig$ = [9, n0, _GCDPC,
    { [_h]: ["GET", "/2020-05-31/continuous-deployment-policy/{Id}/config", 200] }, () => exports.GetContinuousDeploymentPolicyConfigRequest$, () => exports.GetContinuousDeploymentPolicyConfigResult$
];
exports.GetDistribution$ = [9, n0, _GD,
    { [_h]: ["GET", "/2020-05-31/distribution/{Id}", 200] }, () => exports.GetDistributionRequest$, () => exports.GetDistributionResult$
];
exports.GetDistributionConfig$ = [9, n0, _GDC,
    { [_h]: ["GET", "/2020-05-31/distribution/{Id}/config", 200] }, () => exports.GetDistributionConfigRequest$, () => exports.GetDistributionConfigResult$
];
exports.GetDistributionTenant$ = [9, n0, _GDT,
    { [_h]: ["GET", "/2020-05-31/distribution-tenant/{Identifier}", 200] }, () => exports.GetDistributionTenantRequest$, () => exports.GetDistributionTenantResult$
];
exports.GetDistributionTenantByDomain$ = [9, n0, _GDTBD,
    { [_h]: ["GET", "/2020-05-31/distribution-tenant", 200] }, () => exports.GetDistributionTenantByDomainRequest$, () => exports.GetDistributionTenantByDomainResult$
];
exports.GetFieldLevelEncryption$ = [9, n0, _GFLE,
    { [_h]: ["GET", "/2020-05-31/field-level-encryption/{Id}", 200] }, () => exports.GetFieldLevelEncryptionRequest$, () => exports.GetFieldLevelEncryptionResult$
];
exports.GetFieldLevelEncryptionConfig$ = [9, n0, _GFLEC,
    { [_h]: ["GET", "/2020-05-31/field-level-encryption/{Id}/config", 200] }, () => exports.GetFieldLevelEncryptionConfigRequest$, () => exports.GetFieldLevelEncryptionConfigResult$
];
exports.GetFieldLevelEncryptionProfile$ = [9, n0, _GFLEP,
    { [_h]: ["GET", "/2020-05-31/field-level-encryption-profile/{Id}", 200] }, () => exports.GetFieldLevelEncryptionProfileRequest$, () => exports.GetFieldLevelEncryptionProfileResult$
];
exports.GetFieldLevelEncryptionProfileConfig$ = [9, n0, _GFLEPC,
    { [_h]: ["GET", "/2020-05-31/field-level-encryption-profile/{Id}/config", 200] }, () => exports.GetFieldLevelEncryptionProfileConfigRequest$, () => exports.GetFieldLevelEncryptionProfileConfigResult$
];
exports.GetFunction$ = [9, n0, _GF,
    { [_h]: ["GET", "/2020-05-31/function/{Name}", 200] }, () => exports.GetFunctionRequest$, () => exports.GetFunctionResult$
];
exports.GetInvalidation$ = [9, n0, _GI,
    { [_h]: ["GET", "/2020-05-31/distribution/{DistributionId}/invalidation/{Id}", 200] }, () => exports.GetInvalidationRequest$, () => exports.GetInvalidationResult$
];
exports.GetInvalidationForDistributionTenant$ = [9, n0, _GIFDT,
    { [_h]: ["GET", "/2020-05-31/distribution-tenant/{DistributionTenantId}/invalidation/{Id}", 200] }, () => exports.GetInvalidationForDistributionTenantRequest$, () => exports.GetInvalidationForDistributionTenantResult$
];
exports.GetKeyGroup$ = [9, n0, _GKG,
    { [_h]: ["GET", "/2020-05-31/key-group/{Id}", 200] }, () => exports.GetKeyGroupRequest$, () => exports.GetKeyGroupResult$
];
exports.GetKeyGroupConfig$ = [9, n0, _GKGC,
    { [_h]: ["GET", "/2020-05-31/key-group/{Id}/config", 200] }, () => exports.GetKeyGroupConfigRequest$, () => exports.GetKeyGroupConfigResult$
];
exports.GetManagedCertificateDetails$ = [9, n0, _GMCD,
    { [_h]: ["GET", "/2020-05-31/managed-certificate/{Identifier}", 200] }, () => exports.GetManagedCertificateDetailsRequest$, () => exports.GetManagedCertificateDetailsResult$
];
exports.GetMonitoringSubscription$ = [9, n0, _GMS,
    { [_h]: ["GET", "/2020-05-31/distributions/{DistributionId}/monitoring-subscription", 200] }, () => exports.GetMonitoringSubscriptionRequest$, () => exports.GetMonitoringSubscriptionResult$
];
exports.GetOriginAccessControl$ = [9, n0, _GOAC,
    { [_h]: ["GET", "/2020-05-31/origin-access-control/{Id}", 200] }, () => exports.GetOriginAccessControlRequest$, () => exports.GetOriginAccessControlResult$
];
exports.GetOriginAccessControlConfig$ = [9, n0, _GOACC,
    { [_h]: ["GET", "/2020-05-31/origin-access-control/{Id}/config", 200] }, () => exports.GetOriginAccessControlConfigRequest$, () => exports.GetOriginAccessControlConfigResult$
];
exports.GetOriginRequestPolicy$ = [9, n0, _GORP,
    { [_h]: ["GET", "/2020-05-31/origin-request-policy/{Id}", 200] }, () => exports.GetOriginRequestPolicyRequest$, () => exports.GetOriginRequestPolicyResult$
];
exports.GetOriginRequestPolicyConfig$ = [9, n0, _GORPC,
    { [_h]: ["GET", "/2020-05-31/origin-request-policy/{Id}/config", 200] }, () => exports.GetOriginRequestPolicyConfigRequest$, () => exports.GetOriginRequestPolicyConfigResult$
];
exports.GetPublicKey$ = [9, n0, _GPK,
    { [_h]: ["GET", "/2020-05-31/public-key/{Id}", 200] }, () => exports.GetPublicKeyRequest$, () => exports.GetPublicKeyResult$
];
exports.GetPublicKeyConfig$ = [9, n0, _GPKC,
    { [_h]: ["GET", "/2020-05-31/public-key/{Id}/config", 200] }, () => exports.GetPublicKeyConfigRequest$, () => exports.GetPublicKeyConfigResult$
];
exports.GetRealtimeLogConfig$ = [9, n0, _GRLC,
    { [_h]: ["POST", "/2020-05-31/get-realtime-log-config", 200] }, () => exports.GetRealtimeLogConfigRequest$, () => exports.GetRealtimeLogConfigResult$
];
exports.GetResourcePolicy$ = [9, n0, _GRP,
    { [_h]: ["POST", "/2020-05-31/get-resource-policy", 200] }, () => exports.GetResourcePolicyRequest$, () => exports.GetResourcePolicyResult$
];
exports.GetResponseHeadersPolicy$ = [9, n0, _GRHP,
    { [_h]: ["GET", "/2020-05-31/response-headers-policy/{Id}", 200] }, () => exports.GetResponseHeadersPolicyRequest$, () => exports.GetResponseHeadersPolicyResult$
];
exports.GetResponseHeadersPolicyConfig$ = [9, n0, _GRHPC,
    { [_h]: ["GET", "/2020-05-31/response-headers-policy/{Id}/config", 200] }, () => exports.GetResponseHeadersPolicyConfigRequest$, () => exports.GetResponseHeadersPolicyConfigResult$
];
exports.GetStreamingDistribution$ = [9, n0, _GSD,
    { [_h]: ["GET", "/2020-05-31/streaming-distribution/{Id}", 200] }, () => exports.GetStreamingDistributionRequest$, () => exports.GetStreamingDistributionResult$
];
exports.GetStreamingDistributionConfig$ = [9, n0, _GSDC,
    { [_h]: ["GET", "/2020-05-31/streaming-distribution/{Id}/config", 200] }, () => exports.GetStreamingDistributionConfigRequest$, () => exports.GetStreamingDistributionConfigResult$
];
exports.GetTrustStore$ = [9, n0, _GTS,
    { [_h]: ["GET", "/2020-05-31/trust-store/{Identifier}", 200] }, () => exports.GetTrustStoreRequest$, () => exports.GetTrustStoreResult$
];
exports.GetVpcOrigin$ = [9, n0, _GVO,
    { [_h]: ["GET", "/2020-05-31/vpc-origin/{Id}", 200] }, () => exports.GetVpcOriginRequest$, () => exports.GetVpcOriginResult$
];
exports.ListAnycastIpLists$ = [9, n0, _LAIL,
    { [_h]: ["GET", "/2020-05-31/anycast-ip-list", 200] }, () => exports.ListAnycastIpListsRequest$, () => exports.ListAnycastIpListsResult$
];
exports.ListCachePolicies$ = [9, n0, _LCP,
    { [_h]: ["GET", "/2020-05-31/cache-policy", 200] }, () => exports.ListCachePoliciesRequest$, () => exports.ListCachePoliciesResult$
];
exports.ListCloudFrontOriginAccessIdentities$ = [9, n0, _LCFOAI,
    { [_h]: ["GET", "/2020-05-31/origin-access-identity/cloudfront", 200] }, () => exports.ListCloudFrontOriginAccessIdentitiesRequest$, () => exports.ListCloudFrontOriginAccessIdentitiesResult$
];
exports.ListConflictingAliases$ = [9, n0, _LCA,
    { [_h]: ["GET", "/2020-05-31/conflicting-alias", 200] }, () => exports.ListConflictingAliasesRequest$, () => exports.ListConflictingAliasesResult$
];
exports.ListConnectionFunctions$ = [9, n0, _LCF,
    { [_h]: ["POST", "/2020-05-31/connection-functions", 200] }, () => exports.ListConnectionFunctionsRequest$, () => exports.ListConnectionFunctionsResult$
];
exports.ListConnectionGroups$ = [9, n0, _LCG,
    { [_h]: ["POST", "/2020-05-31/connection-groups", 200] }, () => exports.ListConnectionGroupsRequest$, () => exports.ListConnectionGroupsResult$
];
exports.ListContinuousDeploymentPolicies$ = [9, n0, _LCDP,
    { [_h]: ["GET", "/2020-05-31/continuous-deployment-policy", 200] }, () => exports.ListContinuousDeploymentPoliciesRequest$, () => exports.ListContinuousDeploymentPoliciesResult$
];
exports.ListDistributions$ = [9, n0, _LD,
    { [_h]: ["GET", "/2020-05-31/distribution", 200] }, () => exports.ListDistributionsRequest$, () => exports.ListDistributionsResult$
];
exports.ListDistributionsByAnycastIpListId$ = [9, n0, _LDBAILI,
    { [_h]: ["GET", "/2020-05-31/distributionsByAnycastIpListId/{AnycastIpListId}", 200] }, () => exports.ListDistributionsByAnycastIpListIdRequest$, () => exports.ListDistributionsByAnycastIpListIdResult$
];
exports.ListDistributionsByCachePolicyId$ = [9, n0, _LDBCPI,
    { [_h]: ["GET", "/2020-05-31/distributionsByCachePolicyId/{CachePolicyId}", 200] }, () => exports.ListDistributionsByCachePolicyIdRequest$, () => exports.ListDistributionsByCachePolicyIdResult$
];
exports.ListDistributionsByConnectionFunction$ = [9, n0, _LDBCF,
    { [_h]: ["GET", "/2020-05-31/distributionsByConnectionFunction", 200] }, () => exports.ListDistributionsByConnectionFunctionRequest$, () => exports.ListDistributionsByConnectionFunctionResult$
];
exports.ListDistributionsByConnectionMode$ = [9, n0, _LDBCM,
    { [_h]: ["GET", "/2020-05-31/distributionsByConnectionMode/{ConnectionMode}", 200] }, () => exports.ListDistributionsByConnectionModeRequest$, () => exports.ListDistributionsByConnectionModeResult$
];
exports.ListDistributionsByKeyGroup$ = [9, n0, _LDBKG,
    { [_h]: ["GET", "/2020-05-31/distributionsByKeyGroupId/{KeyGroupId}", 200] }, () => exports.ListDistributionsByKeyGroupRequest$, () => exports.ListDistributionsByKeyGroupResult$
];
exports.ListDistributionsByOriginRequestPolicyId$ = [9, n0, _LDBORPI,
    { [_h]: ["GET", "/2020-05-31/distributionsByOriginRequestPolicyId/{OriginRequestPolicyId}", 200] }, () => exports.ListDistributionsByOriginRequestPolicyIdRequest$, () => exports.ListDistributionsByOriginRequestPolicyIdResult$
];
exports.ListDistributionsByOwnedResource$ = [9, n0, _LDBOR,
    { [_h]: ["GET", "/2020-05-31/distributionsByOwnedResource/{ResourceArn}", 200] }, () => exports.ListDistributionsByOwnedResourceRequest$, () => exports.ListDistributionsByOwnedResourceResult$
];
exports.ListDistributionsByRealtimeLogConfig$ = [9, n0, _LDBRLC,
    { [_h]: ["POST", "/2020-05-31/distributionsByRealtimeLogConfig", 200] }, () => exports.ListDistributionsByRealtimeLogConfigRequest$, () => exports.ListDistributionsByRealtimeLogConfigResult$
];
exports.ListDistributionsByResponseHeadersPolicyId$ = [9, n0, _LDBRHPI,
    { [_h]: ["GET", "/2020-05-31/distributionsByResponseHeadersPolicyId/{ResponseHeadersPolicyId}", 200] }, () => exports.ListDistributionsByResponseHeadersPolicyIdRequest$, () => exports.ListDistributionsByResponseHeadersPolicyIdResult$
];
exports.ListDistributionsByTrustStore$ = [9, n0, _LDBTS,
    { [_h]: ["GET", "/2020-05-31/distributionsByTrustStore", 200] }, () => exports.ListDistributionsByTrustStoreRequest$, () => exports.ListDistributionsByTrustStoreResult$
];
exports.ListDistributionsByVpcOriginId$ = [9, n0, _LDBVOI,
    { [_h]: ["GET", "/2020-05-31/distributionsByVpcOriginId/{VpcOriginId}", 200] }, () => exports.ListDistributionsByVpcOriginIdRequest$, () => exports.ListDistributionsByVpcOriginIdResult$
];
exports.ListDistributionsByWebACLId$ = [9, n0, _LDBWACLI,
    { [_h]: ["GET", "/2020-05-31/distributionsByWebACLId/{WebACLId}", 200] }, () => exports.ListDistributionsByWebACLIdRequest$, () => exports.ListDistributionsByWebACLIdResult$
];
exports.ListDistributionTenants$ = [9, n0, _LDT,
    { [_h]: ["POST", "/2020-05-31/distribution-tenants", 200] }, () => exports.ListDistributionTenantsRequest$, () => exports.ListDistributionTenantsResult$
];
exports.ListDistributionTenantsByCustomization$ = [9, n0, _LDTBC,
    { [_h]: ["POST", "/2020-05-31/distribution-tenants-by-customization", 200] }, () => exports.ListDistributionTenantsByCustomizationRequest$, () => exports.ListDistributionTenantsByCustomizationResult$
];
exports.ListDomainConflicts$ = [9, n0, _LDC,
    { [_h]: ["POST", "/2020-05-31/domain-conflicts", 200] }, () => exports.ListDomainConflictsRequest$, () => exports.ListDomainConflictsResult$
];
exports.ListFieldLevelEncryptionConfigs$ = [9, n0, _LFLEC,
    { [_h]: ["GET", "/2020-05-31/field-level-encryption", 200] }, () => exports.ListFieldLevelEncryptionConfigsRequest$, () => exports.ListFieldLevelEncryptionConfigsResult$
];
exports.ListFieldLevelEncryptionProfiles$ = [9, n0, _LFLEP,
    { [_h]: ["GET", "/2020-05-31/field-level-encryption-profile", 200] }, () => exports.ListFieldLevelEncryptionProfilesRequest$, () => exports.ListFieldLevelEncryptionProfilesResult$
];
exports.ListFunctions$ = [9, n0, _LF,
    { [_h]: ["GET", "/2020-05-31/function", 200] }, () => exports.ListFunctionsRequest$, () => exports.ListFunctionsResult$
];
exports.ListInvalidations$ = [9, n0, _LI,
    { [_h]: ["GET", "/2020-05-31/distribution/{DistributionId}/invalidation", 200] }, () => exports.ListInvalidationsRequest$, () => exports.ListInvalidationsResult$
];
exports.ListInvalidationsForDistributionTenant$ = [9, n0, _LIFDT,
    { [_h]: ["GET", "/2020-05-31/distribution-tenant/{Id}/invalidation", 200] }, () => exports.ListInvalidationsForDistributionTenantRequest$, () => exports.ListInvalidationsForDistributionTenantResult$
];
exports.ListKeyGroups$ = [9, n0, _LKG,
    { [_h]: ["GET", "/2020-05-31/key-group", 200] }, () => exports.ListKeyGroupsRequest$, () => exports.ListKeyGroupsResult$
];
exports.ListKeyValueStores$ = [9, n0, _LKVS,
    { [_h]: ["GET", "/2020-05-31/key-value-store", 200] }, () => exports.ListKeyValueStoresRequest$, () => exports.ListKeyValueStoresResult$
];
exports.ListOriginAccessControls$ = [9, n0, _LOAC,
    { [_h]: ["GET", "/2020-05-31/origin-access-control", 200] }, () => exports.ListOriginAccessControlsRequest$, () => exports.ListOriginAccessControlsResult$
];
exports.ListOriginRequestPolicies$ = [9, n0, _LORP,
    { [_h]: ["GET", "/2020-05-31/origin-request-policy", 200] }, () => exports.ListOriginRequestPoliciesRequest$, () => exports.ListOriginRequestPoliciesResult$
];
exports.ListPublicKeys$ = [9, n0, _LPK,
    { [_h]: ["GET", "/2020-05-31/public-key", 200] }, () => exports.ListPublicKeysRequest$, () => exports.ListPublicKeysResult$
];
exports.ListRealtimeLogConfigs$ = [9, n0, _LRLC,
    { [_h]: ["GET", "/2020-05-31/realtime-log-config", 200] }, () => exports.ListRealtimeLogConfigsRequest$, () => exports.ListRealtimeLogConfigsResult$
];
exports.ListResponseHeadersPolicies$ = [9, n0, _LRHP,
    { [_h]: ["GET", "/2020-05-31/response-headers-policy", 200] }, () => exports.ListResponseHeadersPoliciesRequest$, () => exports.ListResponseHeadersPoliciesResult$
];
exports.ListStreamingDistributions$ = [9, n0, _LSD,
    { [_h]: ["GET", "/2020-05-31/streaming-distribution", 200] }, () => exports.ListStreamingDistributionsRequest$, () => exports.ListStreamingDistributionsResult$
];
exports.ListTagsForResource$ = [9, n0, _LTFR,
    { [_h]: ["GET", "/2020-05-31/tagging", 200] }, () => exports.ListTagsForResourceRequest$, () => exports.ListTagsForResourceResult$
];
exports.ListTrustStores$ = [9, n0, _LTS,
    { [_h]: ["POST", "/2020-05-31/trust-stores", 200] }, () => exports.ListTrustStoresRequest$, () => exports.ListTrustStoresResult$
];
exports.ListVpcOrigins$ = [9, n0, _LVO,
    { [_h]: ["GET", "/2020-05-31/vpc-origin", 200] }, () => exports.ListVpcOriginsRequest$, () => exports.ListVpcOriginsResult$
];
exports.PublishConnectionFunction$ = [9, n0, _PCF,
    { [_h]: ["POST", "/2020-05-31/connection-function/{Id}/publish", 200] }, () => exports.PublishConnectionFunctionRequest$, () => exports.PublishConnectionFunctionResult$
];
exports.PublishFunction$ = [9, n0, _PFu,
    { [_h]: ["POST", "/2020-05-31/function/{Name}/publish", 200] }, () => exports.PublishFunctionRequest$, () => exports.PublishFunctionResult$
];
exports.PutResourcePolicy$ = [9, n0, _PRP,
    { [_h]: ["POST", "/2020-05-31/put-resource-policy", 200] }, () => exports.PutResourcePolicyRequest$, () => exports.PutResourcePolicyResult$
];
exports.TagResource$ = [9, n0, _TRag,
    { [_h]: ["POST", "/2020-05-31/tagging?Operation=Tag", 204] }, () => exports.TagResourceRequest$, () => __Unit
];
exports.TestConnectionFunction$ = [9, n0, _TCF,
    { [_h]: ["POST", "/2020-05-31/connection-function/{Id}/test", 200] }, () => exports.TestConnectionFunctionRequest$, () => exports.TestConnectionFunctionResult$
];
exports.TestFunction$ = [9, n0, _TF,
    { [_h]: ["POST", "/2020-05-31/function/{Name}/test", 200] }, () => exports.TestFunctionRequest$, () => exports.TestFunctionResult$
];
exports.UntagResource$ = [9, n0, _UR,
    { [_h]: ["POST", "/2020-05-31/tagging?Operation=Untag", 204] }, () => exports.UntagResourceRequest$, () => __Unit
];
exports.UpdateAnycastIpList$ = [9, n0, _UAIL,
    { [_h]: ["PUT", "/2020-05-31/anycast-ip-list/{Id}", 200] }, () => exports.UpdateAnycastIpListRequest$, () => exports.UpdateAnycastIpListResult$
];
exports.UpdateCachePolicy$ = [9, n0, _UCP,
    { [_h]: ["PUT", "/2020-05-31/cache-policy/{Id}", 200] }, () => exports.UpdateCachePolicyRequest$, () => exports.UpdateCachePolicyResult$
];
exports.UpdateCloudFrontOriginAccessIdentity$ = [9, n0, _UCFOAI,
    { [_h]: ["PUT", "/2020-05-31/origin-access-identity/cloudfront/{Id}/config", 200] }, () => exports.UpdateCloudFrontOriginAccessIdentityRequest$, () => exports.UpdateCloudFrontOriginAccessIdentityResult$
];
exports.UpdateConnectionFunction$ = [9, n0, _UCF,
    { [_h]: ["PUT", "/2020-05-31/connection-function/{Id}", 200] }, () => exports.UpdateConnectionFunctionRequest$, () => exports.UpdateConnectionFunctionResult$
];
exports.UpdateConnectionGroup$ = [9, n0, _UCG,
    { [_h]: ["PUT", "/2020-05-31/connection-group/{Id}", 200] }, () => exports.UpdateConnectionGroupRequest$, () => exports.UpdateConnectionGroupResult$
];
exports.UpdateContinuousDeploymentPolicy$ = [9, n0, _UCDP,
    { [_h]: ["PUT", "/2020-05-31/continuous-deployment-policy/{Id}", 200] }, () => exports.UpdateContinuousDeploymentPolicyRequest$, () => exports.UpdateContinuousDeploymentPolicyResult$
];
exports.UpdateDistribution$ = [9, n0, _UD,
    { [_h]: ["PUT", "/2020-05-31/distribution/{Id}/config", 200] }, () => exports.UpdateDistributionRequest$, () => exports.UpdateDistributionResult$
];
exports.UpdateDistributionTenant$ = [9, n0, _UDT,
    { [_h]: ["PUT", "/2020-05-31/distribution-tenant/{Id}", 200] }, () => exports.UpdateDistributionTenantRequest$, () => exports.UpdateDistributionTenantResult$
];
exports.UpdateDistributionWithStagingConfig$ = [9, n0, _UDWSC,
    { [_h]: ["PUT", "/2020-05-31/distribution/{Id}/promote-staging-config", 200] }, () => exports.UpdateDistributionWithStagingConfigRequest$, () => exports.UpdateDistributionWithStagingConfigResult$
];
exports.UpdateDomainAssociation$ = [9, n0, _UDA,
    { [_h]: ["POST", "/2020-05-31/domain-association", 200] }, () => exports.UpdateDomainAssociationRequest$, () => exports.UpdateDomainAssociationResult$
];
exports.UpdateFieldLevelEncryptionConfig$ = [9, n0, _UFLEC,
    { [_h]: ["PUT", "/2020-05-31/field-level-encryption/{Id}/config", 200] }, () => exports.UpdateFieldLevelEncryptionConfigRequest$, () => exports.UpdateFieldLevelEncryptionConfigResult$
];
exports.UpdateFieldLevelEncryptionProfile$ = [9, n0, _UFLEP,
    { [_h]: ["PUT", "/2020-05-31/field-level-encryption-profile/{Id}/config", 200] }, () => exports.UpdateFieldLevelEncryptionProfileRequest$, () => exports.UpdateFieldLevelEncryptionProfileResult$
];
exports.UpdateFunction$ = [9, n0, _UF,
    { [_h]: ["PUT", "/2020-05-31/function/{Name}", 200] }, () => exports.UpdateFunctionRequest$, () => exports.UpdateFunctionResult$
];
exports.UpdateKeyGroup$ = [9, n0, _UKG,
    { [_h]: ["PUT", "/2020-05-31/key-group/{Id}", 200] }, () => exports.UpdateKeyGroupRequest$, () => exports.UpdateKeyGroupResult$
];
exports.UpdateKeyValueStore$ = [9, n0, _UKVS,
    { [_h]: ["PUT", "/2020-05-31/key-value-store/{Name}", 200] }, () => exports.UpdateKeyValueStoreRequest$, () => exports.UpdateKeyValueStoreResult$
];
exports.UpdateOriginAccessControl$ = [9, n0, _UOAC,
    { [_h]: ["PUT", "/2020-05-31/origin-access-control/{Id}/config", 200] }, () => exports.UpdateOriginAccessControlRequest$, () => exports.UpdateOriginAccessControlResult$
];
exports.UpdateOriginRequestPolicy$ = [9, n0, _UORP,
    { [_h]: ["PUT", "/2020-05-31/origin-request-policy/{Id}", 200] }, () => exports.UpdateOriginRequestPolicyRequest$, () => exports.UpdateOriginRequestPolicyResult$
];
exports.UpdatePublicKey$ = [9, n0, _UPK,
    { [_h]: ["PUT", "/2020-05-31/public-key/{Id}/config", 200] }, () => exports.UpdatePublicKeyRequest$, () => exports.UpdatePublicKeyResult$
];
exports.UpdateRealtimeLogConfig$ = [9, n0, _URLC,
    { [_h]: ["PUT", "/2020-05-31/realtime-log-config", 200] }, () => exports.UpdateRealtimeLogConfigRequest$, () => exports.UpdateRealtimeLogConfigResult$
];
exports.UpdateResponseHeadersPolicy$ = [9, n0, _URHP,
    { [_h]: ["PUT", "/2020-05-31/response-headers-policy/{Id}", 200] }, () => exports.UpdateResponseHeadersPolicyRequest$, () => exports.UpdateResponseHeadersPolicyResult$
];
exports.UpdateStreamingDistribution$ = [9, n0, _USD,
    { [_h]: ["PUT", "/2020-05-31/streaming-distribution/{Id}/config", 200] }, () => exports.UpdateStreamingDistributionRequest$, () => exports.UpdateStreamingDistributionResult$
];
exports.UpdateTrustStore$ = [9, n0, _UTS,
    { [_h]: ["PUT", "/2020-05-31/trust-store/{Id}", 200] }, () => exports.UpdateTrustStoreRequest$, () => exports.UpdateTrustStoreResult$
];
exports.UpdateVpcOrigin$ = [9, n0, _UVO,
    { [_h]: ["PUT", "/2020-05-31/vpc-origin/{Id}", 202] }, () => exports.UpdateVpcOriginRequest$, () => exports.UpdateVpcOriginResult$
];
exports.VerifyDnsConfiguration$ = [9, n0, _VDC,
    { [_h]: ["POST", "/2020-05-31/verify-dns-configuration", 200] }, () => exports.VerifyDnsConfigurationRequest$, () => exports.VerifyDnsConfigurationResult$
];
